from pydicom._type_definitions import *
import numpy
import os
from _typeshed import Incomplete
from collections.abc import Callable as Callable, Iterator, MutableSequence, Set as Set, ValuesView
from pydicom import config as config, jsonrep as jsonrep
from pydicom._version import __version_info__ as __version_info__
from pydicom.charset import convert_encodings as convert_encodings, default_encoding as default_encoding
from pydicom.config import logger as logger
from pydicom.datadict import dictionary_VR as dictionary_VR, dictionary_description as dictionary_description, get_private_entry as get_private_entry, keyword_for_tag as keyword_for_tag, repeater_has_keyword as repeater_has_keyword, tag_for_keyword as tag_for_keyword
from pydicom.dataelem import DataElement as DataElement, RawDataElement as RawDataElement, convert_raw_data_element as convert_raw_data_element
from pydicom.filebase import ReadableBuffer as ReadableBuffer, WriteableBuffer as WriteableBuffer
from pydicom.fileutil import PathType as PathType, path_from_pathlike as path_from_pathlike
from pydicom.misc import warn_and_log as warn_and_log
from pydicom.pixels import compress as compress, convert_color_space as convert_color_space, decompress as decompress, pixel_array as pixel_array
from pydicom.pixels.utils import get_image_pixel_ids as get_image_pixel_ids, reshape_pixel_array as reshape_pixel_array, set_pixel_data as set_pixel_data
from pydicom.tag import BaseTag as BaseTag, TAG_PIXREP as TAG_PIXREP, Tag as Tag, TagType as TagType, tag_in_exception as tag_in_exception
from pydicom.uid import PYDICOM_IMPLEMENTATION_UID as PYDICOM_IMPLEMENTATION_UID, UID as UID
from pydicom.valuerep import AMBIGUOUS_VR as AMBIGUOUS_VR
from types import TracebackType
from typing import Any, AnyStr, BinaryIO, overload

PIXEL_KEYWORDS: Incomplete

class PrivateBlock:
    group: Incomplete
    private_creator: Incomplete
    dataset: Incomplete
    block_start: Incomplete
    def __init__(self, key: tuple[int, str], dataset: Dataset, private_creator_element: int) -> None: ...
    def get_tag(self, element_offset: int) -> BaseTag: ...
    def __contains__(self, element_offset: int) -> bool: ...
    def __getitem__(self, element_offset: int) -> DataElement: ...
    def __delitem__(self, element_offset: int) -> None: ...
    def add_new(self, element_offset: int, VR: str, value: object) -> None: ...
    def __deepcopy__(self, memo: Any) -> PrivateBlock: ...

class Dataset:
    # Auto-generated class attributes below

    # Keyword: type hint  # VR, VM, Type
    # Part 10, 7.1: File Meta Information ElementsFileMetaInformationGroupLength: int  # UL, 1, 1
    FileMetaInformationVersion: bytes  # OB, 1, 1
    MediaStorageSOPClassUID: str | UID  # UI, 1, 1
    MediaStorageSOPInstanceUID: str | UID  # UI, 1, 1
    TransferSyntaxUID: str | UID  # UI, 1, 1
    ImplementationClassUID: str | UID  # UI, 1, 1
    ImplementationVersionName: str | None  # SH, 1, 3
    SourceApplicationEntityTitle: str | None  # AE, 1, 3
    SendingApplicationEntityTitle: str | None  # AE, 1, 3
    ReceivingApplicationEntityTitle: str | None  # AE, 1, 3
    SourcePresentationAddress: str | None  # UR, 1, 3
    ReceivingPresentationAddress: str | None  # UR, 1, 3
    PrivateInformationCreatorUID: str | UID | None  # UI, 1, 3
    PrivateInformation: bytes  # OB, 1, 1C
    
    # Part 3, C.7.6.3.3: Image Pixel Description Macro
    SamplesPerPixel: int  # US, 1, 1
    PlanarConfiguration: int  # US, 1, 1C
    PhotometricInterpretation: str  # CS, 1, 1
    Rows: int  # US, 1, 1
    Columns: int  # US, 1, 1
    BitsAllocated: int  # US, 1, 1
    BitsStored: int  # US, 1, 1
    HighBit: int  # US, 1, 1
    PixelRepresentation: int  # US, 1, 1
    
    # Part 6, Table 6-1: All other public elements
    CommandGroupLength: UL_1_Type
    AffectedSOPClassUID: UI_1_Type
    RequestedSOPClassUID: UI_1_Type
    CommandField: US_1_Type
    MessageID: US_1_Type
    MessageIDBeingRespondedTo: US_1_Type
    MoveDestination: AE_1_Type
    Priority: US_1_Type
    CommandDataSetType: US_1_Type
    Status: US_1_Type
    OffendingElement: AT_1N_Type
    ErrorComment: LO_1_Type
    ErrorID: US_1_Type
    AffectedSOPInstanceUID: UI_1_Type
    RequestedSOPInstanceUID: UI_1_Type
    EventTypeID: US_1_Type
    AttributeIdentifierList: AT_1N_Type
    ActionTypeID: US_1_Type
    NumberOfRemainingSuboperations: US_1_Type
    NumberOfCompletedSuboperations: US_1_Type
    NumberOfFailedSuboperations: US_1_Type
    NumberOfWarningSuboperations: US_1_Type
    MoveOriginatorApplicationEntityTitle: AE_1_Type
    MoveOriginatorMessageID: US_1_Type
    SendingPresentationAddress: UR_1_Type
    RTVMetaInformationVersion: OB_1_Type
    RTVCommunicationSOPClassUID: UI_1_Type
    RTVCommunicationSOPInstanceUID: UI_1_Type
    RTVSourceIdentifier: OB_1_Type
    RTVFlowIdentifier: OB_1_Type
    RTVFlowRTPSamplingRate: UL_1_Type
    RTVFlowActualFrameDuration: FD_1_Type
    FileSetID: CS_1_Type
    FileSetDescriptorFileID: CS_N_Type
    SpecificCharacterSetOfFileSetDescriptorFile: CS_1_Type
    OffsetOfTheFirstDirectoryRecordOfTheRootDirectoryEntity: UL_1_Type
    OffsetOfTheLastDirectoryRecordOfTheRootDirectoryEntity: UL_1_Type
    FileSetConsistencyFlag: US_1_Type
    DirectoryRecordSequence: SQType
    OffsetOfTheNextDirectoryRecord: UL_1_Type
    RecordInUseFlag: US_1_Type
    OffsetOfReferencedLowerLevelDirectoryEntity: UL_1_Type
    DirectoryRecordType: CS_1_Type
    PrivateRecordUID: UI_1_Type
    ReferencedFileID: CS_N_Type
    ReferencedSOPClassUIDInFile: UI_1_Type
    ReferencedSOPInstanceUIDInFile: UI_1_Type
    ReferencedTransferSyntaxUIDInFile: UI_1_Type
    ReferencedRelatedGeneralSOPClassUIDInFile: UI_1N_Type
    SpecificCharacterSet: CS_1N_Type
    LanguageCodeSequence: SQType
    ImageType: CS_N_Type
    InstanceCreationDate: DA_1_Type
    InstanceCreationTime: TM_1_Type
    InstanceCreatorUID: UI_1_Type
    InstanceCoercionDateTime: DT_1_Type
    SOPClassUID: UI_1_Type
    AcquisitionUID: UI_1_Type
    SOPInstanceUID: UI_1_Type
    PyramidUID: UI_1_Type
    RelatedGeneralSOPClassUID: UI_1N_Type
    OriginalSpecializedSOPClassUID: UI_1_Type
    SyntheticData: CS_1_Type
    StudyDate: DA_1_Type
    SeriesDate: DA_1_Type
    AcquisitionDate: DA_1_Type
    ContentDate: DA_1_Type
    AcquisitionDateTime: DT_1_Type
    StudyTime: TM_1_Type
    SeriesTime: TM_1_Type
    AcquisitionTime: TM_1_Type
    ContentTime: TM_1_Type
    AccessionNumber: SH_1_Type
    IssuerOfAccessionNumberSequence: SQType
    QueryRetrieveLevel: CS_1_Type
    QueryRetrieveView: CS_1_Type
    RetrieveAETitle: AE_1N_Type
    StationAETitle: AE_1_Type
    InstanceAvailability: CS_1_Type
    FailedSOPInstanceUIDList: UI_1N_Type
    Modality: CS_1_Type
    ModalitiesInStudy: CS_1N_Type
    SOPClassesInStudy: UI_1N_Type
    AnatomicRegionsInStudyCodeSequence: SQType
    ConversionType: CS_1_Type
    PresentationIntentType: CS_1_Type
    Manufacturer: LO_1_Type
    InstitutionName: LO_1_Type
    InstitutionAddress: ST_1_Type
    InstitutionCodeSequence: SQType
    ReferringPhysicianName: PN_1_Type
    ReferringPhysicianAddress: ST_1_Type
    ReferringPhysicianTelephoneNumbers: SH_1N_Type
    ReferringPhysicianIdentificationSequence: SQType
    ConsultingPhysicianName: PN_1N_Type
    ConsultingPhysicianIdentificationSequence: SQType
    CodeValue: SH_1_Type
    ExtendedCodeValue: LO_1_Type
    CodingSchemeDesignator: SH_1_Type
    CodingSchemeVersion: SH_1_Type
    CodeMeaning: LO_1_Type
    MappingResource: CS_1_Type
    ContextGroupVersion: DT_1_Type
    ContextGroupLocalVersion: DT_1_Type
    ExtendedCodeMeaning: LT_1_Type
    CodingSchemeResourcesSequence: SQType
    CodingSchemeURLType: CS_1_Type
    ContextGroupExtensionFlag: CS_1_Type
    CodingSchemeUID: UI_1_Type
    ContextGroupExtensionCreatorUID: UI_1_Type
    CodingSchemeURL: UR_1_Type
    ContextIdentifier: CS_1_Type
    CodingSchemeIdentificationSequence: SQType
    CodingSchemeRegistry: LO_1_Type
    CodingSchemeExternalID: ST_1_Type
    CodingSchemeName: ST_1_Type
    CodingSchemeResponsibleOrganization: ST_1_Type
    ContextUID: UI_1_Type
    MappingResourceUID: UI_1_Type
    LongCodeValue: UC_1_Type
    URNCodeValue: UR_1_Type
    EquivalentCodeSequence: SQType
    MappingResourceName: LO_1_Type
    ContextGroupIdentificationSequence: SQType
    MappingResourceIdentificationSequence: SQType
    TimezoneOffsetFromUTC: SH_1_Type
    ResponsibleGroupCodeSequence: SQType
    EquipmentModality: CS_1_Type
    ManufacturerRelatedModelGroup: LO_1_Type
    PrivateDataElementCharacteristicsSequence: SQType
    PrivateGroupReference: US_1_Type
    PrivateCreatorReference: LO_1_Type
    BlockIdentifyingInformationStatus: CS_1_Type
    NonidentifyingPrivateElements: US_1N_Type
    DeidentificationActionSequence: SQType
    IdentifyingPrivateElements: US_1N_Type
    DeidentificationAction: CS_1_Type
    PrivateDataElement: US_1_Type
    PrivateDataElementValueMultiplicity: UL_N_Type
    PrivateDataElementValueRepresentation: CS_1_Type
    PrivateDataElementNumberOfItems: UL_N_Type
    PrivateDataElementName: UC_1_Type
    PrivateDataElementKeyword: UC_1_Type
    PrivateDataElementDescription: UT_1_Type
    PrivateDataElementEncoding: UT_1_Type
    PrivateDataElementDefinitionSequence: SQType
    ScopeOfInventorySequence: SQType
    InventoryPurpose: LT_1_Type
    InventoryInstanceDescription: LT_1_Type
    InventoryLevel: CS_1_Type
    ItemInventoryDateTime: DT_1_Type
    RemovedFromOperationalUse: CS_1_Type
    ReasonForRemovalCodeSequence: SQType
    StoredInstanceBaseURI: UR_1_Type
    FolderAccessURI: UR_1_Type
    FileAccessURI: UR_1_Type
    ContainerFileType: CS_1_Type
    FilenameInContainer: UR_1_Type
    FileOffsetInContainer: UV_1_Type
    FileLengthInContainer: UV_1_Type
    StoredInstanceTransferSyntaxUID: UI_1_Type
    ExtendedMatchingMechanisms: CS_1N_Type
    RangeMatchingSequence: SQType
    ListOfUIDMatchingSequence: SQType
    EmptyValueMatchingSequence: SQType
    GeneralMatchingSequence: SQType
    RequestedStatusInterval: US_1_Type
    RetainInstances: CS_1_Type
    ExpirationDateTime: DT_1_Type
    TransactionStatus: CS_1_Type
    TransactionStatusComment: LT_1_Type
    FileSetAccessSequence: SQType
    FileAccessSequence: SQType
    RecordKey: OB_1_Type
    PriorRecordKey: OB_1_Type
    MetadataSequence: SQType
    UpdatedMetadataSequence: SQType
    StudyUpdateDateTime: DT_1_Type
    InventoryAccessEndPointsSequence: SQType
    StudyAccessEndPointsSequence: SQType
    IncorporatedInventoryInstanceSequence: SQType
    InventoriedStudiesSequence: SQType
    InventoriedSeriesSequence: SQType
    InventoriedInstancesSequence: SQType
    InventoryCompletionStatus: CS_1_Type
    NumberOfStudyRecordsInInstance: UL_1_Type
    TotalNumberOfStudyRecords: UV_1_Type
    MaximumNumberOfRecords: UV_1_Type
    StationName: SH_1_Type
    StudyDescription: LO_1_Type
    ProcedureCodeSequence: SQType
    SeriesDescription: LO_1_Type
    SeriesDescriptionCodeSequence: SQType
    InstitutionalDepartmentName: LO_1_Type
    InstitutionalDepartmentTypeCodeSequence: SQType
    PhysiciansOfRecord: PN_1N_Type
    PhysiciansOfRecordIdentificationSequence: SQType
    PerformingPhysicianName: PN_1N_Type
    PerformingPhysicianIdentificationSequence: SQType
    NameOfPhysiciansReadingStudy: PN_1N_Type
    PhysiciansReadingStudyIdentificationSequence: SQType
    OperatorsName: PN_1N_Type
    OperatorIdentificationSequence: SQType
    AdmittingDiagnosesDescription: LO_1N_Type
    AdmittingDiagnosesCodeSequence: SQType
    PyramidDescription: LO_1_Type
    ManufacturerModelName: LO_1_Type
    ReferencedStudySequence: SQType
    ReferencedPerformedProcedureStepSequence: SQType
    ReferencedInstancesBySOPClassSequence: SQType
    ReferencedSeriesSequence: SQType
    ReferencedPatientSequence: SQType
    ReferencedVisitSequence: SQType
    ReferencedStereometricInstanceSequence: SQType
    ReferencedWaveformSequence: SQType
    ReferencedImageSequence: SQType
    ReferencedInstanceSequence: SQType
    ReferencedRealWorldValueMappingInstanceSequence: SQType
    ReferencedSOPClassUID: UI_1_Type
    ReferencedSOPInstanceUID: UI_1_Type
    DefinitionSourceSequence: SQType
    SOPClassesSupported: UI_1N_Type
    ReferencedFrameNumber: IS_1N_Type
    SimpleFrameList: UL_1N_Type
    CalculatedFrameList: UL_N_Type
    TimeRange: FD_N_Type
    FrameExtractionSequence: SQType
    MultiFrameSourceSOPInstanceUID: UI_1_Type
    RetrieveURL: UR_1_Type
    TransactionUID: UI_1_Type
    WarningReason: US_1_Type
    FailureReason: US_1_Type
    FailedSOPSequence: SQType
    ReferencedSOPSequence: SQType
    OtherFailuresSequence: SQType
    FailedStudySequence: SQType
    StudiesContainingOtherReferencedInstancesSequence: SQType
    RelatedSeriesSequence: SQType
    DerivationDescription: ST_1_Type
    SourceImageSequence: SQType
    StageName: SH_1_Type
    StageNumber: IS_1_Type
    NumberOfStages: IS_1_Type
    ViewName: SH_1_Type
    ViewNumber: IS_1_Type
    NumberOfEventTimers: IS_1_Type
    NumberOfViewsInStage: IS_1_Type
    EventElapsedTimes: DS_1N_Type
    EventTimerNames: LO_1N_Type
    EventTimerSequence: SQType
    EventTimeOffset: FD_1_Type
    EventCodeSequence: SQType
    StartTrim: IS_1_Type
    StopTrim: IS_1_Type
    RecommendedDisplayFrameRate: IS_1_Type
    AnatomicRegionSequence: SQType
    AnatomicRegionModifierSequence: SQType
    PrimaryAnatomicStructureSequence: SQType
    PrimaryAnatomicStructureModifierSequence: SQType
    AlternateRepresentationSequence: SQType
    AvailableTransferSyntaxUID: UI_1N_Type
    IrradiationEventUID: UI_1N_Type
    SourceIrradiationEventSequence: SQType
    RadiopharmaceuticalAdministrationEventUID: UI_1_Type
    FrameType: CS_N_Type
    ReferencedImageEvidenceSequence: SQType
    ReferencedRawDataSequence: SQType
    CreatorVersionUID: UI_1_Type
    DerivationImageSequence: SQType
    SourceImageEvidenceSequence: SQType
    PixelPresentation: CS_1_Type
    VolumetricProperties: CS_1_Type
    VolumeBasedCalculationTechnique: CS_1_Type
    ComplexImageComponent: CS_1_Type
    AcquisitionContrast: CS_1_Type
    DerivationCodeSequence: SQType
    ReferencedPresentationStateSequence: SQType
    ReferencedOtherPlaneSequence: SQType
    FrameDisplaySequence: SQType
    RecommendedDisplayFrameRateInFloat: FL_1_Type
    SkipFrameRangeFlag: CS_1_Type
    PatientName: PN_1_Type
    PatientID: LO_1_Type
    IssuerOfPatientID: LO_1_Type
    TypeOfPatientID: CS_1_Type
    IssuerOfPatientIDQualifiersSequence: SQType
    SourcePatientGroupIdentificationSequence: SQType
    GroupOfPatientsIdentificationSequence: SQType
    SubjectRelativePositionInImage: US_N_Type
    PatientBirthDate: DA_1_Type
    PatientBirthTime: TM_1_Type
    PatientBirthDateInAlternativeCalendar: LO_1_Type
    PatientDeathDateInAlternativeCalendar: LO_1_Type
    PatientAlternativeCalendar: CS_1_Type
    PatientSex: CS_1_Type
    PatientInsurancePlanCodeSequence: SQType
    PatientPrimaryLanguageCodeSequence: SQType
    PatientPrimaryLanguageModifierCodeSequence: SQType
    QualityControlSubject: CS_1_Type
    QualityControlSubjectTypeCodeSequence: SQType
    StrainDescription: UC_1_Type
    StrainNomenclature: LO_1_Type
    StrainStockNumber: LO_1_Type
    StrainSourceRegistryCodeSequence: SQType
    StrainStockSequence: SQType
    StrainSource: LO_1_Type
    StrainAdditionalInformation: UT_1_Type
    StrainCodeSequence: SQType
    GeneticModificationsSequence: SQType
    GeneticModificationsDescription: UC_1_Type
    GeneticModificationsNomenclature: LO_1_Type
    GeneticModificationsCodeSequence: SQType
    OtherPatientNames: PN_1N_Type
    OtherPatientIDsSequence: SQType
    PatientBirthName: PN_1_Type
    PatientAge: AS_1_Type
    PatientSize: DS_1_Type
    PatientSizeCodeSequence: SQType
    PatientBodyMassIndex: DS_1_Type
    MeasuredAPDimension: DS_1_Type
    MeasuredLateralDimension: DS_1_Type
    PatientWeight: DS_1_Type
    PatientAddress: LO_1_Type
    PatientMotherBirthName: PN_1_Type
    MilitaryRank: LO_1_Type
    BranchOfService: LO_1_Type
    ReferencedPatientPhotoSequence: SQType
    MedicalAlerts: LO_1N_Type
    Allergies: LO_1N_Type
    CountryOfResidence: LO_1_Type
    RegionOfResidence: LO_1_Type
    PatientTelephoneNumbers: SH_1N_Type
    PatientTelecomInformation: LT_1_Type
    EthnicGroup: SH_1_Type
    EthnicGroupCodeSequence: SQType
    Occupation: SH_1_Type
    SmokingStatus: CS_1_Type
    AdditionalPatientHistory: LT_1_Type
    PregnancyStatus: US_1_Type
    LastMenstrualDate: DA_1_Type
    PatientReligiousPreference: LO_1_Type
    PatientSpeciesDescription: LO_1_Type
    PatientSpeciesCodeSequence: SQType
    PatientSexNeutered: CS_1_Type
    AnatomicalOrientationType: CS_1_Type
    PatientBreedDescription: LO_1_Type
    PatientBreedCodeSequence: SQType
    BreedRegistrationSequence: SQType
    BreedRegistrationNumber: LO_1_Type
    BreedRegistryCodeSequence: SQType
    ResponsiblePerson: PN_1_Type
    ResponsiblePersonRole: CS_1_Type
    ResponsibleOrganization: LO_1_Type
    PatientComments: LT_1_Type
    ExaminedBodyThickness: FL_1_Type
    ClinicalTrialSponsorName: LO_1_Type
    ClinicalTrialProtocolID: LO_1_Type
    ClinicalTrialProtocolName: LO_1_Type
    IssuerOfClinicalTrialProtocolID: LO_1_Type
    OtherClinicalTrialProtocolIDsSequence: SQType
    ClinicalTrialSiteID: LO_1_Type
    ClinicalTrialSiteName: LO_1_Type
    IssuerOfClinicalTrialSiteID: LO_1_Type
    ClinicalTrialSubjectID: LO_1_Type
    IssuerOfClinicalTrialSubjectID: LO_1_Type
    ClinicalTrialSubjectReadingID: LO_1_Type
    IssuerOfClinicalTrialSubjectReadingID: LO_1_Type
    ClinicalTrialTimePointID: LO_1_Type
    ClinicalTrialTimePointDescription: ST_1_Type
    LongitudinalTemporalOffsetFromEvent: FD_1_Type
    LongitudinalTemporalEventType: CS_1_Type
    ClinicalTrialTimePointTypeCodeSequence: SQType
    IssuerOfClinicalTrialTimePointID: LO_1_Type
    ClinicalTrialCoordinatingCenterName: LO_1_Type
    PatientIdentityRemoved: CS_1_Type
    DeidentificationMethod: LO_1N_Type
    DeidentificationMethodCodeSequence: SQType
    ClinicalTrialSeriesID: LO_1_Type
    ClinicalTrialSeriesDescription: LO_1_Type
    IssuerOfClinicalTrialSeriesID: LO_1_Type
    ClinicalTrialProtocolEthicsCommitteeName: LO_1_Type
    ClinicalTrialProtocolEthicsCommitteeApprovalNumber: LO_1_Type
    ConsentForClinicalTrialUseSequence: SQType
    DistributionType: CS_1_Type
    ConsentForDistributionFlag: CS_1_Type
    EthicsCommitteeApprovalEffectivenessStartDate: DA_1_Type
    EthicsCommitteeApprovalEffectivenessEndDate: DA_1_Type
    ComponentManufacturingProcedure: ST_1_Type
    ComponentManufacturer: ST_1_Type
    MaterialThickness: DS_1N_Type
    MaterialPipeDiameter: DS_1N_Type
    MaterialIsolationDiameter: DS_1N_Type
    MaterialGrade: ST_1_Type
    MaterialPropertiesDescription: ST_1_Type
    MaterialNotes: LT_1_Type
    ComponentShape: CS_1_Type
    CurvatureType: CS_1_Type
    OuterDiameter: DS_1_Type
    InnerDiameter: DS_1_Type
    ComponentWelderIDs: LO_1N_Type
    SecondaryApprovalStatus: CS_1_Type
    SecondaryReviewDate: DA_1_Type
    SecondaryReviewTime: TM_1_Type
    SecondaryReviewerName: PN_1_Type
    RepairID: ST_1_Type
    MultipleComponentApprovalSequence: SQType
    OtherApprovalStatus: CS_1N_Type
    OtherSecondaryApprovalStatus: CS_1N_Type
    DataElementLabelSequence: SQType
    DataElementLabelItemSequence: SQType
    DataElement: AT_1_Type
    DataElementName: LO_1_Type
    DataElementDescription: LO_1_Type
    DataElementConditionality: CS_1_Type
    DataElementMinimumCharacters: IS_1_Type
    DataElementMaximumCharacters: IS_1_Type
    ActualEnvironmentalConditions: ST_1_Type
    ExpiryDate: DA_1_Type
    EnvironmentalConditions: ST_1_Type
    EvaluatorSequence: SQType
    EvaluatorNumber: IS_1_Type
    EvaluatorName: PN_1_Type
    EvaluationAttempt: IS_1_Type
    IndicationSequence: SQType
    IndicationNumber: IS_1_Type
    IndicationLabel: SH_1_Type
    IndicationDescription: ST_1_Type
    IndicationType: CS_1N_Type
    IndicationDisposition: CS_1_Type
    IndicationROISequence: SQType
    IndicationPhysicalPropertySequence: SQType
    PropertyLabel: SH_1_Type
    CoordinateSystemNumberOfAxes: IS_1_Type
    CoordinateSystemAxesSequence: SQType
    CoordinateSystemAxisDescription: ST_1_Type
    CoordinateSystemDataSetMapping: CS_1_Type
    CoordinateSystemAxisNumber: IS_1_Type
    CoordinateSystemAxisType: CS_1_Type
    CoordinateSystemAxisUnits: CS_1_Type
    CoordinateSystemAxisValues: OB_1_Type
    CoordinateSystemTransformSequence: SQType
    TransformDescription: ST_1_Type
    TransformNumberOfAxes: IS_1_Type
    TransformOrderOfAxes: IS_1N_Type
    TransformedAxisUnits: CS_1_Type
    CoordinateSystemTransformRotationAndScaleMatrix: DS_1N_Type
    CoordinateSystemTransformTranslationMatrix: DS_1N_Type
    InternalDetectorFrameTime: DS_1_Type
    NumberOfFramesIntegrated: DS_1_Type
    DetectorTemperatureSequence: SQType
    SensorName: ST_1_Type
    HorizontalOffsetOfSensor: DS_1_Type
    VerticalOffsetOfSensor: DS_1_Type
    SensorTemperature: DS_1_Type
    DarkCurrentSequence: SQType
    DarkCurrentCounts: OB_OW_Type
    GainCorrectionReferenceSequence: SQType
    AirCounts: OB_OW_Type
    KVUsedInGainCalibration: DS_1_Type
    MAUsedInGainCalibration: DS_1_Type
    NumberOfFramesUsedForIntegration: DS_1_Type
    FilterMaterialUsedInGainCalibration: LO_1_Type
    FilterThicknessUsedInGainCalibration: DS_1_Type
    DateOfGainCalibration: DA_1_Type
    TimeOfGainCalibration: TM_1_Type
    BadPixelImage: OB_1_Type
    CalibrationNotes: LT_1_Type
    LinearityCorrectionTechnique: LT_1_Type
    BeamHardeningCorrectionTechnique: LT_1_Type
    PulserEquipmentSequence: SQType
    PulserType: CS_1_Type
    PulserNotes: LT_1_Type
    ReceiverEquipmentSequence: SQType
    AmplifierType: CS_1_Type
    ReceiverNotes: LT_1_Type
    PreAmplifierEquipmentSequence: SQType
    PreAmplifierNotes: LT_1_Type
    TransmitTransducerSequence: SQType
    ReceiveTransducerSequence: SQType
    NumberOfElements: US_1_Type
    ElementShape: CS_1_Type
    ElementDimensionA: DS_1_Type
    ElementDimensionB: DS_1_Type
    ElementPitchA: DS_1_Type
    MeasuredBeamDimensionA: DS_1_Type
    MeasuredBeamDimensionB: DS_1_Type
    LocationOfMeasuredBeamDiameter: DS_1_Type
    NominalFrequency: DS_1_Type
    MeasuredCenterFrequency: DS_1_Type
    MeasuredBandwidth: DS_1_Type
    ElementPitchB: DS_1_Type
    PulserSettingsSequence: SQType
    PulseWidth: DS_1_Type
    ExcitationFrequency: DS_1_Type
    ModulationType: CS_1_Type
    Damping: DS_1_Type
    ReceiverSettingsSequence: SQType
    AcquiredSoundpathLength: DS_1_Type
    AcquisitionCompressionType: CS_1_Type
    AcquisitionSampleSize: IS_1_Type
    RectifierSmoothing: DS_1_Type
    DACSequence: SQType
    DACType: CS_1_Type
    DACGainPoints: DS_1N_Type
    DACTimePoints: DS_1N_Type
    DACAmplitude: DS_1N_Type
    PreAmplifierSettingsSequence: SQType
    TransmitTransducerSettingsSequence: SQType
    ReceiveTransducerSettingsSequence: SQType
    IncidentAngle: DS_1_Type
    CouplingTechnique: ST_1_Type
    CouplingMedium: ST_1_Type
    CouplingVelocity: DS_1_Type
    ProbeCenterLocationX: DS_1_Type
    ProbeCenterLocationZ: DS_1_Type
    SoundPathLength: DS_1_Type
    DelayLawIdentifier: ST_1_Type
    GateSettingsSequence: SQType
    GateThreshold: DS_1_Type
    VelocityOfSound: DS_1_Type
    CalibrationSettingsSequence: SQType
    CalibrationProcedure: ST_1_Type
    ProcedureVersion: SH_1_Type
    ProcedureCreationDate: DA_1_Type
    ProcedureExpirationDate: DA_1_Type
    ProcedureLastModifiedDate: DA_1_Type
    CalibrationTime: TM_1N_Type
    CalibrationDate: DA_1N_Type
    ProbeDriveEquipmentSequence: SQType
    DriveType: CS_1_Type
    ProbeDriveNotes: LT_1_Type
    DriveProbeSequence: SQType
    ProbeInductance: DS_1_Type
    ProbeResistance: DS_1_Type
    ReceiveProbeSequence: SQType
    ProbeDriveSettingsSequence: SQType
    BridgeResistors: DS_1_Type
    ProbeOrientationAngle: DS_1_Type
    UserSelectedGainY: DS_1_Type
    UserSelectedPhase: DS_1_Type
    UserSelectedOffsetX: DS_1_Type
    UserSelectedOffsetY: DS_1_Type
    ChannelSettingsSequence: SQType
    ChannelThreshold: DS_1_Type
    ScannerSettingsSequence: SQType
    ScanProcedure: ST_1_Type
    TranslationRateX: DS_1_Type
    TranslationRateY: DS_1_Type
    ChannelOverlap: DS_1_Type
    ImageQualityIndicatorType: LO_1N_Type
    ImageQualityIndicatorMaterial: LO_1N_Type
    ImageQualityIndicatorSize: LO_1N_Type
    LINACEnergy: IS_1_Type
    LINACOutput: IS_1_Type
    ActiveAperture: US_1_Type
    TotalAperture: DS_1_Type
    ApertureElevation: DS_1_Type
    MainLobeAngle: DS_1_Type
    MainRoofAngle: DS_1_Type
    ConnectorType: CS_1_Type
    WedgeModelNumber: SH_1_Type
    WedgeAngleFloat: DS_1_Type
    WedgeRoofAngle: DS_1_Type
    WedgeElement1Position: CS_1_Type
    WedgeMaterialVelocity: DS_1_Type
    WedgeMaterial: SH_1_Type
    WedgeOffsetZ: DS_1_Type
    WedgeOriginOffsetX: DS_1_Type
    WedgeTimeDelay: DS_1_Type
    WedgeName: SH_1_Type
    WedgeManufacturerName: SH_1_Type
    WedgeDescription: LO_1_Type
    NominalBeamAngle: DS_1_Type
    WedgeOffsetX: DS_1_Type
    WedgeOffsetY: DS_1_Type
    WedgeTotalLength: DS_1_Type
    WedgeInContactLength: DS_1_Type
    WedgeFrontGap: DS_1_Type
    WedgeTotalHeight: DS_1_Type
    WedgeFrontHeight: DS_1_Type
    WedgeRearHeight: DS_1_Type
    WedgeTotalWidth: DS_1_Type
    WedgeInContactWidth: DS_1_Type
    WedgeChamferHeight: DS_1_Type
    WedgeCurve: CS_1_Type
    RadiusAlongWedge: DS_1_Type
    WhitePoint: DS_1_Type
    PrimaryChromaticities: DS_N_Type
    BatteryLevel: UT_1_Type
    ExposureTimeInSeconds: DS_1_Type
    FNumber: DS_1_Type
    OECFRows: IS_1_Type
    OECFColumns: IS_1_Type
    OECFColumnNames: UC_1N_Type
    OECFValues: DS_1N_Type
    SpatialFrequencyResponseRows: IS_1_Type
    SpatialFrequencyResponseColumns: IS_1_Type
    SpatialFrequencyResponseColumnNames: UC_1N_Type
    SpatialFrequencyResponseValues: DS_1N_Type
    ColorFilterArrayPatternRows: IS_1_Type
    ColorFilterArrayPatternColumns: IS_1_Type
    ColorFilterArrayPatternValues: DS_1N_Type
    FlashFiringStatus: US_1_Type
    FlashReturnStatus: US_1_Type
    FlashMode: US_1_Type
    FlashFunctionPresent: US_1_Type
    FlashRedEyeMode: US_1_Type
    ExposureProgram: US_1_Type
    SpectralSensitivity: UT_1_Type
    PhotographicSensitivity: IS_1_Type
    SelfTimerMode: IS_1_Type
    SensitivityType: US_1_Type
    StandardOutputSensitivity: IS_1_Type
    RecommendedExposureIndex: IS_1_Type
    ISOSpeed: IS_1_Type
    ISOSpeedLatitudeyyy: IS_1_Type
    ISOSpeedLatitudezzz: IS_1_Type
    EXIFVersion: UT_1_Type
    ShutterSpeedValue: DS_1_Type
    ApertureValue: DS_1_Type
    BrightnessValue: DS_1_Type
    ExposureBiasValue: DS_1_Type
    MaxApertureValue: DS_1_Type
    SubjectDistance: DS_1_Type
    MeteringMode: US_1_Type
    LightSource: US_1_Type
    FocalLength: DS_1_Type
    SubjectArea: IS_N_Type
    MakerNote: OB_1_Type
    Temperature: DS_1_Type
    Humidity: DS_1_Type
    Pressure: DS_1_Type
    WaterDepth: DS_1_Type
    Acceleration: DS_1_Type
    CameraElevationAngle: DS_1_Type
    FlashEnergy: DS_N_Type
    SubjectLocation: IS_N_Type
    PhotographicExposureIndex: DS_1_Type
    SensingMethod: US_1_Type
    FileSource: US_1_Type
    SceneType: US_1_Type
    CustomRendered: US_1_Type
    ExposureMode: US_1_Type
    WhiteBalance: US_1_Type
    DigitalZoomRatio: DS_1_Type
    FocalLengthIn35mmFilm: IS_1_Type
    SceneCaptureType: US_1_Type
    GainControl: US_1_Type
    Contrast: US_1_Type
    Saturation: US_1_Type
    Sharpness: US_1_Type
    DeviceSettingDescription: OB_1_Type
    SubjectDistanceRange: US_1_Type
    CameraOwnerName: UT_1_Type
    LensSpecification: DS_N_Type
    LensMake: UT_1_Type
    LensModel: UT_1_Type
    LensSerialNumber: UT_1_Type
    InteroperabilityIndex: CS_1_Type
    InteroperabilityVersion: OB_1_Type
    GPSVersionID: OB_1_Type
    GPSLatitudeRef: CS_1_Type
    GPSLatitude: DS_N_Type
    GPSLongitudeRef: CS_1_Type
    GPSLongitude: DS_N_Type
    GPSAltitudeRef: US_1_Type
    GPSAltitude: DS_1_Type
    GPSTimeStamp: DT_1_Type
    GPSSatellites: UT_1_Type
    GPSStatus: CS_1_Type
    GPSMeasureMode: CS_1_Type
    GPSDOP: DS_1_Type
    GPSSpeedRef: CS_1_Type
    GPSSpeed: DS_1_Type
    GPSTrackRef: CS_1_Type
    GPSTrack: DS_1_Type
    GPSImgDirectionRef: CS_1_Type
    GPSImgDirection: DS_1_Type
    GPSMapDatum: UT_1_Type
    GPSDestLatitudeRef: CS_1_Type
    GPSDestLatitude: DS_N_Type
    GPSDestLongitudeRef: CS_1_Type
    GPSDestLongitude: DS_N_Type
    GPSDestBearingRef: CS_1_Type
    GPSDestBearing: DS_1_Type
    GPSDestDistanceRef: CS_1_Type
    GPSDestDistance: DS_1_Type
    GPSProcessingMethod: OB_1_Type
    GPSAreaInformation: OB_1_Type
    GPSDateStamp: DT_1_Type
    GPSDifferential: IS_1_Type
    LightSourcePolarization: CS_1_Type
    EmitterColorTemperature: DS_1_Type
    ContactMethod: CS_1_Type
    ImmersionMedia: CS_1N_Type
    OpticalMagnificationFactor: DS_1_Type
    ContrastBolusAgent: LO_1_Type
    ContrastBolusAgentSequence: SQType
    ContrastBolusT1Relaxivity: FL_1_Type
    ContrastBolusAdministrationRouteSequence: SQType
    BodyPartExamined: CS_1_Type
    ScanningSequence: CS_1N_Type
    SequenceVariant: CS_1N_Type
    ScanOptions: CS_1N_Type
    MRAcquisitionType: CS_1_Type
    SequenceName: SH_1_Type
    AngioFlag: CS_1_Type
    InterventionDrugInformationSequence: SQType
    InterventionDrugStopTime: TM_1_Type
    InterventionDrugDose: DS_1_Type
    InterventionDrugCodeSequence: SQType
    AdditionalDrugSequence: SQType
    Radiopharmaceutical: LO_1_Type
    InterventionDrugName: LO_1_Type
    InterventionDrugStartTime: TM_1_Type
    InterventionSequence: SQType
    InterventionStatus: CS_1_Type
    InterventionDescription: ST_1_Type
    CineRate: IS_1_Type
    InitialCineRunState: CS_1_Type
    SliceThickness: DS_1_Type
    KVP: DS_1_Type
    CountsAccumulated: IS_1_Type
    AcquisitionTerminationCondition: CS_1_Type
    EffectiveDuration: DS_1_Type
    AcquisitionStartCondition: CS_1_Type
    AcquisitionStartConditionData: IS_1_Type
    AcquisitionTerminationConditionData: IS_1_Type
    RepetitionTime: DS_1_Type
    EchoTime: DS_1_Type
    InversionTime: DS_1_Type
    NumberOfAverages: DS_1_Type
    ImagingFrequency: DS_1_Type
    ImagedNucleus: SH_1_Type
    EchoNumbers: IS_1N_Type
    MagneticFieldStrength: DS_1_Type
    SpacingBetweenSlices: DS_1_Type
    NumberOfPhaseEncodingSteps: IS_1_Type
    DataCollectionDiameter: DS_1_Type
    EchoTrainLength: IS_1_Type
    PercentSampling: DS_1_Type
    PercentPhaseFieldOfView: DS_1_Type
    PixelBandwidth: DS_1_Type
    DeviceSerialNumber: LO_1_Type
    DeviceUID: UI_1_Type
    DeviceID: LO_1_Type
    PlateID: LO_1_Type
    GeneratorID: LO_1_Type
    GridID: LO_1_Type
    CassetteID: LO_1_Type
    GantryID: LO_1_Type
    UniqueDeviceIdentifier: UT_1_Type
    UDISequence: SQType
    ManufacturerDeviceClassUID: UI_1N_Type
    SecondaryCaptureDeviceID: LO_1_Type
    DateOfSecondaryCapture: DA_1_Type
    TimeOfSecondaryCapture: TM_1_Type
    SecondaryCaptureDeviceManufacturer: LO_1_Type
    SecondaryCaptureDeviceManufacturerModelName: LO_1_Type
    SecondaryCaptureDeviceSoftwareVersions: LO_1N_Type
    SoftwareVersions: LO_1N_Type
    VideoImageFormatAcquired: SH_1_Type
    DigitalImageFormatAcquired: LO_1_Type
    ProtocolName: LO_1_Type
    ContrastBolusRoute: LO_1_Type
    ContrastBolusVolume: DS_1_Type
    ContrastBolusStartTime: TM_1_Type
    ContrastBolusStopTime: TM_1_Type
    ContrastBolusTotalDose: DS_1_Type
    SyringeCounts: IS_1_Type
    ContrastFlowRate: DS_1N_Type
    ContrastFlowDuration: DS_1N_Type
    ContrastBolusIngredient: CS_1_Type
    ContrastBolusIngredientConcentration: DS_1_Type
    SpatialResolution: DS_1_Type
    TriggerTime: DS_1_Type
    TriggerSourceOrType: LO_1_Type
    NominalInterval: IS_1_Type
    FrameTime: DS_1_Type
    CardiacFramingType: LO_1_Type
    FrameTimeVector: DS_1N_Type
    FrameDelay: DS_1_Type
    ImageTriggerDelay: DS_1_Type
    MultiplexGroupTimeOffset: DS_1_Type
    TriggerTimeOffset: DS_1_Type
    SynchronizationTrigger: CS_1_Type
    SynchronizationChannel: US_N_Type
    TriggerSamplePosition: UL_1_Type
    RadiopharmaceuticalRoute: LO_1_Type
    RadiopharmaceuticalVolume: DS_1_Type
    RadiopharmaceuticalStartTime: TM_1_Type
    RadiopharmaceuticalStopTime: TM_1_Type
    RadionuclideTotalDose: DS_1_Type
    RadionuclideHalfLife: DS_1_Type
    RadionuclidePositronFraction: DS_1_Type
    RadiopharmaceuticalSpecificActivity: DS_1_Type
    RadiopharmaceuticalStartDateTime: DT_1_Type
    RadiopharmaceuticalStopDateTime: DT_1_Type
    BeatRejectionFlag: CS_1_Type
    LowRRValue: IS_1_Type
    HighRRValue: IS_1_Type
    IntervalsAcquired: IS_1_Type
    IntervalsRejected: IS_1_Type
    PVCRejection: LO_1_Type
    SkipBeats: IS_1_Type
    HeartRate: IS_1_Type
    CardiacNumberOfImages: IS_1_Type
    TriggerWindow: IS_1_Type
    ReconstructionDiameter: DS_1_Type
    DistanceSourceToDetector: DS_1_Type
    DistanceSourceToPatient: DS_1_Type
    EstimatedRadiographicMagnificationFactor: DS_1_Type
    GantryDetectorTilt: DS_1_Type
    GantryDetectorSlew: DS_1_Type
    TableHeight: DS_1_Type
    TableTraverse: DS_1_Type
    TableMotion: CS_1_Type
    TableVerticalIncrement: DS_1N_Type
    TableLateralIncrement: DS_1N_Type
    TableLongitudinalIncrement: DS_1N_Type
    TableAngle: DS_1_Type
    TableType: CS_1_Type
    RotationDirection: CS_1_Type
    RadialPosition: DS_1N_Type
    ScanArc: DS_1_Type
    AngularStep: DS_1_Type
    CenterOfRotationOffset: DS_1_Type
    FieldOfViewShape: CS_1_Type
    FieldOfViewDimensions: IS_N_Type
    ExposureTime: IS_1_Type
    XRayTubeCurrent: IS_1_Type
    Exposure: IS_1_Type
    ExposureInuAs: IS_1_Type
    AveragePulseWidth: DS_1_Type
    RadiationSetting: CS_1_Type
    RectificationType: CS_1_Type
    RadiationMode: CS_1_Type
    ImageAndFluoroscopyAreaDoseProduct: DS_1_Type
    FilterType: SH_1_Type
    TypeOfFilters: LO_1N_Type
    IntensifierSize: DS_1_Type
    ImagerPixelSpacing: DS_N_Type
    Grid: CS_1N_Type
    GeneratorPower: IS_1_Type
    CollimatorGridName: SH_1_Type
    CollimatorType: CS_1_Type
    FocalDistance: IS_N_Type
    XFocusCenter: DS_N_Type
    YFocusCenter: DS_N_Type
    FocalSpots: DS_1N_Type
    AnodeTargetMaterial: CS_1_Type
    BodyPartThickness: DS_1_Type
    CompressionForce: DS_1_Type
    CompressionPressure: DS_1_Type
    PaddleDescription: LO_1_Type
    CompressionContactArea: DS_1_Type
    AcquisitionMode: LO_1_Type
    DoseModeName: LO_1_Type
    AcquiredSubtractionMaskFlag: CS_1_Type
    FluoroscopyPersistenceFlag: CS_1_Type
    FluoroscopyLastImageHoldPersistenceFlag: CS_1_Type
    UpperLimitNumberOfPersistentFluoroscopyFrames: IS_1_Type
    ContrastBolusAutoInjectionTriggerFlag: CS_1_Type
    ContrastBolusInjectionDelay: FD_1_Type
    XAAcquisitionPhaseDetailsSequence: SQType
    XAAcquisitionFrameRate: FD_1_Type
    XAPlaneDetailsSequence: SQType
    AcquisitionFieldOfViewLabel: LO_1_Type
    XRayFilterDetailsSequence: SQType
    XAAcquisitionDuration: FD_1_Type
    ReconstructionPipelineType: CS_1_Type
    ImageFilterDetailsSequence: SQType
    AppliedMaskSubtractionFlag: CS_1_Type
    RequestedSeriesDescriptionCodeSequence: SQType
    DateOfLastCalibration: DA_1N_Type
    TimeOfLastCalibration: TM_1N_Type
    DateTimeOfLastCalibration: DT_1_Type
    CalibrationDateTime: DT_1_Type
    DateOfManufacture: DA_1_Type
    DateOfInstallation: DA_1_Type
    ConvolutionKernel: SH_1N_Type
    ActualFrameDuration: IS_1_Type
    CountRate: IS_1_Type
    PreferredPlaybackSequencing: US_1_Type
    ReceiveCoilName: SH_1_Type
    TransmitCoilName: SH_1_Type
    PlateType: SH_1_Type
    PhosphorType: LO_1_Type
    WaterEquivalentDiameter: FD_1_Type
    WaterEquivalentDiameterCalculationMethodCodeSequence: SQType
    ScanVelocity: DS_1_Type
    WholeBodyTechnique: CS_1N_Type
    ScanLength: IS_1_Type
    AcquisitionMatrix: US_N_Type
    InPlanePhaseEncodingDirection: CS_1_Type
    FlipAngle: DS_1_Type
    VariableFlipAngleFlag: CS_1_Type
    SAR: DS_1_Type
    dBdt: DS_1_Type
    B1rms: FL_1_Type
    AcquisitionDeviceProcessingDescription: LO_1_Type
    AcquisitionDeviceProcessingCode: LO_1_Type
    CassetteOrientation: CS_1_Type
    CassetteSize: CS_1_Type
    ExposuresOnPlate: US_1_Type
    RelativeXRayExposure: IS_1_Type
    ExposureIndex: DS_1_Type
    TargetExposureIndex: DS_1_Type
    DeviationIndex: DS_1_Type
    ColumnAngulation: DS_1_Type
    TomoLayerHeight: DS_1_Type
    TomoAngle: DS_1_Type
    TomoTime: DS_1_Type
    TomoType: CS_1_Type
    TomoClass: CS_1_Type
    NumberOfTomosynthesisSourceImages: IS_1_Type
    PositionerMotion: CS_1_Type
    PositionerType: CS_1_Type
    PositionerPrimaryAngle: DS_1_Type
    PositionerSecondaryAngle: DS_1_Type
    PositionerPrimaryAngleIncrement: DS_1N_Type
    PositionerSecondaryAngleIncrement: DS_1N_Type
    DetectorPrimaryAngle: DS_1_Type
    DetectorSecondaryAngle: DS_1_Type
    ShutterShape: CS_N_Type
    ShutterLeftVerticalEdge: IS_1_Type
    ShutterRightVerticalEdge: IS_1_Type
    ShutterUpperHorizontalEdge: IS_1_Type
    ShutterLowerHorizontalEdge: IS_1_Type
    CenterOfCircularShutter: IS_N_Type
    RadiusOfCircularShutter: IS_1_Type
    VerticesOfThePolygonalShutter: IS_N_Type
    ShutterPresentationValue: US_1_Type
    ShutterOverlayGroup: US_1_Type
    ShutterPresentationColorCIELabValue: US_N_Type
    OutlineShapeType: CS_1_Type
    OutlineLeftVerticalEdge: FD_1_Type
    OutlineRightVerticalEdge: FD_1_Type
    OutlineUpperHorizontalEdge: FD_1_Type
    OutlineLowerHorizontalEdge: FD_1_Type
    CenterOfCircularOutline: FD_N_Type
    DiameterOfCircularOutline: FD_1_Type
    NumberOfPolygonalVertices: UL_1_Type
    VerticesOfThePolygonalOutline: OF_1_Type
    CollimatorShape: CS_N_Type
    CollimatorLeftVerticalEdge: IS_1_Type
    CollimatorRightVerticalEdge: IS_1_Type
    CollimatorUpperHorizontalEdge: IS_1_Type
    CollimatorLowerHorizontalEdge: IS_1_Type
    CenterOfCircularCollimator: IS_N_Type
    RadiusOfCircularCollimator: IS_1_Type
    VerticesOfThePolygonalCollimator: IS_N_Type
    AcquisitionTimeSynchronized: CS_1_Type
    TimeSource: SH_1_Type
    TimeDistributionProtocol: CS_1_Type
    NTPSourceAddress: LO_1_Type
    PageNumberVector: IS_1N_Type
    FrameLabelVector: SH_1N_Type
    FramePrimaryAngleVector: DS_1N_Type
    FrameSecondaryAngleVector: DS_1N_Type
    SliceLocationVector: DS_1N_Type
    DisplayWindowLabelVector: SH_1N_Type
    NominalScannedPixelSpacing: DS_N_Type
    DigitizingDeviceTransportDirection: CS_1_Type
    RotationOfScannedFilm: DS_1_Type
    BiopsyTargetSequence: SQType
    TargetUID: UI_1_Type
    LocalizingCursorPosition: FL_N_Type
    CalculatedTargetPosition: FL_N_Type
    TargetLabel: SH_1_Type
    DisplayedZValue: FL_1_Type
    IVUSAcquisition: CS_1_Type
    IVUSPullbackRate: DS_1_Type
    IVUSGatedRate: DS_1_Type
    IVUSPullbackStartFrameNumber: IS_1_Type
    IVUSPullbackStopFrameNumber: IS_1_Type
    LesionNumber: IS_1N_Type
    OutputPower: SH_1N_Type
    TransducerData: LO_1N_Type
    TransducerIdentificationSequence: SQType
    FocusDepth: DS_1_Type
    ProcessingFunction: LO_1_Type
    MechanicalIndex: DS_1_Type
    BoneThermalIndex: DS_1_Type
    CranialThermalIndex: DS_1_Type
    SoftTissueThermalIndex: DS_1_Type
    SoftTissueFocusThermalIndex: DS_1_Type
    SoftTissueSurfaceThermalIndex: DS_1_Type
    DepthOfScanField: IS_1_Type
    PatientPosition: CS_1_Type
    ViewPosition: CS_1_Type
    ProjectionEponymousNameCodeSequence: SQType
    Sensitivity: DS_1_Type
    SequenceOfUltrasoundRegions: SQType
    RegionSpatialFormat: US_1_Type
    RegionDataType: US_1_Type
    RegionFlags: UL_1_Type
    RegionLocationMinX0: UL_1_Type
    RegionLocationMinY0: UL_1_Type
    RegionLocationMaxX1: UL_1_Type
    RegionLocationMaxY1: UL_1_Type
    ReferencePixelX0: SL_1_Type
    ReferencePixelY0: SL_1_Type
    PhysicalUnitsXDirection: US_1_Type
    PhysicalUnitsYDirection: US_1_Type
    ReferencePixelPhysicalValueX: FD_1_Type
    ReferencePixelPhysicalValueY: FD_1_Type
    PhysicalDeltaX: FD_1_Type
    PhysicalDeltaY: FD_1_Type
    TransducerFrequency: UL_1_Type
    TransducerType: CS_1_Type
    PulseRepetitionFrequency: UL_1_Type
    DopplerCorrectionAngle: FD_1_Type
    SteeringAngle: FD_1_Type
    DopplerSampleVolumeXPosition: SL_1_Type
    DopplerSampleVolumeYPosition: SL_1_Type
    TMLinePositionX0: SL_1_Type
    TMLinePositionY0: SL_1_Type
    TMLinePositionX1: SL_1_Type
    TMLinePositionY1: SL_1_Type
    PixelComponentOrganization: US_1_Type
    PixelComponentMask: UL_1_Type
    PixelComponentRangeStart: UL_1_Type
    PixelComponentRangeStop: UL_1_Type
    PixelComponentPhysicalUnits: US_1_Type
    PixelComponentDataType: US_1_Type
    NumberOfTableBreakPoints: UL_1_Type
    TableOfXBreakPoints: UL_1N_Type
    TableOfYBreakPoints: FD_1N_Type
    NumberOfTableEntries: UL_1_Type
    TableOfPixelValues: UL_1N_Type
    TableOfParameterValues: FL_1N_Type
    RWaveTimeVector: FL_1N_Type
    ActiveImageAreaOverlayGroup: US_1_Type
    DetectorConditionsNominalFlag: CS_1_Type
    DetectorTemperature: DS_1_Type
    DetectorType: CS_1_Type
    DetectorConfiguration: CS_1_Type
    DetectorDescription: LT_1_Type
    DetectorMode: LT_1_Type
    DetectorID: SH_1_Type
    DateOfLastDetectorCalibration: DA_1_Type
    TimeOfLastDetectorCalibration: TM_1_Type
    ExposuresOnDetectorSinceLastCalibration: IS_1_Type
    ExposuresOnDetectorSinceManufactured: IS_1_Type
    DetectorTimeSinceLastExposure: DS_1_Type
    DetectorActiveTime: DS_1_Type
    DetectorActivationOffsetFromExposure: DS_1_Type
    DetectorBinning: DS_N_Type
    DetectorElementPhysicalSize: DS_N_Type
    DetectorElementSpacing: DS_N_Type
    DetectorActiveShape: CS_1_Type
    DetectorActiveDimensions: DS_N_Type
    DetectorActiveOrigin: DS_N_Type
    DetectorManufacturerName: LO_1_Type
    DetectorManufacturerModelName: LO_1_Type
    FieldOfViewOrigin: DS_N_Type
    FieldOfViewRotation: DS_1_Type
    FieldOfViewHorizontalFlip: CS_1_Type
    PixelDataAreaOriginRelativeToFOV: FL_N_Type
    PixelDataAreaRotationAngleRelativeToFOV: FL_1_Type
    GridAbsorbingMaterial: LT_1_Type
    GridSpacingMaterial: LT_1_Type
    GridThickness: DS_1_Type
    GridPitch: DS_1_Type
    GridAspectRatio: IS_N_Type
    GridPeriod: DS_1_Type
    GridFocalDistance: DS_1_Type
    FilterMaterial: CS_1N_Type
    FilterThicknessMinimum: DS_1N_Type
    FilterThicknessMaximum: DS_1N_Type
    FilterBeamPathLengthMinimum: FL_1N_Type
    FilterBeamPathLengthMaximum: FL_1N_Type
    ExposureControlMode: CS_1_Type
    ExposureControlModeDescription: LT_1_Type
    ExposureStatus: CS_1_Type
    PhototimerSetting: DS_1_Type
    ExposureTimeInuS: DS_1_Type
    XRayTubeCurrentInuA: DS_1_Type
    ContentQualification: CS_1_Type
    PulseSequenceName: SH_1_Type
    MRImagingModifierSequence: SQType
    EchoPulseSequence: CS_1_Type
    InversionRecovery: CS_1_Type
    FlowCompensation: CS_1_Type
    MultipleSpinEcho: CS_1_Type
    MultiPlanarExcitation: CS_1_Type
    PhaseContrast: CS_1_Type
    TimeOfFlightContrast: CS_1_Type
    Spoiling: CS_1_Type
    SteadyStatePulseSequence: CS_1_Type
    EchoPlanarPulseSequence: CS_1_Type
    TagAngleFirstAxis: FD_1_Type
    MagnetizationTransfer: CS_1_Type
    T2Preparation: CS_1_Type
    BloodSignalNulling: CS_1_Type
    SaturationRecovery: CS_1_Type
    SpectrallySelectedSuppression: CS_1_Type
    SpectrallySelectedExcitation: CS_1_Type
    SpatialPresaturation: CS_1_Type
    Tagging: CS_1_Type
    OversamplingPhase: CS_1_Type
    TagSpacingFirstDimension: FD_1_Type
    GeometryOfKSpaceTraversal: CS_1_Type
    SegmentedKSpaceTraversal: CS_1_Type
    RectilinearPhaseEncodeReordering: CS_1_Type
    TagThickness: FD_1_Type
    PartialFourierDirection: CS_1_Type
    CardiacSynchronizationTechnique: CS_1_Type
    ReceiveCoilManufacturerName: LO_1_Type
    MRReceiveCoilSequence: SQType
    ReceiveCoilType: CS_1_Type
    QuadratureReceiveCoil: CS_1_Type
    MultiCoilDefinitionSequence: SQType
    MultiCoilConfiguration: LO_1_Type
    MultiCoilElementName: SH_1_Type
    MultiCoilElementUsed: CS_1_Type
    MRTransmitCoilSequence: SQType
    TransmitCoilManufacturerName: LO_1_Type
    TransmitCoilType: CS_1_Type
    SpectralWidth: FD_N_Type
    ChemicalShiftReference: FD_N_Type
    VolumeLocalizationTechnique: CS_1_Type
    MRAcquisitionFrequencyEncodingSteps: US_1_Type
    Decoupling: CS_1_Type
    DecoupledNucleus: CS_N_Type
    DecouplingFrequency: FD_N_Type
    DecouplingMethod: CS_1_Type
    DecouplingChemicalShiftReference: FD_N_Type
    KSpaceFiltering: CS_1_Type
    TimeDomainFiltering: CS_N_Type
    NumberOfZeroFills: US_N_Type
    BaselineCorrection: CS_1_Type
    ParallelReductionFactorInPlane: FD_1_Type
    CardiacRRIntervalSpecified: FD_1_Type
    AcquisitionDuration: FD_1_Type
    FrameAcquisitionDateTime: DT_1_Type
    DiffusionDirectionality: CS_1_Type
    DiffusionGradientDirectionSequence: SQType
    ParallelAcquisition: CS_1_Type
    ParallelAcquisitionTechnique: CS_1_Type
    InversionTimes: FD_1N_Type
    MetaboliteMapDescription: ST_1_Type
    PartialFourier: CS_1_Type
    EffectiveEchoTime: FD_1_Type
    MetaboliteMapCodeSequence: SQType
    ChemicalShiftSequence: SQType
    CardiacSignalSource: CS_1_Type
    DiffusionBValue: FD_1_Type
    DiffusionGradientOrientation: FD_N_Type
    VelocityEncodingDirection: FD_N_Type
    VelocityEncodingMinimumValue: FD_1_Type
    VelocityEncodingAcquisitionSequence: SQType
    NumberOfKSpaceTrajectories: US_1_Type
    CoverageOfKSpace: CS_1_Type
    SpectroscopyAcquisitionPhaseRows: UL_1_Type
    TransmitterFrequency: FD_N_Type
    ResonantNucleus: CS_N_Type
    FrequencyCorrection: CS_1_Type
    MRSpectroscopyFOVGeometrySequence: SQType
    SlabThickness: FD_1_Type
    SlabOrientation: FD_N_Type
    MidSlabPosition: FD_N_Type
    MRSpatialSaturationSequence: SQType
    MRTimingAndRelatedParametersSequence: SQType
    MREchoSequence: SQType
    MRModifierSequence: SQType
    MRDiffusionSequence: SQType
    CardiacSynchronizationSequence: SQType
    MRAveragesSequence: SQType
    MRFOVGeometrySequence: SQType
    VolumeLocalizationSequence: SQType
    SpectroscopyAcquisitionDataColumns: UL_1_Type
    DiffusionAnisotropyType: CS_1_Type
    FrameReferenceDateTime: DT_1_Type
    MRMetaboliteMapSequence: SQType
    ParallelReductionFactorOutOfPlane: FD_1_Type
    SpectroscopyAcquisitionOutOfPlanePhaseSteps: UL_1_Type
    ParallelReductionFactorSecondInPlane: FD_1_Type
    CardiacBeatRejectionTechnique: CS_1_Type
    RespiratoryMotionCompensationTechnique: CS_1_Type
    RespiratorySignalSource: CS_1_Type
    BulkMotionCompensationTechnique: CS_1_Type
    BulkMotionSignalSource: CS_1_Type
    ApplicableSafetyStandardAgency: CS_1_Type
    ApplicableSafetyStandardDescription: LO_1_Type
    OperatingModeSequence: SQType
    OperatingModeType: CS_1_Type
    OperatingMode: CS_1_Type
    SpecificAbsorptionRateDefinition: CS_1_Type
    GradientOutputType: CS_1_Type
    SpecificAbsorptionRateValue: FD_1_Type
    GradientOutput: FD_1_Type
    FlowCompensationDirection: CS_1_Type
    TaggingDelay: FD_1_Type
    RespiratoryMotionCompensationTechniqueDescription: ST_1_Type
    RespiratorySignalSourceID: SH_1_Type
    MRVelocityEncodingSequence: SQType
    FirstOrderPhaseCorrection: CS_1_Type
    WaterReferencedPhaseCorrection: CS_1_Type
    MRSpectroscopyAcquisitionType: CS_1_Type
    RespiratoryCyclePosition: CS_1_Type
    VelocityEncodingMaximumValue: FD_1_Type
    TagSpacingSecondDimension: FD_1_Type
    TagAngleSecondAxis: SS_1_Type
    FrameAcquisitionDuration: FD_1_Type
    MRImageFrameTypeSequence: SQType
    MRSpectroscopyFrameTypeSequence: SQType
    MRAcquisitionPhaseEncodingStepsInPlane: US_1_Type
    MRAcquisitionPhaseEncodingStepsOutOfPlane: US_1_Type
    SpectroscopyAcquisitionPhaseColumns: UL_1_Type
    CardiacCyclePosition: CS_1_Type
    SpecificAbsorptionRateSequence: SQType
    RFEchoTrainLength: US_1_Type
    GradientEchoTrainLength: US_1_Type
    ArterialSpinLabelingContrast: CS_1_Type
    MRArterialSpinLabelingSequence: SQType
    ASLTechniqueDescription: LO_1_Type
    ASLSlabNumber: US_1_Type
    ASLSlabThickness: FD_1_Type
    ASLSlabOrientation: FD_N_Type
    ASLMidSlabPosition: FD_N_Type
    ASLContext: CS_1_Type
    ASLPulseTrainDuration: UL_1_Type
    ASLCrusherFlag: CS_1_Type
    ASLCrusherFlowLimit: FD_1_Type
    ASLCrusherDescription: LO_1_Type
    ASLBolusCutoffFlag: CS_1_Type
    ASLBolusCutoffTimingSequence: SQType
    ASLBolusCutoffTechnique: LO_1_Type
    ASLBolusCutoffDelayTime: UL_1_Type
    ASLSlabSequence: SQType
    ChemicalShiftMinimumIntegrationLimitInppm: FD_1_Type
    ChemicalShiftMaximumIntegrationLimitInppm: FD_1_Type
    WaterReferenceAcquisition: CS_1_Type
    EchoPeakPosition: IS_1_Type
    CTAcquisitionTypeSequence: SQType
    AcquisitionType: CS_1_Type
    TubeAngle: FD_1_Type
    CTAcquisitionDetailsSequence: SQType
    RevolutionTime: FD_1_Type
    SingleCollimationWidth: FD_1_Type
    TotalCollimationWidth: FD_1_Type
    CTTableDynamicsSequence: SQType
    TableSpeed: FD_1_Type
    TableFeedPerRotation: FD_1_Type
    SpiralPitchFactor: FD_1_Type
    CTGeometrySequence: SQType
    DataCollectionCenterPatient: FD_N_Type
    CTReconstructionSequence: SQType
    ReconstructionAlgorithm: CS_1_Type
    ConvolutionKernelGroup: CS_1_Type
    ReconstructionFieldOfView: FD_N_Type
    ReconstructionTargetCenterPatient: FD_N_Type
    ReconstructionAngle: FD_1_Type
    ImageFilter: SH_1_Type
    CTExposureSequence: SQType
    ReconstructionPixelSpacing: FD_N_Type
    ExposureModulationType: CS_1N_Type
    CTXRayDetailsSequence: SQType
    CTPositionSequence: SQType
    TablePosition: FD_1_Type
    ExposureTimeInms: FD_1_Type
    CTImageFrameTypeSequence: SQType
    XRayTubeCurrentInmA: FD_1_Type
    ExposureInmAs: FD_1_Type
    ConstantVolumeFlag: CS_1_Type
    FluoroscopyFlag: CS_1_Type
    DistanceSourceToDataCollectionCenter: FD_1_Type
    ContrastBolusAgentNumber: US_1_Type
    ContrastBolusIngredientCodeSequence: SQType
    ContrastAdministrationProfileSequence: SQType
    ContrastBolusUsageSequence: SQType
    ContrastBolusAgentAdministered: CS_1_Type
    ContrastBolusAgentDetected: CS_1_Type
    ContrastBolusAgentPhase: CS_1_Type
    CTDIvol: FD_1_Type
    CTDIPhantomTypeCodeSequence: SQType
    CalciumScoringMassFactorPatient: FL_1_Type
    CalciumScoringMassFactorDevice: FL_N_Type
    EnergyWeightingFactor: FL_1_Type
    CTAdditionalXRaySourceSequence: SQType
    MultienergyCTAcquisition: CS_1_Type
    MultienergyCTAcquisitionSequence: SQType
    MultienergyCTProcessingSequence: SQType
    MultienergyCTCharacteristicsSequence: SQType
    MultienergyCTXRaySourceSequence: SQType
    XRaySourceIndex: US_1_Type
    XRaySourceID: UC_1_Type
    MultienergySourceTechnique: CS_1_Type
    SourceStartDateTime: DT_1_Type
    SourceEndDateTime: DT_1_Type
    SwitchingPhaseNumber: US_1_Type
    SwitchingPhaseNominalDuration: DS_1_Type
    SwitchingPhaseTransitionDuration: DS_1_Type
    EffectiveBinEnergy: DS_1_Type
    MultienergyCTXRayDetectorSequence: SQType
    XRayDetectorIndex: US_1_Type
    XRayDetectorID: UC_1_Type
    MultienergyDetectorType: CS_1_Type
    XRayDetectorLabel: ST_1_Type
    NominalMaxEnergy: DS_1_Type
    NominalMinEnergy: DS_1_Type
    ReferencedXRayDetectorIndex: US_1N_Type
    ReferencedXRaySourceIndex: US_1N_Type
    ReferencedPathIndex: US_1N_Type
    MultienergyCTPathSequence: SQType
    MultienergyCTPathIndex: US_1_Type
    MultienergyAcquisitionDescription: UT_1_Type
    MonoenergeticEnergyEquivalent: FD_1_Type
    MaterialCodeSequence: SQType
    DecompositionMethod: CS_1_Type
    DecompositionDescription: UT_1_Type
    DecompositionAlgorithmIdentificationSequence: SQType
    DecompositionMaterialSequence: SQType
    MaterialAttenuationSequence: SQType
    PhotonEnergy: DS_1_Type
    XRayMassAttenuationCoefficient: DS_1_Type
    ProjectionPixelCalibrationSequence: SQType
    DistanceSourceToIsocenter: FL_1_Type
    DistanceObjectToTableTop: FL_1_Type
    ObjectPixelSpacingInCenterOfBeam: FL_N_Type
    PositionerPositionSequence: SQType
    TablePositionSequence: SQType
    CollimatorShapeSequence: SQType
    PlanesInAcquisition: CS_1_Type
    XAXRFFrameCharacteristicsSequence: SQType
    FrameAcquisitionSequence: SQType
    XRayReceptorType: CS_1_Type
    AcquisitionProtocolName: LO_1_Type
    AcquisitionProtocolDescription: LT_1_Type
    ContrastBolusIngredientOpaque: CS_1_Type
    DistanceReceptorPlaneToDetectorHousing: FL_1_Type
    IntensifierActiveShape: CS_1_Type
    IntensifierActiveDimensions: FL_N_Type
    PhysicalDetectorSize: FL_N_Type
    PositionOfIsocenterProjection: FL_N_Type
    FieldOfViewSequence: SQType
    FieldOfViewDescription: LO_1_Type
    ExposureControlSensingRegionsSequence: SQType
    ExposureControlSensingRegionShape: CS_1_Type
    ExposureControlSensingRegionLeftVerticalEdge: SS_1_Type
    ExposureControlSensingRegionRightVerticalEdge: SS_1_Type
    ExposureControlSensingRegionUpperHorizontalEdge: SS_1_Type
    ExposureControlSensingRegionLowerHorizontalEdge: SS_1_Type
    CenterOfCircularExposureControlSensingRegion: SS_N_Type
    RadiusOfCircularExposureControlSensingRegion: US_1_Type
    VerticesOfThePolygonalExposureControlSensingRegion: SS_N_Type
    ColumnAngulationPatient: FL_1_Type
    BeamAngle: FL_1_Type
    FrameDetectorParametersSequence: SQType
    CalculatedAnatomyThickness: FL_1_Type
    CalibrationSequence: SQType
    ObjectThicknessSequence: SQType
    PlaneIdentification: CS_1_Type
    FieldOfViewDimensionsInFloat: FL_N_Type
    IsocenterReferenceSystemSequence: SQType
    PositionerIsocenterPrimaryAngle: FL_1_Type
    PositionerIsocenterSecondaryAngle: FL_1_Type
    PositionerIsocenterDetectorRotationAngle: FL_1_Type
    TableXPositionToIsocenter: FL_1_Type
    TableYPositionToIsocenter: FL_1_Type
    TableZPositionToIsocenter: FL_1_Type
    TableHorizontalRotationAngle: FL_1_Type
    TableHeadTiltAngle: FL_1_Type
    TableCradleTiltAngle: FL_1_Type
    FrameDisplayShutterSequence: SQType
    AcquiredImageAreaDoseProduct: FL_1_Type
    CArmPositionerTabletopRelationship: CS_1_Type
    XRayGeometrySequence: SQType
    IrradiationEventIdentificationSequence: SQType
    XRay3DFrameTypeSequence: SQType
    ContributingSourcesSequence: SQType
    XRay3DAcquisitionSequence: SQType
    PrimaryPositionerScanArc: FL_1_Type
    SecondaryPositionerScanArc: FL_1_Type
    PrimaryPositionerScanStartAngle: FL_1_Type
    SecondaryPositionerScanStartAngle: FL_1_Type
    PrimaryPositionerIncrement: FL_1_Type
    SecondaryPositionerIncrement: FL_1_Type
    StartAcquisitionDateTime: DT_1_Type
    EndAcquisitionDateTime: DT_1_Type
    PrimaryPositionerIncrementSign: SS_1_Type
    SecondaryPositionerIncrementSign: SS_1_Type
    ApplicationName: LO_1_Type
    ApplicationVersion: LO_1_Type
    ApplicationManufacturer: LO_1_Type
    AlgorithmType: CS_1_Type
    AlgorithmDescription: LO_1_Type
    XRay3DReconstructionSequence: SQType
    ReconstructionDescription: LO_1_Type
    PerProjectionAcquisitionSequence: SQType
    DetectorPositionSequence: SQType
    XRayAcquisitionDoseSequence: SQType
    XRaySourceIsocenterPrimaryAngle: FD_1_Type
    XRaySourceIsocenterSecondaryAngle: FD_1_Type
    BreastSupportIsocenterPrimaryAngle: FD_1_Type
    BreastSupportIsocenterSecondaryAngle: FD_1_Type
    BreastSupportXPositionToIsocenter: FD_1_Type
    BreastSupportYPositionToIsocenter: FD_1_Type
    BreastSupportZPositionToIsocenter: FD_1_Type
    DetectorIsocenterPrimaryAngle: FD_1_Type
    DetectorIsocenterSecondaryAngle: FD_1_Type
    DetectorXPositionToIsocenter: FD_1_Type
    DetectorYPositionToIsocenter: FD_1_Type
    DetectorZPositionToIsocenter: FD_1_Type
    XRayGridSequence: SQType
    XRayFilterSequence: SQType
    DetectorActiveAreaTLHCPosition: FD_N_Type
    DetectorActiveAreaOrientation: FD_N_Type
    PositionerPrimaryAngleDirection: CS_1_Type
    DiffusionBMatrixSequence: SQType
    DiffusionBValueXX: FD_1_Type
    DiffusionBValueXY: FD_1_Type
    DiffusionBValueXZ: FD_1_Type
    DiffusionBValueYY: FD_1_Type
    DiffusionBValueYZ: FD_1_Type
    DiffusionBValueZZ: FD_1_Type
    FunctionalMRSequence: SQType
    FunctionalSettlingPhaseFramesPresent: CS_1_Type
    FunctionalSyncPulse: DT_1_Type
    SettlingPhaseFrame: CS_1_Type
    DecayCorrectionDateTime: DT_1_Type
    StartDensityThreshold: FD_1_Type
    StartRelativeDensityDifferenceThreshold: FD_1_Type
    StartCardiacTriggerCountThreshold: FD_1_Type
    StartRespiratoryTriggerCountThreshold: FD_1_Type
    TerminationCountsThreshold: FD_1_Type
    TerminationDensityThreshold: FD_1_Type
    TerminationRelativeDensityThreshold: FD_1_Type
    TerminationTimeThreshold: FD_1_Type
    TerminationCardiacTriggerCountThreshold: FD_1_Type
    TerminationRespiratoryTriggerCountThreshold: FD_1_Type
    DetectorGeometry: CS_1_Type
    TransverseDetectorSeparation: FD_1_Type
    AxialDetectorDimension: FD_1_Type
    RadiopharmaceuticalAgentNumber: US_1_Type
    PETFrameAcquisitionSequence: SQType
    PETDetectorMotionDetailsSequence: SQType
    PETTableDynamicsSequence: SQType
    PETPositionSequence: SQType
    PETFrameCorrectionFactorsSequence: SQType
    RadiopharmaceuticalUsageSequence: SQType
    AttenuationCorrectionSource: CS_1_Type
    NumberOfIterations: US_1_Type
    NumberOfSubsets: US_1_Type
    PETReconstructionSequence: SQType
    PETFrameTypeSequence: SQType
    TimeOfFlightInformationUsed: CS_1_Type
    ReconstructionType: CS_1_Type
    DecayCorrected: CS_1_Type
    AttenuationCorrected: CS_1_Type
    ScatterCorrected: CS_1_Type
    DeadTimeCorrected: CS_1_Type
    GantryMotionCorrected: CS_1_Type
    PatientMotionCorrected: CS_1_Type
    CountLossNormalizationCorrected: CS_1_Type
    RandomsCorrected: CS_1_Type
    NonUniformRadialSamplingCorrected: CS_1_Type
    SensitivityCalibrated: CS_1_Type
    DetectorNormalizationCorrection: CS_1_Type
    IterativeReconstructionMethod: CS_1_Type
    AttenuationCorrectionTemporalRelationship: CS_1_Type
    PatientPhysiologicalStateSequence: SQType
    PatientPhysiologicalStateCodeSequence: SQType
    DepthsOfFocus: FD_1N_Type
    ExcludedIntervalsSequence: SQType
    ExclusionStartDateTime: DT_1_Type
    ExclusionDuration: FD_1_Type
    USImageDescriptionSequence: SQType
    ImageDataTypeSequence: SQType
    DataType: CS_1_Type
    TransducerScanPatternCodeSequence: SQType
    AliasedDataType: CS_1_Type
    PositionMeasuringDeviceUsed: CS_1_Type
    TransducerGeometryCodeSequence: SQType
    TransducerBeamSteeringCodeSequence: SQType
    TransducerApplicationCodeSequence: SQType
    ZeroVelocityPixelValue: US_SS_Type
    PhotoacousticExcitationCharacteristicsSequence: SQType
    ExcitationSpectralWidth: FD_1_Type
    ExcitationEnergy: FD_1_Type
    ExcitationPulseDuration: FD_1_Type
    ExcitationWavelengthSequence: SQType
    ExcitationWavelength: FD_1_Type
    IlluminationTranslationFlag: CS_1_Type
    AcousticCouplingMediumFlag: CS_1_Type
    AcousticCouplingMediumCodeSequence: SQType
    AcousticCouplingMediumTemperature: FD_1_Type
    TransducerResponseSequence: SQType
    CenterFrequency: FD_1_Type
    FractionalBandwidth: FD_1_Type
    LowerCutoffFrequency: FD_1_Type
    UpperCutoffFrequency: FD_1_Type
    TransducerTechnologySequence: SQType
    SoundSpeedCorrectionMechanismCodeSequence: SQType
    ObjectSoundSpeed: FD_1_Type
    AcousticCouplingMediumSoundSpeed: FD_1_Type
    PhotoacousticImageFrameTypeSequence: SQType
    ImageDataTypeCodeSequence: SQType
    ReferenceLocationLabel: LO_1_Type
    ReferenceLocationDescription: UT_1_Type
    ReferenceBasisCodeSequence: SQType
    ReferenceGeometryCodeSequence: SQType
    OffsetDistance: DS_1_Type
    OffsetDirection: CS_1_Type
    PotentialScheduledProtocolCodeSequence: SQType
    PotentialRequestedProcedureCodeSequence: SQType
    PotentialReasonsForProcedure: UC_1N_Type
    PotentialReasonsForProcedureCodeSequence: SQType
    PotentialDiagnosticTasks: UC_1N_Type
    ContraindicationsCodeSequence: SQType
    ReferencedDefinedProtocolSequence: SQType
    ReferencedPerformedProtocolSequence: SQType
    PredecessorProtocolSequence: SQType
    ProtocolPlanningInformation: UT_1_Type
    ProtocolDesignRationale: UT_1_Type
    PatientSpecificationSequence: SQType
    ModelSpecificationSequence: SQType
    ParametersSpecificationSequence: SQType
    InstructionSequence: SQType
    InstructionIndex: US_1_Type
    InstructionText: LO_1_Type
    InstructionDescription: UT_1_Type
    InstructionPerformedFlag: CS_1_Type
    InstructionPerformedDateTime: DT_1_Type
    InstructionPerformanceComment: UT_1_Type
    PatientPositioningInstructionSequence: SQType
    PositioningMethodCodeSequence: SQType
    PositioningLandmarkSequence: SQType
    TargetFrameOfReferenceUID: UI_1_Type
    AcquisitionProtocolElementSpecificationSequence: SQType
    AcquisitionProtocolElementSequence: SQType
    ProtocolElementNumber: US_1_Type
    ProtocolElementName: LO_1_Type
    ProtocolElementCharacteristicsSummary: UT_1_Type
    ProtocolElementPurpose: UT_1_Type
    AcquisitionMotion: CS_1_Type
    AcquisitionStartLocationSequence: SQType
    AcquisitionEndLocationSequence: SQType
    ReconstructionProtocolElementSpecificationSequence: SQType
    ReconstructionProtocolElementSequence: SQType
    StorageProtocolElementSpecificationSequence: SQType
    StorageProtocolElementSequence: SQType
    RequestedSeriesDescription: LO_1_Type
    SourceAcquisitionProtocolElementNumber: US_1N_Type
    SourceAcquisitionBeamNumber: US_1N_Type
    SourceReconstructionProtocolElementNumber: US_1N_Type
    ReconstructionStartLocationSequence: SQType
    ReconstructionEndLocationSequence: SQType
    ReconstructionAlgorithmSequence: SQType
    ReconstructionTargetCenterLocationSequence: SQType
    ImageFilterDescription: UT_1_Type
    CTDIvolNotificationTrigger: FD_1_Type
    DLPNotificationTrigger: FD_1_Type
    AutoKVPSelectionType: CS_1_Type
    AutoKVPUpperBound: FD_1_Type
    AutoKVPLowerBound: FD_1_Type
    ProtocolDefinedPatientPosition: CS_1_Type
    ContributingEquipmentSequence: SQType
    ContributionDateTime: DT_1_Type
    ContributionDescription: ST_1_Type
    StudyInstanceUID: UI_1_Type
    SeriesInstanceUID: UI_1_Type
    StudyID: SH_1_Type
    SeriesNumber: IS_1_Type
    AcquisitionNumber: IS_1_Type
    InstanceNumber: IS_1_Type
    ItemNumber: IS_1_Type
    PatientOrientation: CS_N_Type
    PyramidLabel: LO_1_Type
    ImagePositionPatient: DS_N_Type
    ImageOrientationPatient: DS_N_Type
    FrameOfReferenceUID: UI_1_Type
    Laterality: CS_1_Type
    ImageLaterality: CS_1_Type
    TemporalPositionIdentifier: IS_1_Type
    NumberOfTemporalPositions: IS_1_Type
    TemporalResolution: DS_1_Type
    SynchronizationFrameOfReferenceUID: UI_1_Type
    SOPInstanceUIDOfConcatenationSource: UI_1_Type
    ImagesInAcquisition: IS_1_Type
    TargetPositionReferenceIndicator: LO_1_Type
    PositionReferenceIndicator: LO_1_Type
    SliceLocation: DS_1_Type
    NumberOfPatientRelatedStudies: IS_1_Type
    NumberOfPatientRelatedSeries: IS_1_Type
    NumberOfPatientRelatedInstances: IS_1_Type
    NumberOfStudyRelatedSeries: IS_1_Type
    NumberOfStudyRelatedInstances: IS_1_Type
    NumberOfSeriesRelatedInstances: IS_1_Type
    ImageComments: LT_1_Type
    StackID: SH_1_Type
    InStackPositionNumber: UL_1_Type
    FrameAnatomySequence: SQType
    FrameLaterality: CS_1_Type
    FrameContentSequence: SQType
    PlanePositionSequence: SQType
    PlaneOrientationSequence: SQType
    TemporalPositionIndex: UL_1_Type
    NominalCardiacTriggerDelayTime: FD_1_Type
    NominalCardiacTriggerTimePriorToRPeak: FL_1_Type
    ActualCardiacTriggerTimePriorToRPeak: FL_1_Type
    FrameAcquisitionNumber: US_1_Type
    DimensionIndexValues: UL_1N_Type
    FrameComments: LT_1_Type
    ConcatenationUID: UI_1_Type
    InConcatenationNumber: US_1_Type
    InConcatenationTotalNumber: US_1_Type
    DimensionOrganizationUID: UI_1_Type
    DimensionIndexPointer: AT_1_Type
    FunctionalGroupPointer: AT_1_Type
    UnassignedSharedConvertedAttributesSequence: SQType
    UnassignedPerFrameConvertedAttributesSequence: SQType
    ConversionSourceAttributesSequence: SQType
    DimensionIndexPrivateCreator: LO_1_Type
    DimensionOrganizationSequence: SQType
    DimensionIndexSequence: SQType
    ConcatenationFrameOffsetNumber: UL_1_Type
    FunctionalGroupPrivateCreator: LO_1_Type
    NominalPercentageOfCardiacPhase: FL_1_Type
    NominalPercentageOfRespiratoryPhase: FL_1_Type
    StartingRespiratoryAmplitude: FL_1_Type
    StartingRespiratoryPhase: CS_1_Type
    EndingRespiratoryAmplitude: FL_1_Type
    EndingRespiratoryPhase: CS_1_Type
    RespiratoryTriggerType: CS_1_Type
    RRIntervalTimeNominal: FD_1_Type
    ActualCardiacTriggerDelayTime: FD_1_Type
    RespiratorySynchronizationSequence: SQType
    RespiratoryIntervalTime: FD_1_Type
    NominalRespiratoryTriggerDelayTime: FD_1_Type
    RespiratoryTriggerDelayThreshold: FD_1_Type
    ActualRespiratoryTriggerDelayTime: FD_1_Type
    ImagePositionVolume: FD_N_Type
    ImageOrientationVolume: FD_N_Type
    UltrasoundAcquisitionGeometry: CS_1_Type
    ApexPosition: FD_N_Type
    VolumeToTransducerMappingMatrix: FD_N_Type
    VolumeToTableMappingMatrix: FD_N_Type
    VolumeToTransducerRelationship: CS_1_Type
    PatientFrameOfReferenceSource: CS_1_Type
    TemporalPositionTimeOffset: FD_1_Type
    PlanePositionVolumeSequence: SQType
    PlaneOrientationVolumeSequence: SQType
    TemporalPositionSequence: SQType
    DimensionOrganizationType: CS_1_Type
    VolumeFrameOfReferenceUID: UI_1_Type
    TableFrameOfReferenceUID: UI_1_Type
    DimensionDescriptionLabel: LO_1_Type
    PatientOrientationInFrameSequence: SQType
    FrameLabel: LO_1_Type
    AcquisitionIndex: US_1N_Type
    ContributingSOPInstancesReferenceSequence: SQType
    ReconstructionIndex: US_1_Type
    LightPathFilterPassThroughWavelength: US_1_Type
    LightPathFilterPassBand: US_N_Type
    ImagePathFilterPassThroughWavelength: US_1_Type
    ImagePathFilterPassBand: US_N_Type
    PatientEyeMovementCommanded: CS_1_Type
    PatientEyeMovementCommandCodeSequence: SQType
    SphericalLensPower: FL_1_Type
    CylinderLensPower: FL_1_Type
    CylinderAxis: FL_1_Type
    EmmetropicMagnification: FL_1_Type
    IntraOcularPressure: FL_1_Type
    HorizontalFieldOfView: FL_1_Type
    PupilDilated: CS_1_Type
    DegreeOfDilation: FL_1_Type
    VertexDistance: FD_1_Type
    StereoBaselineAngle: FL_1_Type
    StereoBaselineDisplacement: FL_1_Type
    StereoHorizontalPixelOffset: FL_1_Type
    StereoVerticalPixelOffset: FL_1_Type
    StereoRotation: FL_1_Type
    AcquisitionDeviceTypeCodeSequence: SQType
    IlluminationTypeCodeSequence: SQType
    LightPathFilterTypeStackCodeSequence: SQType
    ImagePathFilterTypeStackCodeSequence: SQType
    LensesCodeSequence: SQType
    ChannelDescriptionCodeSequence: SQType
    RefractiveStateSequence: SQType
    MydriaticAgentCodeSequence: SQType
    RelativeImagePositionCodeSequence: SQType
    CameraAngleOfView: FL_1_Type
    StereoPairsSequence: SQType
    LeftImageSequence: SQType
    RightImageSequence: SQType
    StereoPairsPresent: CS_1_Type
    AxialLengthOfTheEye: FL_1_Type
    OphthalmicFrameLocationSequence: SQType
    ReferenceCoordinates: FL_N_Type
    DepthSpatialResolution: FL_1_Type
    MaximumDepthDistortion: FL_1_Type
    AlongScanSpatialResolution: FL_1_Type
    MaximumAlongScanDistortion: FL_1_Type
    OphthalmicImageOrientation: CS_1_Type
    DepthOfTransverseImage: FL_1_Type
    MydriaticAgentConcentrationUnitsSequence: SQType
    AcrossScanSpatialResolution: FL_1_Type
    MaximumAcrossScanDistortion: FL_1_Type
    MydriaticAgentConcentration: DS_1_Type
    IlluminationWaveLength: FL_1_Type
    IlluminationPower: FL_1_Type
    IlluminationBandwidth: FL_1_Type
    MydriaticAgentSequence: SQType
    OphthalmicAxialMeasurementsRightEyeSequence: SQType
    OphthalmicAxialMeasurementsLeftEyeSequence: SQType
    OphthalmicAxialMeasurementsDeviceType: CS_1_Type
    OphthalmicAxialLengthMeasurementsType: CS_1_Type
    OphthalmicAxialLengthSequence: SQType
    OphthalmicAxialLength: FL_1_Type
    LensStatusCodeSequence: SQType
    VitreousStatusCodeSequence: SQType
    IOLFormulaCodeSequence: SQType
    IOLFormulaDetail: LO_1_Type
    KeratometerIndex: FL_1_Type
    SourceOfOphthalmicAxialLengthCodeSequence: SQType
    SourceOfCornealSizeDataCodeSequence: SQType
    TargetRefraction: FL_1_Type
    RefractiveProcedureOccurred: CS_1_Type
    RefractiveSurgeryTypeCodeSequence: SQType
    OphthalmicUltrasoundMethodCodeSequence: SQType
    SurgicallyInducedAstigmatismSequence: SQType
    TypeOfOpticalCorrection: CS_1_Type
    ToricIOLPowerSequence: SQType
    PredictedToricErrorSequence: SQType
    PreSelectedForImplantation: CS_1_Type
    ToricIOLPowerForExactEmmetropiaSequence: SQType
    ToricIOLPowerForExactTargetRefractionSequence: SQType
    OphthalmicAxialLengthMeasurementsSequence: SQType
    IOLPower: FL_1_Type
    PredictedRefractiveError: FL_1_Type
    OphthalmicAxialLengthVelocity: FL_1_Type
    LensStatusDescription: LO_1_Type
    VitreousStatusDescription: LO_1_Type
    IOLPowerSequence: SQType
    LensConstantSequence: SQType
    IOLManufacturer: LO_1_Type
    ImplantName: LO_1_Type
    KeratometryMeasurementTypeCodeSequence: SQType
    ImplantPartNumber: LO_1_Type
    ReferencedOphthalmicAxialMeasurementsSequence: SQType
    OphthalmicAxialLengthMeasurementsSegmentNameCodeSequence: SQType
    RefractiveErrorBeforeRefractiveSurgeryCodeSequence: SQType
    IOLPowerForExactEmmetropia: FL_1_Type
    IOLPowerForExactTargetRefraction: FL_1_Type
    AnteriorChamberDepthDefinitionCodeSequence: SQType
    LensThicknessSequence: SQType
    AnteriorChamberDepthSequence: SQType
    CalculationCommentSequence: SQType
    CalculationCommentType: CS_1_Type
    CalculationComment: LT_1_Type
    LensThickness: FL_1_Type
    AnteriorChamberDepth: FL_1_Type
    SourceOfLensThicknessDataCodeSequence: SQType
    SourceOfAnteriorChamberDepthDataCodeSequence: SQType
    SourceOfRefractiveMeasurementsSequence: SQType
    SourceOfRefractiveMeasurementsCodeSequence: SQType
    OphthalmicAxialLengthMeasurementModified: CS_1_Type
    OphthalmicAxialLengthDataSourceCodeSequence: SQType
    SignalToNoiseRatio: FL_1_Type
    OphthalmicAxialLengthDataSourceDescription: LO_1_Type
    OphthalmicAxialLengthMeasurementsTotalLengthSequence: SQType
    OphthalmicAxialLengthMeasurementsSegmentalLengthSequence: SQType
    OphthalmicAxialLengthMeasurementsLengthSummationSequence: SQType
    UltrasoundOphthalmicAxialLengthMeasurementsSequence: SQType
    OpticalOphthalmicAxialLengthMeasurementsSequence: SQType
    UltrasoundSelectedOphthalmicAxialLengthSequence: SQType
    OphthalmicAxialLengthSelectionMethodCodeSequence: SQType
    OpticalSelectedOphthalmicAxialLengthSequence: SQType
    SelectedSegmentalOphthalmicAxialLengthSequence: SQType
    SelectedTotalOphthalmicAxialLengthSequence: SQType
    OphthalmicAxialLengthQualityMetricSequence: SQType
    IntraocularLensCalculationsRightEyeSequence: SQType
    IntraocularLensCalculationsLeftEyeSequence: SQType
    ReferencedOphthalmicAxialLengthMeasurementQCImageSequence: SQType
    OphthalmicMappingDeviceType: CS_1_Type
    AcquisitionMethodCodeSequence: SQType
    AcquisitionMethodAlgorithmSequence: SQType
    OphthalmicThicknessMapTypeCodeSequence: SQType
    OphthalmicThicknessMappingNormalsSequence: SQType
    RetinalThicknessDefinitionCodeSequence: SQType
    PixelValueMappingToCodedConceptSequence: SQType
    MappedPixelValue: US_SS_Type
    PixelValueMappingExplanation: LO_1_Type
    OphthalmicThicknessMapQualityThresholdSequence: SQType
    OphthalmicThicknessMapThresholdQualityRating: FL_1_Type
    AnatomicStructureReferencePoint: FL_N_Type
    RegistrationToLocalizerSequence: SQType
    RegisteredLocalizerUnits: CS_1_Type
    RegisteredLocalizerTopLeftHandCorner: FL_N_Type
    RegisteredLocalizerBottomRightHandCorner: FL_N_Type
    OphthalmicThicknessMapQualityRatingSequence: SQType
    RelevantOPTAttributesSequence: SQType
    TransformationMethodCodeSequence: SQType
    TransformationAlgorithmSequence: SQType
    OphthalmicAxialLengthMethod: CS_1_Type
    OphthalmicFOV: FL_1_Type
    TwoDimensionalToThreeDimensionalMapSequence: SQType
    WideFieldOphthalmicPhotographyQualityRatingSequence: SQType
    WideFieldOphthalmicPhotographyQualityThresholdSequence: SQType
    WideFieldOphthalmicPhotographyThresholdQualityRating: FL_1_Type
    XCoordinatesCenterPixelViewAngle: FL_1_Type
    YCoordinatesCenterPixelViewAngle: FL_1_Type
    NumberOfMapPoints: UL_1_Type
    TwoDimensionalToThreeDimensionalMapData: OF_1_Type
    DerivationAlgorithmSequence: SQType
    OphthalmicImageTypeCodeSequence: SQType
    OphthalmicImageTypeDescription: LO_1_Type
    ScanPatternTypeCodeSequence: SQType
    ReferencedSurfaceMeshIdentificationSequence: SQType
    OphthalmicVolumetricPropertiesFlag: CS_1_Type
    OphthalmicAnatomicReferencePointXCoordinate: FL_1_Type
    OphthalmicAnatomicReferencePointYCoordinate: FL_1_Type
    OphthalmicEnFaceImageQualityRatingSequence: SQType
    QualityThreshold: DS_1_Type
    OCTBscanAnalysisAcquisitionParametersSequence: SQType
    NumberOfBscansPerFrame: UL_1_Type
    BscanSlabThickness: FL_1_Type
    DistanceBetweenBscanSlabs: FL_1_Type
    BscanCycleTime: FL_1_Type
    BscanCycleTimeVector: FL_1N_Type
    AscanRate: FL_1_Type
    BscanRate: FL_1_Type
    SurfaceMeshZPixelOffset: UL_1_Type
    VisualFieldHorizontalExtent: FL_1_Type
    VisualFieldVerticalExtent: FL_1_Type
    VisualFieldShape: CS_1_Type
    ScreeningTestModeCodeSequence: SQType
    MaximumStimulusLuminance: FL_1_Type
    BackgroundLuminance: FL_1_Type
    StimulusColorCodeSequence: SQType
    BackgroundIlluminationColorCodeSequence: SQType
    StimulusArea: FL_1_Type
    StimulusPresentationTime: FL_1_Type
    FixationSequence: SQType
    FixationMonitoringCodeSequence: SQType
    VisualFieldCatchTrialSequence: SQType
    FixationCheckedQuantity: US_1_Type
    PatientNotProperlyFixatedQuantity: US_1_Type
    PresentedVisualStimuliDataFlag: CS_1_Type
    NumberOfVisualStimuli: US_1_Type
    ExcessiveFixationLossesDataFlag: CS_1_Type
    ExcessiveFixationLosses: CS_1_Type
    StimuliRetestingQuantity: US_1_Type
    CommentsOnPatientPerformanceOfVisualField: LT_1_Type
    FalseNegativesEstimateFlag: CS_1_Type
    FalseNegativesEstimate: FL_1_Type
    NegativeCatchTrialsQuantity: US_1_Type
    FalseNegativesQuantity: US_1_Type
    ExcessiveFalseNegativesDataFlag: CS_1_Type
    ExcessiveFalseNegatives: CS_1_Type
    FalsePositivesEstimateFlag: CS_1_Type
    FalsePositivesEstimate: FL_1_Type
    CatchTrialsDataFlag: CS_1_Type
    PositiveCatchTrialsQuantity: US_1_Type
    TestPointNormalsDataFlag: CS_1_Type
    TestPointNormalsSequence: SQType
    GlobalDeviationProbabilityNormalsFlag: CS_1_Type
    FalsePositivesQuantity: US_1_Type
    ExcessiveFalsePositivesDataFlag: CS_1_Type
    ExcessiveFalsePositives: CS_1_Type
    VisualFieldTestNormalsFlag: CS_1_Type
    ResultsNormalsSequence: SQType
    AgeCorrectedSensitivityDeviationAlgorithmSequence: SQType
    GlobalDeviationFromNormal: FL_1_Type
    GeneralizedDefectSensitivityDeviationAlgorithmSequence: SQType
    LocalizedDeviationFromNormal: FL_1_Type
    PatientReliabilityIndicator: LO_1_Type
    VisualFieldMeanSensitivity: FL_1_Type
    GlobalDeviationProbability: FL_1_Type
    LocalDeviationProbabilityNormalsFlag: CS_1_Type
    LocalizedDeviationProbability: FL_1_Type
    ShortTermFluctuationCalculated: CS_1_Type
    ShortTermFluctuation: FL_1_Type
    ShortTermFluctuationProbabilityCalculated: CS_1_Type
    ShortTermFluctuationProbability: FL_1_Type
    CorrectedLocalizedDeviationFromNormalCalculated: CS_1_Type
    CorrectedLocalizedDeviationFromNormal: FL_1_Type
    CorrectedLocalizedDeviationFromNormalProbabilityCalculated: CS_1_Type
    CorrectedLocalizedDeviationFromNormalProbability: FL_1_Type
    GlobalDeviationProbabilitySequence: SQType
    LocalizedDeviationProbabilitySequence: SQType
    FovealSensitivityMeasured: CS_1_Type
    FovealSensitivity: FL_1_Type
    VisualFieldTestDuration: FL_1_Type
    VisualFieldTestPointSequence: SQType
    VisualFieldTestPointXCoordinate: FL_1_Type
    VisualFieldTestPointYCoordinate: FL_1_Type
    AgeCorrectedSensitivityDeviationValue: FL_1_Type
    StimulusResults: CS_1_Type
    SensitivityValue: FL_1_Type
    RetestStimulusSeen: CS_1_Type
    RetestSensitivityValue: FL_1_Type
    VisualFieldTestPointNormalsSequence: SQType
    QuantifiedDefect: FL_1_Type
    AgeCorrectedSensitivityDeviationProbabilityValue: FL_1_Type
    GeneralizedDefectCorrectedSensitivityDeviationFlag: CS_1_Type
    GeneralizedDefectCorrectedSensitivityDeviationValue: FL_1_Type
    GeneralizedDefectCorrectedSensitivityDeviationProbabilityValue: FL_1_Type
    MinimumSensitivityValue: FL_1_Type
    BlindSpotLocalized: CS_1_Type
    BlindSpotXCoordinate: FL_1_Type
    BlindSpotYCoordinate: FL_1_Type
    VisualAcuityMeasurementSequence: SQType
    RefractiveParametersUsedOnPatientSequence: SQType
    MeasurementLaterality: CS_1_Type
    OphthalmicPatientClinicalInformationLeftEyeSequence: SQType
    OphthalmicPatientClinicalInformationRightEyeSequence: SQType
    FovealPointNormativeDataFlag: CS_1_Type
    FovealPointProbabilityValue: FL_1_Type
    ScreeningBaselineMeasured: CS_1_Type
    ScreeningBaselineMeasuredSequence: SQType
    ScreeningBaselineType: CS_1_Type
    ScreeningBaselineValue: FL_1_Type
    AlgorithmSource: LO_1_Type
    DataSetName: LO_1_Type
    DataSetVersion: LO_1_Type
    DataSetSource: LO_1_Type
    DataSetDescription: LO_1_Type
    VisualFieldTestReliabilityGlobalIndexSequence: SQType
    VisualFieldGlobalResultsIndexSequence: SQType
    DataObservationSequence: SQType
    IndexNormalsFlag: CS_1_Type
    IndexProbability: FL_1_Type
    IndexProbabilitySequence: SQType
    SamplesPerPixelUsed: US_1_Type
    NumberOfFrames: IS_1_Type
    FrameIncrementPointer: AT_1N_Type
    FrameDimensionPointer: AT_1N_Type
    UltrasoundColorDataPresent: US_1_Type
    PixelSpacing: DS_N_Type
    ZoomFactor: DS_N_Type
    ZoomCenter: DS_N_Type
    PixelAspectRatio: IS_N_Type
    CorrectedImage: CS_1N_Type
    SmallestImagePixelValue: US_SS_Type
    LargestImagePixelValue: US_SS_Type
    SmallestPixelValueInSeries: US_SS_Type
    LargestPixelValueInSeries: US_SS_Type
    PixelPaddingValue: US_SS_Type
    PixelPaddingRangeLimit: US_SS_Type
    FloatPixelPaddingValue: FL_1_Type
    DoubleFloatPixelPaddingValue: FD_1_Type
    FloatPixelPaddingRangeLimit: FL_1_Type
    DoubleFloatPixelPaddingRangeLimit: FD_1_Type
    QualityControlImage: CS_1_Type
    BurnedInAnnotation: CS_1_Type
    RecognizableVisualFeatures: CS_1_Type
    LongitudinalTemporalInformationModified: CS_1_Type
    ReferencedColorPaletteInstanceUID: UI_1_Type
    PixelSpacingCalibrationType: CS_1_Type
    PixelSpacingCalibrationDescription: LO_1_Type
    PixelIntensityRelationship: CS_1_Type
    PixelIntensityRelationshipSign: SS_1_Type
    WindowCenter: DS_1N_Type
    WindowWidth: DS_1N_Type
    RescaleIntercept: DS_1_Type
    RescaleSlope: DS_1_Type
    RescaleType: LO_1_Type
    WindowCenterWidthExplanation: LO_1N_Type
    VOILUTFunction: CS_1_Type
    RecommendedViewingMode: CS_1_Type
    RedPaletteColorLookupTableDescriptor: US_SS_Type
    GreenPaletteColorLookupTableDescriptor: US_SS_Type
    BluePaletteColorLookupTableDescriptor: US_SS_Type
    AlphaPaletteColorLookupTableDescriptor: US_N_Type
    PaletteColorLookupTableUID: UI_1_Type
    RedPaletteColorLookupTableData: OW_1_Type
    GreenPaletteColorLookupTableData: OW_1_Type
    BluePaletteColorLookupTableData: OW_1_Type
    AlphaPaletteColorLookupTableData: OW_1_Type
    SegmentedRedPaletteColorLookupTableData: OW_1_Type
    SegmentedGreenPaletteColorLookupTableData: OW_1_Type
    SegmentedBluePaletteColorLookupTableData: OW_1_Type
    SegmentedAlphaPaletteColorLookupTableData: OW_1_Type
    StoredValueColorRangeSequence: SQType
    MinimumStoredValueMapped: FD_1_Type
    MaximumStoredValueMapped: FD_1_Type
    BreastImplantPresent: CS_1_Type
    PartialView: CS_1_Type
    PartialViewDescription: ST_1_Type
    PartialViewCodeSequence: SQType
    SpatialLocationsPreserved: CS_1_Type
    DataFrameAssignmentSequence: SQType
    DataPathAssignment: CS_1_Type
    BitsMappedToColorLookupTable: US_1_Type
    BlendingLUT1Sequence: SQType
    BlendingLUT1TransferFunction: CS_1_Type
    BlendingWeightConstant: FD_1_Type
    BlendingLookupTableDescriptor: US_N_Type
    BlendingLookupTableData: OW_1_Type
    EnhancedPaletteColorLookupTableSequence: SQType
    BlendingLUT2Sequence: SQType
    BlendingLUT2TransferFunction: CS_1_Type
    DataPathID: CS_1_Type
    RGBLUTTransferFunction: CS_1_Type
    AlphaLUTTransferFunction: CS_1_Type
    ICCProfile: OB_1_Type
    ColorSpace: CS_1_Type
    LossyImageCompression: CS_1_Type
    LossyImageCompressionRatio: DS_1N_Type
    LossyImageCompressionMethod: CS_1N_Type
    ModalityLUTSequence: SQType
    VariableModalityLUTSequence: SQType
    LUTDescriptor: US_SS_Type
    LUTExplanation: LO_1_Type
    ModalityLUTType: LO_1_Type
    LUTData: US_OW_Type
    VOILUTSequence: SQType
    SoftcopyVOILUTSequence: SQType
    RepresentativeFrameNumber: US_1_Type
    FrameNumbersOfInterest: US_1N_Type
    FrameOfInterestDescription: LO_1N_Type
    FrameOfInterestType: CS_1N_Type
    RWavePointer: US_1N_Type
    MaskSubtractionSequence: SQType
    MaskOperation: CS_1_Type
    ApplicableFrameRange: US_N_Type
    MaskFrameNumbers: US_1N_Type
    ContrastFrameAveraging: US_1_Type
    MaskSubPixelShift: FL_N_Type
    TIDOffset: SS_1_Type
    MaskOperationExplanation: ST_1_Type
    EquipmentAdministratorSequence: SQType
    NumberOfDisplaySubsystems: US_1_Type
    CurrentConfigurationID: US_1_Type
    DisplaySubsystemID: US_1_Type
    DisplaySubsystemName: SH_1_Type
    DisplaySubsystemDescription: LO_1_Type
    SystemStatus: CS_1_Type
    SystemStatusComment: LO_1_Type
    TargetLuminanceCharacteristicsSequence: SQType
    LuminanceCharacteristicsID: US_1_Type
    DisplaySubsystemConfigurationSequence: SQType
    ConfigurationID: US_1_Type
    ConfigurationName: SH_1_Type
    ConfigurationDescription: LO_1_Type
    ReferencedTargetLuminanceCharacteristicsID: US_1_Type
    QAResultsSequence: SQType
    DisplaySubsystemQAResultsSequence: SQType
    ConfigurationQAResultsSequence: SQType
    MeasurementEquipmentSequence: SQType
    MeasurementFunctions: CS_1N_Type
    MeasurementEquipmentType: CS_1_Type
    VisualEvaluationResultSequence: SQType
    DisplayCalibrationResultSequence: SQType
    DDLValue: US_1_Type
    CIExyWhitePoint: FL_N_Type
    DisplayFunctionType: CS_1_Type
    GammaValue: FL_1_Type
    NumberOfLuminancePoints: US_1_Type
    LuminanceResponseSequence: SQType
    TargetMinimumLuminance: FL_1_Type
    TargetMaximumLuminance: FL_1_Type
    LuminanceValue: FL_1_Type
    LuminanceResponseDescription: LO_1_Type
    WhitePointFlag: CS_1_Type
    DisplayDeviceTypeCodeSequence: SQType
    DisplaySubsystemSequence: SQType
    LuminanceResultSequence: SQType
    AmbientLightValueSource: CS_1_Type
    MeasuredCharacteristics: CS_1N_Type
    LuminanceUniformityResultSequence: SQType
    VisualEvaluationTestSequence: SQType
    TestResult: CS_1_Type
    TestResultComment: LO_1_Type
    TestImageValidation: CS_1_Type
    TestPatternCodeSequence: SQType
    MeasurementPatternCodeSequence: SQType
    VisualEvaluationMethodCodeSequence: SQType
    PixelDataProviderURL: UR_1_Type
    DataPointRows: UL_1_Type
    DataPointColumns: UL_1_Type
    SignalDomainColumns: CS_1_Type
    DataRepresentation: CS_1_Type
    PixelMeasuresSequence: SQType
    FrameVOILUTSequence: SQType
    PixelValueTransformationSequence: SQType
    SignalDomainRows: CS_1_Type
    DisplayFilterPercentage: FL_1_Type
    FramePixelShiftSequence: SQType
    SubtractionItemID: US_1_Type
    PixelIntensityRelationshipLUTSequence: SQType
    FramePixelDataPropertiesSequence: SQType
    GeometricalProperties: CS_1_Type
    GeometricMaximumDistortion: FL_1_Type
    ImageProcessingApplied: CS_1N_Type
    MaskSelectionMode: CS_1_Type
    LUTFunction: CS_1_Type
    MaskVisibilityPercentage: FL_1_Type
    PixelShiftSequence: SQType
    RegionPixelShiftSequence: SQType
    VerticesOfTheRegion: SS_N_Type
    MultiFramePresentationSequence: SQType
    PixelShiftFrameRange: US_N_Type
    LUTFrameRange: US_N_Type
    ImageToEquipmentMappingMatrix: DS_N_Type
    EquipmentCoordinateSystemIdentification: CS_1_Type
    RequestingPhysicianIdentificationSequence: SQType
    RequestingPhysician: PN_1_Type
    RequestingService: LO_1_Type
    RequestingServiceCodeSequence: SQType
    RequestedProcedureDescription: LO_1_Type
    RequestedProcedureCodeSequence: SQType
    RequestedLateralityCodeSequence: SQType
    ReasonForVisit: UT_1_Type
    ReasonForVisitCodeSequence: SQType
    RequestedContrastAgent: LO_1_Type
    FlowIdentifierSequence: SQType
    FlowIdentifier: OB_1_Type
    FlowTransferSyntaxUID: UI_1_Type
    FlowRTPSamplingRate: UL_1_Type
    SourceIdentifier: OB_1_Type
    FrameOriginTimestamp: OB_1_Type
    IncludesImagingSubject: CS_1_Type
    FrameUsefulnessGroupSequence: SQType
    RealTimeBulkDataFlowSequence: SQType
    CameraPositionGroupSequence: SQType
    IncludesInformation: CS_1_Type
    TimeOfFrameGroupSequence: SQType
    VisitStatusID: CS_1_Type
    AdmissionID: LO_1_Type
    IssuerOfAdmissionIDSequence: SQType
    RouteOfAdmissions: LO_1_Type
    AdmittingDate: DA_1_Type
    AdmittingTime: TM_1_Type
    SpecialNeeds: LO_1_Type
    ServiceEpisodeID: LO_1_Type
    ServiceEpisodeDescription: LO_1_Type
    IssuerOfServiceEpisodeIDSequence: SQType
    PertinentDocumentsSequence: SQType
    PertinentResourcesSequence: SQType
    ResourceDescription: LO_1_Type
    CurrentPatientLocation: LO_1_Type
    PatientInstitutionResidence: LO_1_Type
    PatientState: LO_1_Type
    PatientClinicalTrialParticipationSequence: SQType
    VisitComments: LT_1_Type
    WaveformOriginality: CS_1_Type
    NumberOfWaveformChannels: US_1_Type
    NumberOfWaveformSamples: UL_1_Type
    SamplingFrequency: DS_1_Type
    MultiplexGroupLabel: SH_1_Type
    ChannelDefinitionSequence: SQType
    WaveformChannelNumber: IS_1_Type
    ChannelLabel: SH_1_Type
    ChannelStatus: CS_1N_Type
    ChannelSourceSequence: SQType
    ChannelSourceModifiersSequence: SQType
    SourceWaveformSequence: SQType
    ChannelDerivationDescription: LO_1_Type
    ChannelSensitivity: DS_1_Type
    ChannelSensitivityUnitsSequence: SQType
    ChannelSensitivityCorrectionFactor: DS_1_Type
    ChannelBaseline: DS_1_Type
    ChannelTimeSkew: DS_1_Type
    ChannelSampleSkew: DS_1_Type
    ChannelOffset: DS_1_Type
    WaveformBitsStored: US_1_Type
    FilterLowFrequency: DS_1_Type
    FilterHighFrequency: DS_1_Type
    NotchFilterFrequency: DS_1_Type
    NotchFilterBandwidth: DS_1_Type
    WaveformDataDisplayScale: FL_1_Type
    WaveformDisplayBackgroundCIELabValue: US_N_Type
    WaveformPresentationGroupSequence: SQType
    PresentationGroupNumber: US_1_Type
    ChannelDisplaySequence: SQType
    ChannelRecommendedDisplayCIELabValue: US_N_Type
    ChannelPosition: FL_1_Type
    DisplayShadingFlag: CS_1_Type
    FractionalChannelDisplayScale: FL_1_Type
    AbsoluteChannelDisplayScale: FL_1_Type
    MultiplexedAudioChannelsDescriptionCodeSequence: SQType
    ChannelIdentificationCode: IS_1_Type
    ChannelMode: CS_1_Type
    MultiplexGroupUID: UI_1_Type
    PowerlineFrequency: DS_1_Type
    ChannelImpedanceSequence: SQType
    ImpedanceValue: DS_1_Type
    ImpedanceMeasurementDateTime: DT_1_Type
    ImpedanceMeasurementFrequency: DS_1_Type
    ImpedanceMeasurementCurrentType: CS_1_Type
    WaveformAmplifierType: CS_1_Type
    FilterLowFrequencyCharacteristicsSequence: SQType
    FilterHighFrequencyCharacteristicsSequence: SQType
    SummarizedFilterLookupTable: SQType
    NotchFilterCharacteristicsSequence: SQType
    WaveformFilterType: CS_1_Type
    AnalogFilterCharacteristicsSequence: SQType
    AnalogFilterRollOff: DS_1_Type
    AnalogFilterType: SQType
    DigitalFilterCharacteristicsSequence: SQType
    DigitalFilterOrder: IS_1_Type
    DigitalFilterTypeCodeSequence: SQType
    WaveformFilterDescription: ST_1_Type
    FilterLookupTableSequence: SQType
    FilterLookupTableDescription: ST_1_Type
    FrequencyEncodingCodeSequence: SQType
    MagnitudeEncodingCodeSequence: SQType
    FilterLookupTableData: OD_1_Type
    ScheduledStationAETitle: AE_1N_Type
    ScheduledProcedureStepStartDate: DA_1_Type
    ScheduledProcedureStepStartTime: TM_1_Type
    ScheduledProcedureStepEndDate: DA_1_Type
    ScheduledProcedureStepEndTime: TM_1_Type
    ScheduledPerformingPhysicianName: PN_1_Type
    ScheduledProcedureStepDescription: LO_1_Type
    ScheduledProtocolCodeSequence: SQType
    ScheduledProcedureStepID: SH_1_Type
    StageCodeSequence: SQType
    ScheduledPerformingPhysicianIdentificationSequence: SQType
    ScheduledStationName: SH_1N_Type
    ScheduledProcedureStepLocation: SH_1_Type
    PreMedication: LO_1_Type
    ScheduledProcedureStepStatus: CS_1_Type
    OrderPlacerIdentifierSequence: SQType
    OrderFillerIdentifierSequence: SQType
    LocalNamespaceEntityID: UT_1_Type
    UniversalEntityID: UT_1_Type
    UniversalEntityIDType: CS_1_Type
    IdentifierTypeCode: CS_1_Type
    AssigningFacilitySequence: SQType
    AssigningJurisdictionCodeSequence: SQType
    AssigningAgencyOrDepartmentCodeSequence: SQType
    ScheduledProcedureStepSequence: SQType
    ReferencedNonImageCompositeSOPInstanceSequence: SQType
    PerformedStationAETitle: AE_1_Type
    PerformedStationName: SH_1_Type
    PerformedLocation: SH_1_Type
    PerformedProcedureStepStartDate: DA_1_Type
    PerformedProcedureStepStartTime: TM_1_Type
    PerformedProcedureStepEndDate: DA_1_Type
    PerformedProcedureStepEndTime: TM_1_Type
    PerformedProcedureStepStatus: CS_1_Type
    PerformedProcedureStepID: SH_1_Type
    PerformedProcedureStepDescription: LO_1_Type
    PerformedProcedureTypeDescription: LO_1_Type
    PerformedProtocolCodeSequence: SQType
    PerformedProtocolType: CS_1_Type
    ScheduledStepAttributesSequence: SQType
    RequestAttributesSequence: SQType
    CommentsOnThePerformedProcedureStep: ST_1_Type
    PerformedProcedureStepDiscontinuationReasonCodeSequence: SQType
    QuantitySequence: SQType
    Quantity: DS_1_Type
    MeasuringUnitsSequence: SQType
    BillingItemSequence: SQType
    EntranceDose: US_1_Type
    ExposedArea: US_N_Type
    DistanceSourceToEntrance: DS_1_Type
    CommentsOnRadiationDose: ST_1_Type
    XRayOutput: DS_1_Type
    HalfValueLayer: DS_1_Type
    OrganDose: DS_1_Type
    OrganExposed: CS_1_Type
    BillingProcedureStepSequence: SQType
    FilmConsumptionSequence: SQType
    BillingSuppliesAndDevicesSequence: SQType
    PerformedSeriesSequence: SQType
    CommentsOnTheScheduledProcedureStep: LT_1_Type
    ProtocolContextSequence: SQType
    ContentItemModifierSequence: SQType
    ScheduledSpecimenSequence: SQType
    ContainerIdentifier: LO_1_Type
    IssuerOfTheContainerIdentifierSequence: SQType
    AlternateContainerIdentifierSequence: SQType
    ContainerTypeCodeSequence: SQType
    ContainerDescription: LO_1_Type
    ContainerComponentSequence: SQType
    SpecimenIdentifier: LO_1_Type
    SpecimenUID: UI_1_Type
    AcquisitionContextSequence: SQType
    AcquisitionContextDescription: ST_1_Type
    SpecimenDescriptionSequence: SQType
    IssuerOfTheSpecimenIdentifierSequence: SQType
    SpecimenTypeCodeSequence: SQType
    SpecimenShortDescription: LO_1_Type
    SpecimenDetailedDescription: UT_1_Type
    SpecimenPreparationSequence: SQType
    SpecimenPreparationStepContentItemSequence: SQType
    SpecimenLocalizationContentItemSequence: SQType
    WholeSlideMicroscopyImageFrameTypeSequence: SQType
    ImageCenterPointCoordinatesSequence: SQType
    XOffsetInSlideCoordinateSystem: DS_1_Type
    YOffsetInSlideCoordinateSystem: DS_1_Type
    ZOffsetInSlideCoordinateSystem: DS_1_Type
    MeasurementUnitsCodeSequence: SQType
    RequestedProcedureID: SH_1_Type
    ReasonForTheRequestedProcedure: LO_1_Type
    RequestedProcedurePriority: SH_1_Type
    PatientTransportArrangements: LO_1_Type
    RequestedProcedureLocation: LO_1_Type
    ConfidentialityCode: LO_1_Type
    ReportingPriority: SH_1_Type
    ReasonForRequestedProcedureCodeSequence: SQType
    NamesOfIntendedRecipientsOfResults: PN_1N_Type
    IntendedRecipientsOfResultsIdentificationSequence: SQType
    ReasonForPerformedProcedureCodeSequence: SQType
    PersonIdentificationCodeSequence: SQType
    PersonAddress: ST_1_Type
    PersonTelephoneNumbers: LO_1N_Type
    PersonTelecomInformation: LT_1_Type
    RequestedProcedureComments: LT_1_Type
    IssueDateOfImagingServiceRequest: DA_1_Type
    IssueTimeOfImagingServiceRequest: TM_1_Type
    OrderEnteredBy: PN_1_Type
    OrderEntererLocation: SH_1_Type
    OrderCallbackPhoneNumber: SH_1_Type
    OrderCallbackTelecomInformation: LT_1_Type
    PlacerOrderNumberImagingServiceRequest: LO_1_Type
    FillerOrderNumberImagingServiceRequest: LO_1_Type
    ImagingServiceRequestComments: LT_1_Type
    ConfidentialityConstraintOnPatientDataDescription: LO_1_Type
    ScheduledProcedureStepStartDateTime: DT_1_Type
    ScheduledProcedureStepExpirationDateTime: DT_1_Type
    HumanPerformerCodeSequence: SQType
    ScheduledProcedureStepModificationDateTime: DT_1_Type
    ExpectedCompletionDateTime: DT_1_Type
    ScheduledWorkitemCodeSequence: SQType
    PerformedWorkitemCodeSequence: SQType
    InputInformationSequence: SQType
    ScheduledStationNameCodeSequence: SQType
    ScheduledStationClassCodeSequence: SQType
    ScheduledStationGeographicLocationCodeSequence: SQType
    PerformedStationNameCodeSequence: SQType
    PerformedStationClassCodeSequence: SQType
    PerformedStationGeographicLocationCodeSequence: SQType
    OutputInformationSequence: SQType
    ScheduledHumanPerformersSequence: SQType
    ActualHumanPerformersSequence: SQType
    HumanPerformerOrganization: LO_1_Type
    HumanPerformerName: PN_1_Type
    RawDataHandling: CS_1_Type
    InputReadinessState: CS_1_Type
    PerformedProcedureStepStartDateTime: DT_1_Type
    PerformedProcedureStepEndDateTime: DT_1_Type
    ProcedureStepCancellationDateTime: DT_1_Type
    OutputDestinationSequence: SQType
    DICOMStorageSequence: SQType
    STOWRSStorageSequence: SQType
    StorageURL: UR_1_Type
    XDSStorageSequence: SQType
    EntranceDoseInmGy: DS_1_Type
    EntranceDoseDerivation: CS_1_Type
    ParametricMapFrameTypeSequence: SQType
    ReferencedImageRealWorldValueMappingSequence: SQType
    RealWorldValueMappingSequence: SQType
    PixelValueMappingCodeSequence: SQType
    LUTLabel: SH_1_Type
    RealWorldValueLastValueMapped: US_SS_Type
    RealWorldValueLUTData: FD_1N_Type
    DoubleFloatRealWorldValueLastValueMapped: FD_1_Type
    DoubleFloatRealWorldValueFirstValueMapped: FD_1_Type
    RealWorldValueFirstValueMapped: US_SS_Type
    QuantityDefinitionSequence: SQType
    RealWorldValueIntercept: FD_1_Type
    RealWorldValueSlope: FD_1_Type
    RelationshipType: CS_1_Type
    VerifyingOrganization: LO_1_Type
    VerificationDateTime: DT_1_Type
    ObservationDateTime: DT_1_Type
    ObservationStartDateTime: DT_1_Type
    ValueType: CS_1_Type
    ConceptNameCodeSequence: SQType
    ContinuityOfContent: CS_1_Type
    VerifyingObserverSequence: SQType
    VerifyingObserverName: PN_1_Type
    AuthorObserverSequence: SQType
    ParticipantSequence: SQType
    CustodialOrganizationSequence: SQType
    ParticipationType: CS_1_Type
    ParticipationDateTime: DT_1_Type
    ObserverType: CS_1_Type
    VerifyingObserverIdentificationCodeSequence: SQType
    ReferencedWaveformChannels: US_N_Type
    DateTime: DT_1_Type
    Date: DA_1_Type
    Time: TM_1_Type
    PersonName: PN_1_Type
    UID: UI_1_Type
    TemporalRangeType: CS_1_Type
    ReferencedSamplePositions: UL_1N_Type
    ReferencedTimeOffsets: DS_1N_Type
    ReferencedDateTime: DT_1N_Type
    TextValue: UT_1_Type
    FloatingPointValue: FD_1N_Type
    RationalNumeratorValue: SL_1N_Type
    RationalDenominatorValue: UL_1N_Type
    ConceptCodeSequence: SQType
    PurposeOfReferenceCodeSequence: SQType
    ObservationUID: UI_1_Type
    AnnotationGroupNumber: US_1_Type
    ModifierCodeSequence: SQType
    MeasuredValueSequence: SQType
    NumericValueQualifierCodeSequence: SQType
    NumericValue: DS_1N_Type
    PredecessorDocumentsSequence: SQType
    ReferencedRequestSequence: SQType
    PerformedProcedureCodeSequence: SQType
    CurrentRequestedProcedureEvidenceSequence: SQType
    PertinentOtherEvidenceSequence: SQType
    HL7StructuredDocumentReferenceSequence: SQType
    CompletionFlag: CS_1_Type
    CompletionFlagDescription: LO_1_Type
    VerificationFlag: CS_1_Type
    ArchiveRequested: CS_1_Type
    PreliminaryFlag: CS_1_Type
    ContentTemplateSequence: SQType
    IdenticalDocumentsSequence: SQType
    ContentSequence: SQType
    TabulatedValuesSequence: SQType
    NumberOfTableRows: UL_1_Type
    NumberOfTableColumns: UL_1_Type
    TableRowNumber: UL_1_Type
    TableColumnNumber: UL_1_Type
    TableRowDefinitionSequence: SQType
    TableColumnDefinitionSequence: SQType
    CellValuesSequence: SQType
    WaveformAnnotationSequence: SQType
    TemplateIdentifier: CS_1_Type
    ReferencedContentItemIdentifier: UL_1N_Type
    HL7InstanceIdentifier: ST_1_Type
    HL7DocumentEffectiveTime: DT_1_Type
    HL7DocumentTypeCodeSequence: SQType
    DocumentClassCodeSequence: SQType
    RetrieveURI: UR_1_Type
    RetrieveLocationUID: UI_1_Type
    TypeOfInstances: CS_1_Type
    DICOMRetrievalSequence: SQType
    DICOMMediaRetrievalSequence: SQType
    WADORetrievalSequence: SQType
    XDSRetrievalSequence: SQType
    WADORSRetrievalSequence: SQType
    RepositoryUniqueID: UI_1_Type
    HomeCommunityID: UI_1_Type
    DocumentTitle: ST_1_Type
    EncapsulatedDocument: OB_1_Type
    MIMETypeOfEncapsulatedDocument: LO_1_Type
    SourceInstanceSequence: SQType
    ListOfMIMETypes: LO_1N_Type
    EncapsulatedDocumentLength: UL_1_Type
    ProductPackageIdentifier: ST_1_Type
    SubstanceAdministrationApproval: CS_1_Type
    ApprovalStatusFurtherDescription: LT_1_Type
    ApprovalStatusDateTime: DT_1_Type
    ProductTypeCodeSequence: SQType
    ProductName: LO_1N_Type
    ProductDescription: LT_1_Type
    ProductLotIdentifier: LO_1_Type
    ProductExpirationDateTime: DT_1_Type
    SubstanceAdministrationDateTime: DT_1_Type
    SubstanceAdministrationNotes: LO_1_Type
    SubstanceAdministrationDeviceID: LO_1_Type
    ProductParameterSequence: SQType
    SubstanceAdministrationParameterSequence: SQType
    ApprovalSequence: SQType
    AssertionCodeSequence: SQType
    AssertionUID: UI_1_Type
    AsserterIdentificationSequence: SQType
    AssertionDateTime: DT_1_Type
    AssertionExpirationDateTime: DT_1_Type
    AssertionComments: UT_1_Type
    RelatedAssertionSequence: SQType
    ReferencedAssertionUID: UI_1_Type
    ApprovalSubjectSequence: SQType
    OrganizationalRoleCodeSequence: SQType
    LensDescription: LO_1_Type
    RightLensSequence: SQType
    LeftLensSequence: SQType
    UnspecifiedLateralityLensSequence: SQType
    CylinderSequence: SQType
    PrismSequence: SQType
    HorizontalPrismPower: FD_1_Type
    HorizontalPrismBase: CS_1_Type
    VerticalPrismPower: FD_1_Type
    VerticalPrismBase: CS_1_Type
    LensSegmentType: CS_1_Type
    OpticalTransmittance: FD_1_Type
    ChannelWidth: FD_1_Type
    PupilSize: FD_1_Type
    CornealSize: FD_1_Type
    CornealSizeSequence: SQType
    AutorefractionRightEyeSequence: SQType
    AutorefractionLeftEyeSequence: SQType
    DistancePupillaryDistance: FD_1_Type
    NearPupillaryDistance: FD_1_Type
    IntermediatePupillaryDistance: FD_1_Type
    OtherPupillaryDistance: FD_1_Type
    KeratometryRightEyeSequence: SQType
    KeratometryLeftEyeSequence: SQType
    SteepKeratometricAxisSequence: SQType
    RadiusOfCurvature: FD_1_Type
    KeratometricPower: FD_1_Type
    KeratometricAxis: FD_1_Type
    FlatKeratometricAxisSequence: SQType
    BackgroundColor: CS_1_Type
    Optotype: CS_1_Type
    OptotypePresentation: CS_1_Type
    SubjectiveRefractionRightEyeSequence: SQType
    SubjectiveRefractionLeftEyeSequence: SQType
    AddNearSequence: SQType
    AddIntermediateSequence: SQType
    AddOtherSequence: SQType
    AddPower: FD_1_Type
    ViewingDistance: FD_1_Type
    CorneaMeasurementsSequence: SQType
    SourceOfCorneaMeasurementDataCodeSequence: SQType
    SteepCornealAxisSequence: SQType
    FlatCornealAxisSequence: SQType
    CornealPower: FD_1_Type
    CornealAxis: FD_1_Type
    CorneaMeasurementMethodCodeSequence: SQType
    RefractiveIndexOfCornea: FL_1_Type
    RefractiveIndexOfAqueousHumor: FL_1_Type
    VisualAcuityTypeCodeSequence: SQType
    VisualAcuityRightEyeSequence: SQType
    VisualAcuityLeftEyeSequence: SQType
    VisualAcuityBothEyesOpenSequence: SQType
    ViewingDistanceType: CS_1_Type
    VisualAcuityModifiers: SS_N_Type
    DecimalVisualAcuity: FD_1_Type
    OptotypeDetailedDefinition: LO_1_Type
    ReferencedRefractiveMeasurementsSequence: SQType
    SpherePower: FD_1_Type
    CylinderPower: FD_1_Type
    CornealTopographySurface: CS_1_Type
    CornealVertexLocation: FL_N_Type
    PupilCentroidXCoordinate: FL_1_Type
    PupilCentroidYCoordinate: FL_1_Type
    EquivalentPupilRadius: FL_1_Type
    CornealTopographyMapTypeCodeSequence: SQType
    VerticesOfTheOutlineOfPupil: IS_N_Type
    CornealTopographyMappingNormalsSequence: SQType
    MaximumCornealCurvatureSequence: SQType
    MaximumCornealCurvature: FL_1_Type
    MaximumCornealCurvatureLocation: FL_N_Type
    MinimumKeratometricSequence: SQType
    SimulatedKeratometricCylinderSequence: SQType
    AverageCornealPower: FL_1_Type
    CornealISValue: FL_1_Type
    AnalyzedArea: FL_1_Type
    SurfaceRegularityIndex: FL_1_Type
    SurfaceAsymmetryIndex: FL_1_Type
    CornealEccentricityIndex: FL_1_Type
    KeratoconusPredictionIndex: FL_1_Type
    DecimalPotentialVisualAcuity: FL_1_Type
    CornealTopographyMapQualityEvaluation: CS_1_Type
    SourceImageCornealProcessedDataSequence: SQType
    CornealPointLocation: FL_N_Type
    CornealPointEstimated: CS_1_Type
    AxialPower: FL_1_Type
    TangentialPower: FL_1_Type
    RefractivePower: FL_1_Type
    RelativeElevation: FL_1_Type
    CornealWavefront: FL_1_Type
    ImagedVolumeWidth: FL_1_Type
    ImagedVolumeHeight: FL_1_Type
    ImagedVolumeDepth: FL_1_Type
    TotalPixelMatrixColumns: UL_1_Type
    TotalPixelMatrixRows: UL_1_Type
    TotalPixelMatrixOriginSequence: SQType
    SpecimenLabelInImage: CS_1_Type
    FocusMethod: CS_1_Type
    ExtendedDepthOfField: CS_1_Type
    NumberOfFocalPlanes: US_1_Type
    DistanceBetweenFocalPlanes: FL_1_Type
    RecommendedAbsentPixelCIELabValue: US_N_Type
    IlluminatorTypeCodeSequence: SQType
    ImageOrientationSlide: DS_N_Type
    OpticalPathSequence: SQType
    OpticalPathIdentifier: SH_1_Type
    OpticalPathDescription: ST_1_Type
    IlluminationColorCodeSequence: SQType
    SpecimenReferenceSequence: SQType
    CondenserLensPower: DS_1_Type
    ObjectiveLensPower: DS_1_Type
    ObjectiveLensNumericalAperture: DS_1_Type
    ConfocalMode: CS_1_Type
    TissueLocation: CS_1_Type
    ConfocalMicroscopyImageFrameTypeSequence: SQType
    ImageAcquisitionDepth: FD_1_Type
    PaletteColorLookupTableSequence: SQType
    OpticalPathIdentificationSequence: SQType
    PlanePositionSlideSequence: SQType
    ColumnPositionInTotalImagePixelMatrix: SL_1_Type
    RowPositionInTotalImagePixelMatrix: SL_1_Type
    PixelOriginInterpretation: CS_1_Type
    NumberOfOpticalPaths: UL_1_Type
    TotalPixelMatrixFocalPlanes: UL_1_Type
    CalibrationImage: CS_1_Type
    DeviceSequence: SQType
    ContainerComponentTypeCodeSequence: SQType
    ContainerComponentThickness: FD_1_Type
    DeviceLength: DS_1_Type
    ContainerComponentWidth: FD_1_Type
    DeviceDiameter: DS_1_Type
    DeviceDiameterUnits: CS_1_Type
    DeviceVolume: DS_1_Type
    InterMarkerDistance: DS_1_Type
    ContainerComponentMaterial: CS_1_Type
    ContainerComponentID: LO_1_Type
    ContainerComponentLength: FD_1_Type
    ContainerComponentDiameter: FD_1_Type
    ContainerComponentDescription: LO_1_Type
    DeviceDescription: LO_1_Type
    LongDeviceDescription: ST_1_Type
    ContrastBolusIngredientPercentByVolume: FL_1_Type
    OCTFocalDistance: FD_1_Type
    BeamSpotSize: FD_1_Type
    EffectiveRefractiveIndex: FD_1_Type
    OCTAcquisitionDomain: CS_1_Type
    OCTOpticalCenterWavelength: FD_1_Type
    AxialResolution: FD_1_Type
    RangingDepth: FD_1_Type
    ALineRate: FD_1_Type
    ALinesPerFrame: US_1_Type
    CatheterRotationalRate: FD_1_Type
    ALinePixelSpacing: FD_1_Type
    ModeOfPercutaneousAccessSequence: SQType
    IntravascularOCTFrameTypeSequence: SQType
    OCTZOffsetApplied: CS_1_Type
    IntravascularFrameContentSequence: SQType
    IntravascularLongitudinalDistance: FD_1_Type
    IntravascularOCTFrameContentSequence: SQType
    OCTZOffsetCorrection: SS_1_Type
    CatheterDirectionOfRotation: CS_1_Type
    SeamLineLocation: FD_1_Type
    FirstALineLocation: FD_1_Type
    SeamLineIndex: US_1_Type
    NumberOfPaddedALines: US_1_Type
    InterpolationType: CS_1_Type
    RefractiveIndexApplied: CS_1_Type
    EnergyWindowVector: US_1N_Type
    NumberOfEnergyWindows: US_1_Type
    EnergyWindowInformationSequence: SQType
    EnergyWindowRangeSequence: SQType
    EnergyWindowLowerLimit: DS_1_Type
    EnergyWindowUpperLimit: DS_1_Type
    RadiopharmaceuticalInformationSequence: SQType
    ResidualSyringeCounts: IS_1_Type
    EnergyWindowName: SH_1_Type
    DetectorVector: US_1N_Type
    NumberOfDetectors: US_1_Type
    DetectorInformationSequence: SQType
    PhaseVector: US_1N_Type
    NumberOfPhases: US_1_Type
    PhaseInformationSequence: SQType
    NumberOfFramesInPhase: US_1_Type
    PhaseDelay: IS_1_Type
    PauseBetweenFrames: IS_1_Type
    PhaseDescription: CS_1_Type
    RotationVector: US_1N_Type
    NumberOfRotations: US_1_Type
    RotationInformationSequence: SQType
    NumberOfFramesInRotation: US_1_Type
    RRIntervalVector: US_1N_Type
    NumberOfRRIntervals: US_1_Type
    GatedInformationSequence: SQType
    DataInformationSequence: SQType
    TimeSlotVector: US_1N_Type
    NumberOfTimeSlots: US_1_Type
    TimeSlotInformationSequence: SQType
    TimeSlotTime: DS_1_Type
    SliceVector: US_1N_Type
    NumberOfSlices: US_1_Type
    AngularViewVector: US_1N_Type
    TimeSliceVector: US_1N_Type
    NumberOfTimeSlices: US_1_Type
    StartAngle: DS_1_Type
    TypeOfDetectorMotion: CS_1_Type
    TriggerVector: IS_1N_Type
    NumberOfTriggersInPhase: US_1_Type
    ViewCodeSequence: SQType
    ViewModifierCodeSequence: SQType
    RadionuclideCodeSequence: SQType
    AdministrationRouteCodeSequence: SQType
    RadiopharmaceuticalCodeSequence: SQType
    CalibrationDataSequence: SQType
    EnergyWindowNumber: US_1_Type
    ImageID: SH_1_Type
    PatientOrientationCodeSequence: SQType
    PatientOrientationModifierCodeSequence: SQType
    PatientGantryRelationshipCodeSequence: SQType
    SliceProgressionDirection: CS_1_Type
    ScanProgressionDirection: CS_1_Type
    SeriesType: CS_N_Type
    Units: CS_1_Type
    CountsSource: CS_1_Type
    ReprojectionMethod: CS_1_Type
    SUVType: CS_1_Type
    RandomsCorrectionMethod: CS_1_Type
    AttenuationCorrectionMethod: LO_1_Type
    DecayCorrection: CS_1_Type
    ReconstructionMethod: LO_1_Type
    DetectorLinesOfResponseUsed: LO_1_Type
    ScatterCorrectionMethod: LO_1_Type
    AxialAcceptance: DS_1_Type
    AxialMash: IS_N_Type
    TransverseMash: IS_1_Type
    DetectorElementSize: DS_N_Type
    CoincidenceWindowWidth: DS_1_Type
    SecondaryCountsType: CS_1N_Type
    FrameReferenceTime: DS_1_Type
    PrimaryPromptsCountsAccumulated: IS_1_Type
    SecondaryCountsAccumulated: IS_1N_Type
    SliceSensitivityFactor: DS_1_Type
    DecayFactor: DS_1_Type
    DoseCalibrationFactor: DS_1_Type
    ScatterFractionFactor: DS_1_Type
    DeadTimeFactor: DS_1_Type
    ImageIndex: US_1_Type
    HistogramSequence: SQType
    HistogramNumberOfBins: US_1_Type
    HistogramFirstBinValue: US_SS_Type
    HistogramLastBinValue: US_SS_Type
    HistogramBinWidth: US_1_Type
    HistogramExplanation: LO_1_Type
    HistogramData: UL_1N_Type
    SegmentationType: CS_1_Type
    SegmentSequence: SQType
    SegmentedPropertyCategoryCodeSequence: SQType
    SegmentNumber: US_1_Type
    SegmentLabel: LO_1_Type
    SegmentDescription: ST_1_Type
    SegmentationAlgorithmIdentificationSequence: SQType
    SegmentAlgorithmType: CS_1_Type
    SegmentAlgorithmName: LO_1N_Type
    SegmentIdentificationSequence: SQType
    ReferencedSegmentNumber: US_1N_Type
    RecommendedDisplayGrayscaleValue: US_1_Type
    RecommendedDisplayCIELabValue: US_N_Type
    MaximumFractionalValue: US_1_Type
    SegmentedPropertyTypeCodeSequence: SQType
    SegmentationFractionalType: CS_1_Type
    SegmentedPropertyTypeModifierCodeSequence: SQType
    UsedSegmentsSequence: SQType
    SegmentsOverlap: CS_1_Type
    TrackingID: UT_1_Type
    TrackingUID: UI_1_Type
    DeformableRegistrationSequence: SQType
    SourceFrameOfReferenceUID: UI_1_Type
    DeformableRegistrationGridSequence: SQType
    GridDimensions: UL_N_Type
    GridResolution: FD_N_Type
    VectorGridData: OF_1_Type
    PreDeformationMatrixRegistrationSequence: SQType
    PostDeformationMatrixRegistrationSequence: SQType
    NumberOfSurfaces: UL_1_Type
    SurfaceSequence: SQType
    SurfaceNumber: UL_1_Type
    SurfaceComments: LT_1_Type
    SurfaceProcessing: CS_1_Type
    SurfaceProcessingRatio: FL_1_Type
    SurfaceProcessingDescription: LO_1_Type
    RecommendedPresentationOpacity: FL_1_Type
    RecommendedPresentationType: CS_1_Type
    FiniteVolume: CS_1_Type
    Manifold: CS_1_Type
    SurfacePointsSequence: SQType
    SurfacePointsNormalsSequence: SQType
    SurfaceMeshPrimitivesSequence: SQType
    NumberOfSurfacePoints: UL_1_Type
    PointCoordinatesData: OF_1_Type
    PointPositionAccuracy: FL_N_Type
    MeanPointDistance: FL_1_Type
    MaximumPointDistance: FL_1_Type
    PointsBoundingBoxCoordinates: FL_N_Type
    AxisOfRotation: FL_N_Type
    CenterOfRotation: FL_N_Type
    NumberOfVectors: UL_1_Type
    VectorDimensionality: US_1_Type
    VectorAccuracy: FL_1N_Type
    VectorCoordinateData: OF_1_Type
    DoublePointCoordinatesData: OD_1_Type
    TriangleStripSequence: SQType
    TriangleFanSequence: SQType
    LineSequence: SQType
    SurfaceCount: UL_1_Type
    ReferencedSurfaceSequence: SQType
    ReferencedSurfaceNumber: UL_1_Type
    SegmentSurfaceGenerationAlgorithmIdentificationSequence: SQType
    SegmentSurfaceSourceInstanceSequence: SQType
    AlgorithmFamilyCodeSequence: SQType
    AlgorithmNameCodeSequence: SQType
    AlgorithmVersion: LO_1_Type
    AlgorithmParameters: LT_1_Type
    FacetSequence: SQType
    SurfaceProcessingAlgorithmIdentificationSequence: SQType
    AlgorithmName: LO_1_Type
    RecommendedPointRadius: FL_1_Type
    RecommendedLineThickness: FL_1_Type
    LongPrimitivePointIndexList: OL_1_Type
    LongTrianglePointIndexList: OL_1_Type
    LongEdgePointIndexList: OL_1_Type
    LongVertexPointIndexList: OL_1_Type
    TrackSetSequence: SQType
    TrackSequence: SQType
    RecommendedDisplayCIELabValueList: OW_1_Type
    TrackingAlgorithmIdentificationSequence: SQType
    TrackSetNumber: UL_1_Type
    TrackSetLabel: LO_1_Type
    TrackSetDescription: UT_1_Type
    TrackSetAnatomicalTypeCodeSequence: SQType
    MeasurementsSequence: SQType
    TrackSetStatisticsSequence: SQType
    FloatingPointValues: OF_1_Type
    TrackPointIndexList: OL_1_Type
    TrackStatisticsSequence: SQType
    MeasurementValuesSequence: SQType
    DiffusionAcquisitionCodeSequence: SQType
    DiffusionModelCodeSequence: SQType
    ImplantSize: LO_1_Type
    ImplantTemplateVersion: LO_1_Type
    ReplacedImplantTemplateSequence: SQType
    ImplantType: CS_1_Type
    DerivationImplantTemplateSequence: SQType
    OriginalImplantTemplateSequence: SQType
    EffectiveDateTime: DT_1_Type
    ImplantTargetAnatomySequence: SQType
    InformationFromManufacturerSequence: SQType
    NotificationFromManufacturerSequence: SQType
    InformationIssueDateTime: DT_1_Type
    InformationSummary: ST_1_Type
    ImplantRegulatoryDisapprovalCodeSequence: SQType
    OverallTemplateSpatialTolerance: FD_1_Type
    HPGLDocumentSequence: SQType
    HPGLDocumentID: US_1_Type
    HPGLDocumentLabel: LO_1_Type
    ViewOrientationCodeSequence: SQType
    ViewOrientationModifierCodeSequence: SQType
    HPGLDocumentScaling: FD_1_Type
    HPGLDocument: OB_1_Type
    HPGLContourPenNumber: US_1_Type
    HPGLPenSequence: SQType
    HPGLPenNumber: US_1_Type
    HPGLPenLabel: LO_1_Type
    HPGLPenDescription: ST_1_Type
    RecommendedRotationPoint: FD_N_Type
    BoundingRectangle: FD_N_Type
    ImplantTemplate3DModelSurfaceNumber: US_1N_Type
    SurfaceModelDescriptionSequence: SQType
    SurfaceModelLabel: LO_1_Type
    SurfaceModelScalingFactor: FD_1_Type
    MaterialsCodeSequence: SQType
    CoatingMaterialsCodeSequence: SQType
    ImplantTypeCodeSequence: SQType
    FixationMethodCodeSequence: SQType
    MatingFeatureSetsSequence: SQType
    MatingFeatureSetID: US_1_Type
    MatingFeatureSetLabel: LO_1_Type
    MatingFeatureSequence: SQType
    MatingFeatureID: US_1_Type
    MatingFeatureDegreeOfFreedomSequence: SQType
    DegreeOfFreedomID: US_1_Type
    DegreeOfFreedomType: CS_1_Type
    TwoDMatingFeatureCoordinatesSequence: SQType
    ReferencedHPGLDocumentID: US_1_Type
    TwoDMatingPoint: FD_N_Type
    TwoDMatingAxes: FD_N_Type
    TwoDDegreeOfFreedomSequence: SQType
    ThreeDDegreeOfFreedomAxis: FD_N_Type
    RangeOfFreedom: FD_N_Type
    ThreeDMatingPoint: FD_N_Type
    ThreeDMatingAxes: FD_N_Type
    TwoDDegreeOfFreedomAxis: FD_N_Type
    PlanningLandmarkPointSequence: SQType
    PlanningLandmarkLineSequence: SQType
    PlanningLandmarkPlaneSequence: SQType
    PlanningLandmarkID: US_1_Type
    PlanningLandmarkDescription: LO_1_Type
    PlanningLandmarkIdentificationCodeSequence: SQType
    TwoDPointCoordinatesSequence: SQType
    TwoDPointCoordinates: FD_N_Type
    ThreeDPointCoordinates: FD_N_Type
    TwoDLineCoordinatesSequence: SQType
    TwoDLineCoordinates: FD_N_Type
    ThreeDLineCoordinates: FD_N_Type
    TwoDPlaneCoordinatesSequence: SQType
    TwoDPlaneIntersection: FD_N_Type
    ThreeDPlaneOrigin: FD_N_Type
    ThreeDPlaneNormal: FD_N_Type
    ModelModification: CS_1_Type
    ModelMirroring: CS_1_Type
    ModelUsageCodeSequence: SQType
    ModelGroupUID: UI_1_Type
    RelativeURIReferenceWithinEncapsulatedDocument: UR_1_Type
    AnnotationCoordinateType: CS_1_Type
    AnnotationGroupSequence: SQType
    AnnotationGroupUID: UI_1_Type
    AnnotationGroupLabel: LO_1_Type
    AnnotationGroupDescription: UT_1_Type
    AnnotationGroupGenerationType: CS_1_Type
    AnnotationGroupAlgorithmIdentificationSequence: SQType
    AnnotationPropertyCategoryCodeSequence: SQType
    AnnotationPropertyTypeCodeSequence: SQType
    AnnotationPropertyTypeModifierCodeSequence: SQType
    NumberOfAnnotations: UL_1_Type
    AnnotationAppliesToAllOpticalPaths: CS_1_Type
    ReferencedOpticalPathIdentifier: SH_1N_Type
    AnnotationAppliesToAllZPlanes: CS_1_Type
    CommonZCoordinateValue: FD_1N_Type
    AnnotationIndexList: OL_1_Type
    GraphicAnnotationSequence: SQType
    GraphicLayer: CS_1_Type
    BoundingBoxAnnotationUnits: CS_1_Type
    AnchorPointAnnotationUnits: CS_1_Type
    GraphicAnnotationUnits: CS_1_Type
    UnformattedTextValue: ST_1_Type
    TextObjectSequence: SQType
    GraphicObjectSequence: SQType
    BoundingBoxTopLeftHandCorner: FL_N_Type
    BoundingBoxBottomRightHandCorner: FL_N_Type
    BoundingBoxTextHorizontalJustification: CS_1_Type
    AnchorPoint: FL_N_Type
    AnchorPointVisibility: CS_1_Type
    GraphicDimensions: US_1_Type
    NumberOfGraphicPoints: US_1_Type
    GraphicData: FL_N_Type
    GraphicType: CS_1_Type
    GraphicFilled: CS_1_Type
    ImageHorizontalFlip: CS_1_Type
    ImageRotation: US_1_Type
    DisplayedAreaTopLeftHandCorner: SL_N_Type
    DisplayedAreaBottomRightHandCorner: SL_N_Type
    DisplayedAreaSelectionSequence: SQType
    GraphicLayerSequence: SQType
    GraphicLayerOrder: IS_1_Type
    GraphicLayerRecommendedDisplayGrayscaleValue: US_1_Type
    GraphicLayerDescription: LO_1_Type
    ContentLabel: CS_1_Type
    ContentDescription: LO_1_Type
    PresentationCreationDate: DA_1_Type
    PresentationCreationTime: TM_1_Type
    ContentCreatorName: PN_1_Type
    ContentCreatorIdentificationCodeSequence: SQType
    AlternateContentDescriptionSequence: SQType
    PresentationSizeMode: CS_1_Type
    PresentationPixelSpacing: DS_N_Type
    PresentationPixelAspectRatio: IS_N_Type
    PresentationPixelMagnificationRatio: FL_1_Type
    GraphicGroupLabel: LO_1_Type
    GraphicGroupDescription: ST_1_Type
    CompoundGraphicSequence: SQType
    CompoundGraphicInstanceID: UL_1_Type
    FontName: LO_1_Type
    FontNameType: CS_1_Type
    CSSFontName: LO_1_Type
    RotationAngle: FD_1_Type
    TextStyleSequence: SQType
    LineStyleSequence: SQType
    FillStyleSequence: SQType
    GraphicGroupSequence: SQType
    TextColorCIELabValue: US_N_Type
    HorizontalAlignment: CS_1_Type
    VerticalAlignment: CS_1_Type
    ShadowStyle: CS_1_Type
    ShadowOffsetX: FL_1_Type
    ShadowOffsetY: FL_1_Type
    ShadowColorCIELabValue: US_N_Type
    Underlined: CS_1_Type
    Bold: CS_1_Type
    Italic: CS_1_Type
    PatternOnColorCIELabValue: US_N_Type
    PatternOffColorCIELabValue: US_N_Type
    LineThickness: FL_1_Type
    LineDashingStyle: CS_1_Type
    LinePattern: UL_1_Type
    FillPattern: OB_1_Type
    FillMode: CS_1_Type
    ShadowOpacity: FL_1_Type
    GapLength: FL_1_Type
    DiameterOfVisibility: FL_1_Type
    RotationPoint: FL_N_Type
    TickAlignment: CS_1_Type
    ShowTickLabel: CS_1_Type
    TickLabelAlignment: CS_1_Type
    CompoundGraphicUnits: CS_1_Type
    PatternOnOpacity: FL_1_Type
    PatternOffOpacity: FL_1_Type
    MajorTicksSequence: SQType
    TickPosition: FL_1_Type
    TickLabel: SH_1_Type
    CompoundGraphicType: CS_1_Type
    GraphicGroupID: UL_1_Type
    ShapeType: CS_1_Type
    RegistrationSequence: SQType
    MatrixRegistrationSequence: SQType
    MatrixSequence: SQType
    FrameOfReferenceToDisplayedCoordinateSystemTransformationMatrix: FD_N_Type
    FrameOfReferenceTransformationMatrixType: CS_1_Type
    RegistrationTypeCodeSequence: SQType
    FiducialDescription: ST_1_Type
    FiducialIdentifier: SH_1_Type
    FiducialIdentifierCodeSequence: SQType
    ContourUncertaintyRadius: FD_1_Type
    UsedFiducialsSequence: SQType
    UsedRTStructureSetROISequence: SQType
    GraphicCoordinatesDataSequence: SQType
    FiducialUID: UI_1_Type
    ReferencedFiducialUID: UI_1_Type
    FiducialSetSequence: SQType
    FiducialSequence: SQType
    FiducialsPropertyCategoryCodeSequence: SQType
    GraphicLayerRecommendedDisplayCIELabValue: US_N_Type
    BlendingSequence: SQType
    RelativeOpacity: FL_1_Type
    ReferencedSpatialRegistrationSequence: SQType
    BlendingPosition: CS_1_Type
    PresentationDisplayCollectionUID: UI_1_Type
    PresentationSequenceCollectionUID: UI_1_Type
    PresentationSequencePositionIndex: US_1_Type
    RenderedImageReferenceSequence: SQType
    VolumetricPresentationStateInputSequence: SQType
    PresentationInputType: CS_1_Type
    InputSequencePositionIndex: US_1_Type
    Crop: CS_1_Type
    CroppingSpecificationIndex: US_1N_Type
    VolumetricPresentationInputNumber: US_1_Type
    ImageVolumeGeometry: CS_1_Type
    VolumetricPresentationInputSetUID: UI_1_Type
    VolumetricPresentationInputSetSequence: SQType
    GlobalCrop: CS_1_Type
    GlobalCroppingSpecificationIndex: US_1N_Type
    RenderingMethod: CS_1_Type
    VolumeCroppingSequence: SQType
    VolumeCroppingMethod: CS_1_Type
    BoundingBoxCrop: FD_N_Type
    ObliqueCroppingPlaneSequence: SQType
    Plane: FD_N_Type
    PlaneNormal: FD_N_Type
    CroppingSpecificationNumber: US_1_Type
    MultiPlanarReconstructionStyle: CS_1_Type
    MPRThicknessType: CS_1_Type
    MPRSlabThickness: FD_1_Type
    MPRTopLeftHandCorner: FD_N_Type
    MPRViewWidthDirection: FD_N_Type
    MPRViewWidth: FD_1_Type
    NumberOfVolumetricCurvePoints: UL_1_Type
    VolumetricCurvePoints: OD_1_Type
    MPRViewHeightDirection: FD_N_Type
    MPRViewHeight: FD_1_Type
    RenderProjection: CS_1_Type
    ViewpointPosition: FD_N_Type
    ViewpointLookAtPoint: FD_N_Type
    ViewpointUpDirection: FD_N_Type
    RenderFieldOfView: FD_N_Type
    SamplingStepSize: FD_1_Type
    ShadingStyle: CS_1_Type
    AmbientReflectionIntensity: FD_1_Type
    LightDirection: FD_N_Type
    DiffuseReflectionIntensity: FD_1_Type
    SpecularReflectionIntensity: FD_1_Type
    Shininess: FD_1_Type
    PresentationStateClassificationComponentSequence: SQType
    ComponentType: CS_1_Type
    ComponentInputSequence: SQType
    VolumetricPresentationInputIndex: US_1_Type
    PresentationStateCompositorComponentSequence: SQType
    WeightingTransferFunctionSequence: SQType
    VolumetricAnnotationSequence: SQType
    ReferencedStructuredContextSequence: SQType
    ReferencedContentItem: UI_1_Type
    VolumetricPresentationInputAnnotationSequence: SQType
    AnnotationClipping: CS_1_Type
    PresentationAnimationStyle: CS_1_Type
    RecommendedAnimationRate: FD_1_Type
    AnimationCurveSequence: SQType
    AnimationStepSize: FD_1_Type
    SwivelRange: FD_1_Type
    VolumetricCurveUpDirections: OD_1_Type
    VolumeStreamSequence: SQType
    RGBATransferFunctionDescription: LO_1_Type
    AdvancedBlendingSequence: SQType
    BlendingInputNumber: US_1_Type
    BlendingDisplayInputSequence: SQType
    BlendingDisplaySequence: SQType
    BlendingMode: CS_1_Type
    TimeSeriesBlending: CS_1_Type
    GeometryForDisplay: CS_1_Type
    ThresholdSequence: SQType
    ThresholdValueSequence: SQType
    ThresholdType: CS_1_Type
    ThresholdValue: FD_1_Type
    HangingProtocolName: SH_1_Type
    HangingProtocolDescription: LO_1_Type
    HangingProtocolLevel: CS_1_Type
    HangingProtocolCreator: LO_1_Type
    HangingProtocolCreationDateTime: DT_1_Type
    HangingProtocolDefinitionSequence: SQType
    HangingProtocolUserIdentificationCodeSequence: SQType
    HangingProtocolUserGroupName: LO_1_Type
    SourceHangingProtocolSequence: SQType
    NumberOfPriorsReferenced: US_1_Type
    ImageSetsSequence: SQType
    ImageSetSelectorSequence: SQType
    ImageSetSelectorUsageFlag: CS_1_Type
    SelectorAttribute: AT_1_Type
    SelectorValueNumber: US_1_Type
    TimeBasedImageSetsSequence: SQType
    ImageSetNumber: US_1_Type
    ImageSetSelectorCategory: CS_1_Type
    RelativeTime: US_N_Type
    RelativeTimeUnits: CS_1_Type
    AbstractPriorValue: SS_N_Type
    AbstractPriorCodeSequence: SQType
    ImageSetLabel: LO_1_Type
    SelectorAttributeVR: CS_1_Type
    SelectorSequencePointer: AT_1N_Type
    SelectorSequencePointerPrivateCreator: LO_1N_Type
    SelectorAttributePrivateCreator: LO_1_Type
    SelectorAEValue: AE_1N_Type
    SelectorASValue: AS_1N_Type
    SelectorATValue: AT_1N_Type
    SelectorDAValue: DA_1N_Type
    SelectorCSValue: CS_1N_Type
    SelectorDTValue: DT_1N_Type
    SelectorISValue: IS_1N_Type
    SelectorOBValue: OB_1_Type
    SelectorLOValue: LO_1N_Type
    SelectorOFValue: OF_1_Type
    SelectorLTValue: LT_1_Type
    SelectorOWValue: OW_1_Type
    SelectorPNValue: PN_1N_Type
    SelectorTMValue: TM_1N_Type
    SelectorSHValue: SH_1N_Type
    SelectorUNValue: UN_1_Type
    SelectorSTValue: ST_1_Type
    SelectorUCValue: UC_1N_Type
    SelectorUTValue: UT_1_Type
    SelectorURValue: UR_1_Type
    SelectorDSValue: DS_1N_Type
    SelectorODValue: OD_1_Type
    SelectorFDValue: FD_1N_Type
    SelectorOLValue: OL_1_Type
    SelectorFLValue: FL_1N_Type
    SelectorULValue: UL_1N_Type
    SelectorUSValue: US_1N_Type
    SelectorSLValue: SL_1N_Type
    SelectorSSValue: SS_1N_Type
    SelectorUIValue: UI_1N_Type
    SelectorCodeSequenceValue: SQType
    SelectorOVValue: OV_1_Type
    SelectorSVValue: SV_1N_Type
    SelectorUVValue: UV_1N_Type
    NumberOfScreens: US_1_Type
    NominalScreenDefinitionSequence: SQType
    NumberOfVerticalPixels: US_1_Type
    NumberOfHorizontalPixels: US_1_Type
    DisplayEnvironmentSpatialPosition: FD_N_Type
    ScreenMinimumGrayscaleBitDepth: US_1_Type
    ScreenMinimumColorBitDepth: US_1_Type
    ApplicationMaximumRepaintTime: US_1_Type
    DisplaySetsSequence: SQType
    DisplaySetNumber: US_1_Type
    DisplaySetLabel: LO_1_Type
    DisplaySetPresentationGroup: US_1_Type
    DisplaySetPresentationGroupDescription: LO_1_Type
    PartialDataDisplayHandling: CS_1_Type
    SynchronizedScrollingSequence: SQType
    DisplaySetScrollingGroup: US_N_Type
    NavigationIndicatorSequence: SQType
    NavigationDisplaySet: US_1_Type
    ReferenceDisplaySets: US_1N_Type
    ImageBoxesSequence: SQType
    ImageBoxNumber: US_1_Type
    ImageBoxLayoutType: CS_1_Type
    ImageBoxTileHorizontalDimension: US_1_Type
    ImageBoxTileVerticalDimension: US_1_Type
    ImageBoxScrollDirection: CS_1_Type
    ImageBoxSmallScrollType: CS_1_Type
    ImageBoxSmallScrollAmount: US_1_Type
    ImageBoxLargeScrollType: CS_1_Type
    ImageBoxLargeScrollAmount: US_1_Type
    ImageBoxOverlapPriority: US_1_Type
    CineRelativeToRealTime: FD_1_Type
    FilterOperationsSequence: SQType
    FilterByCategory: CS_1_Type
    FilterByAttributePresence: CS_1_Type
    FilterByOperator: CS_1_Type
    StructuredDisplayBackgroundCIELabValue: US_N_Type
    EmptyImageBoxCIELabValue: US_N_Type
    StructuredDisplayImageBoxSequence: SQType
    StructuredDisplayTextBoxSequence: SQType
    ReferencedFirstFrameSequence: SQType
    ImageBoxSynchronizationSequence: SQType
    SynchronizedImageBoxList: US_N_Type
    TypeOfSynchronization: CS_1_Type
    BlendingOperationType: CS_1_Type
    ReformattingOperationType: CS_1_Type
    ReformattingThickness: FD_1_Type
    ReformattingInterval: FD_1_Type
    ReformattingOperationInitialViewDirection: CS_1_Type
    ThreeDRenderingType: CS_1N_Type
    SortingOperationsSequence: SQType
    SortByCategory: CS_1_Type
    SortingDirection: CS_1_Type
    DisplaySetPatientOrientation: CS_N_Type
    VOIType: CS_1_Type
    PseudoColorType: CS_1_Type
    PseudoColorPaletteInstanceReferenceSequence: SQType
    ShowGrayscaleInverted: CS_1_Type
    ShowImageTrueSizeFlag: CS_1_Type
    ShowGraphicAnnotationFlag: CS_1_Type
    ShowPatientDemographicsFlag: CS_1_Type
    ShowAcquisitionTechniquesFlag: CS_1_Type
    DisplaySetHorizontalJustification: CS_1_Type
    DisplaySetVerticalJustification: CS_1_Type
    ContinuationStartMeterset: FD_1_Type
    ContinuationEndMeterset: FD_1_Type
    ProcedureStepState: CS_1_Type
    ProcedureStepProgressInformationSequence: SQType
    ProcedureStepProgress: DS_1_Type
    ProcedureStepProgressDescription: ST_1_Type
    ProcedureStepProgressParametersSequence: SQType
    ProcedureStepCommunicationsURISequence: SQType
    ContactURI: UR_1_Type
    ContactDisplayName: LO_1_Type
    ProcedureStepDiscontinuationReasonCodeSequence: SQType
    BeamTaskSequence: SQType
    BeamTaskType: CS_1_Type
    AutosequenceFlag: CS_1_Type
    TableTopVerticalAdjustedPosition: FD_1_Type
    TableTopLongitudinalAdjustedPosition: FD_1_Type
    TableTopLateralAdjustedPosition: FD_1_Type
    PatientSupportAdjustedAngle: FD_1_Type
    TableTopEccentricAdjustedAngle: FD_1_Type
    TableTopPitchAdjustedAngle: FD_1_Type
    TableTopRollAdjustedAngle: FD_1_Type
    DeliveryVerificationImageSequence: SQType
    VerificationImageTiming: CS_1_Type
    DoubleExposureFlag: CS_1_Type
    DoubleExposureOrdering: CS_1_Type
    RelatedReferenceRTImageSequence: SQType
    GeneralMachineVerificationSequence: SQType
    ConventionalMachineVerificationSequence: SQType
    IonMachineVerificationSequence: SQType
    FailedAttributesSequence: SQType
    OverriddenAttributesSequence: SQType
    ConventionalControlPointVerificationSequence: SQType
    IonControlPointVerificationSequence: SQType
    AttributeOccurrenceSequence: SQType
    AttributeOccurrencePointer: AT_1_Type
    AttributeItemSelector: UL_1_Type
    AttributeOccurrencePrivateCreator: LO_1_Type
    SelectorSequencePointerItems: IS_1N_Type
    ScheduledProcedureStepPriority: CS_1_Type
    WorklistLabel: LO_1_Type
    ProcedureStepLabel: LO_1_Type
    ScheduledProcessingParametersSequence: SQType
    PerformedProcessingParametersSequence: SQType
    UnifiedProcedureStepPerformedProcedureSequence: SQType
    ReplacedProcedureStepSequence: SQType
    DeletionLock: LO_1_Type
    ReceivingAE: AE_1_Type
    RequestingAE: AE_1_Type
    ReasonForCancellation: LT_1_Type
    SCPStatus: CS_1_Type
    SubscriptionListStatus: CS_1_Type
    UnifiedProcedureStepListStatus: CS_1_Type
    BeamOrderIndex: UL_1_Type
    DoubleExposureMeterset: FD_1_Type
    DoubleExposureFieldDelta: FD_N_Type
    BrachyTaskSequence: SQType
    ContinuationStartTotalReferenceAirKerma: DS_1_Type
    ContinuationEndTotalReferenceAirKerma: DS_1_Type
    ContinuationPulseNumber: IS_1_Type
    ChannelDeliveryOrderSequence: SQType
    ReferencedChannelNumber: IS_1_Type
    StartCumulativeTimeWeight: DS_1_Type
    EndCumulativeTimeWeight: DS_1_Type
    OmittedChannelSequence: SQType
    ReasonForChannelOmission: CS_1_Type
    ReasonForChannelOmissionDescription: LO_1_Type
    ChannelDeliveryOrderIndex: IS_1_Type
    ChannelDeliveryContinuationSequence: SQType
    OmittedApplicationSetupSequence: SQType
    ImplantAssemblyTemplateName: LO_1_Type
    ImplantAssemblyTemplateIssuer: LO_1_Type
    ImplantAssemblyTemplateVersion: LO_1_Type
    ReplacedImplantAssemblyTemplateSequence: SQType
    ImplantAssemblyTemplateType: CS_1_Type
    OriginalImplantAssemblyTemplateSequence: SQType
    DerivationImplantAssemblyTemplateSequence: SQType
    ImplantAssemblyTemplateTargetAnatomySequence: SQType
    ProcedureTypeCodeSequence: SQType
    SurgicalTechnique: LO_1_Type
    ComponentTypesSequence: SQType
    ComponentTypeCodeSequence: SQType
    ExclusiveComponentType: CS_1_Type
    MandatoryComponentType: CS_1_Type
    ComponentSequence: SQType
    ComponentID: US_1_Type
    ComponentAssemblySequence: SQType
    Component1ReferencedID: US_1_Type
    Component1ReferencedMatingFeatureSetID: US_1_Type
    Component1ReferencedMatingFeatureID: US_1_Type
    Component2ReferencedID: US_1_Type
    Component2ReferencedMatingFeatureSetID: US_1_Type
    Component2ReferencedMatingFeatureID: US_1_Type
    ImplantTemplateGroupName: LO_1_Type
    ImplantTemplateGroupDescription: ST_1_Type
    ImplantTemplateGroupIssuer: LO_1_Type
    ImplantTemplateGroupVersion: LO_1_Type
    ReplacedImplantTemplateGroupSequence: SQType
    ImplantTemplateGroupTargetAnatomySequence: SQType
    ImplantTemplateGroupMembersSequence: SQType
    ImplantTemplateGroupMemberID: US_1_Type
    ThreeDImplantTemplateGroupMemberMatchingPoint: FD_N_Type
    ThreeDImplantTemplateGroupMemberMatchingAxes: FD_N_Type
    ImplantTemplateGroupMemberMatching2DCoordinatesSequence: SQType
    TwoDImplantTemplateGroupMemberMatchingPoint: FD_N_Type
    TwoDImplantTemplateGroupMemberMatchingAxes: FD_N_Type
    ImplantTemplateGroupVariationDimensionSequence: SQType
    ImplantTemplateGroupVariationDimensionName: LO_1_Type
    ImplantTemplateGroupVariationDimensionRankSequence: SQType
    ReferencedImplantTemplateGroupMemberID: US_1_Type
    ImplantTemplateGroupVariationDimensionRank: US_1_Type
    SurfaceScanAcquisitionTypeCodeSequence: SQType
    SurfaceScanModeCodeSequence: SQType
    RegistrationMethodCodeSequence: SQType
    ShotDurationTime: FD_1_Type
    ShotOffsetTime: FD_1_Type
    SurfacePointPresentationValueData: US_1N_Type
    SurfacePointColorCIELabValueData: US_N_Type
    UVMappingSequence: SQType
    TextureLabel: SH_1_Type
    UValueData: OF_1_Type
    VValueData: OF_1_Type
    ReferencedTextureSequence: SQType
    ReferencedSurfaceDataSequence: SQType
    AssessmentSummary: CS_1_Type
    AssessmentSummaryDescription: UT_1_Type
    AssessedSOPInstanceSequence: SQType
    ReferencedComparisonSOPInstanceSequence: SQType
    NumberOfAssessmentObservations: UL_1_Type
    AssessmentObservationsSequence: SQType
    ObservationSignificance: CS_1_Type
    ObservationDescription: UT_1_Type
    StructuredConstraintObservationSequence: SQType
    AssessedAttributeValueSequence: SQType
    AssessmentSetID: LO_1_Type
    AssessmentRequesterSequence: SQType
    SelectorAttributeName: LO_1_Type
    SelectorAttributeKeyword: LO_1_Type
    AssessmentTypeCodeSequence: SQType
    ObservationBasisCodeSequence: SQType
    AssessmentLabel: LO_1_Type
    ConstraintType: CS_1_Type
    SpecificationSelectionGuidance: UT_1_Type
    ConstraintValueSequence: SQType
    RecommendedDefaultValueSequence: SQType
    ConstraintViolationSignificance: CS_1_Type
    ConstraintViolationCondition: UT_1_Type
    ModifiableConstraintFlag: CS_1_Type
    StorageMediaFileSetID: SH_1_Type
    StorageMediaFileSetUID: UI_1_Type
    IconImageSequence: SQType
    SOPInstanceStatus: CS_1_Type
    SOPAuthorizationDateTime: DT_1_Type
    SOPAuthorizationComment: LT_1_Type
    AuthorizationEquipmentCertificationNumber: LO_1_Type
    MACIDNumber: US_1_Type
    MACCalculationTransferSyntaxUID: UI_1_Type
    MACAlgorithm: CS_1_Type
    DataElementsSigned: AT_1N_Type
    DigitalSignatureUID: UI_1_Type
    DigitalSignatureDateTime: DT_1_Type
    CertificateType: CS_1_Type
    CertificateOfSigner: OB_1_Type
    Signature: OB_1_Type
    CertifiedTimestampType: CS_1_Type
    CertifiedTimestamp: OB_1_Type
    DigitalSignaturePurposeCodeSequence: SQType
    ReferencedDigitalSignatureSequence: SQType
    ReferencedSOPInstanceMACSequence: SQType
    MAC: OB_1_Type
    EncryptedAttributesSequence: SQType
    EncryptedContentTransferSyntaxUID: UI_1_Type
    EncryptedContent: OB_1_Type
    ModifiedAttributesSequence: SQType
    NonconformingModifiedAttributesSequence: SQType
    NonconformingDataElementValue: OB_1_Type
    OriginalAttributesSequence: SQType
    AttributeModificationDateTime: DT_1_Type
    ModifyingSystem: LO_1_Type
    SourceOfPreviousValues: LO_1_Type
    ReasonForTheAttributeModification: CS_1_Type
    InstanceOriginStatus: CS_1_Type
    NumberOfCopies: IS_1_Type
    PrinterConfigurationSequence: SQType
    PrintPriority: CS_1_Type
    MediumType: CS_1_Type
    FilmDestination: CS_1_Type
    FilmSessionLabel: LO_1_Type
    MemoryAllocation: IS_1_Type
    MaximumMemoryAllocation: IS_1_Type
    MemoryBitDepth: US_1_Type
    PrintingBitDepth: US_1_Type
    MediaInstalledSequence: SQType
    OtherMediaAvailableSequence: SQType
    SupportedImageDisplayFormatsSequence: SQType
    ReferencedFilmBoxSequence: SQType
    ImageDisplayFormat: ST_1_Type
    AnnotationDisplayFormatID: CS_1_Type
    FilmOrientation: CS_1_Type
    FilmSizeID: CS_1_Type
    PrinterResolutionID: CS_1_Type
    DefaultPrinterResolutionID: CS_1_Type
    MagnificationType: CS_1_Type
    SmoothingType: CS_1_Type
    DefaultMagnificationType: CS_1_Type
    OtherMagnificationTypesAvailable: CS_1N_Type
    DefaultSmoothingType: CS_1_Type
    OtherSmoothingTypesAvailable: CS_1N_Type
    BorderDensity: CS_1_Type
    EmptyImageDensity: CS_1_Type
    MinDensity: US_1_Type
    MaxDensity: US_1_Type
    Trim: CS_1_Type
    ConfigurationInformation: ST_1_Type
    ConfigurationInformationDescription: LT_1_Type
    MaximumCollatedFilms: IS_1_Type
    Illumination: US_1_Type
    ReflectedAmbientLight: US_1_Type
    PrinterPixelSpacing: DS_N_Type
    ReferencedFilmSessionSequence: SQType
    ReferencedImageBoxSequence: SQType
    ReferencedBasicAnnotationBoxSequence: SQType
    ImageBoxPosition: US_1_Type
    Polarity: CS_1_Type
    RequestedImageSize: DS_1_Type
    RequestedDecimateCropBehavior: CS_1_Type
    RequestedResolutionID: CS_1_Type
    RequestedImageSizeFlag: CS_1_Type
    DecimateCropResult: CS_1_Type
    BasicGrayscaleImageSequence: SQType
    BasicColorImageSequence: SQType
    AnnotationPosition: US_1_Type
    TextString: LO_1_Type
    PresentationLUTSequence: SQType
    PresentationLUTShape: CS_1_Type
    ReferencedPresentationLUTSequence: SQType
    ExecutionStatus: CS_1_Type
    ExecutionStatusInfo: CS_1_Type
    CreationDate: DA_1_Type
    CreationTime: TM_1_Type
    Originator: AE_1_Type
    DestinationAE: AE_1_Type
    OwnerID: SH_1_Type
    NumberOfFilms: IS_1_Type
    PrinterStatus: CS_1_Type
    PrinterStatusInfo: CS_1_Type
    PrinterName: LO_1_Type
    ProposedStudySequence: SQType
    OriginalImageSequence: SQType
    LabelUsingInformationExtractedFromInstances: CS_1_Type
    LabelText: UT_1_Type
    LabelStyleSelection: CS_1_Type
    MediaDisposition: LT_1_Type
    BarcodeValue: LT_1_Type
    BarcodeSymbology: CS_1_Type
    AllowMediaSplitting: CS_1_Type
    IncludeNonDICOMObjects: CS_1_Type
    IncludeDisplayApplication: CS_1_Type
    PreserveCompositeInstancesAfterMediaCreation: CS_1_Type
    TotalNumberOfPiecesOfMediaCreated: US_1_Type
    RequestedMediaApplicationProfile: LO_1_Type
    ReferencedStorageMediaSequence: SQType
    FailureAttributes: AT_1N_Type
    AllowLossyCompression: CS_1_Type
    RequestPriority: CS_1_Type
    RTImageLabel: SH_1_Type
    RTImageName: LO_1_Type
    RTImageDescription: ST_1_Type
    ReportedValuesOrigin: CS_1_Type
    RTImagePlane: CS_1_Type
    XRayImageReceptorTranslation: DS_N_Type
    XRayImageReceptorAngle: DS_1_Type
    RTImageOrientation: DS_N_Type
    ImagePlanePixelSpacing: DS_N_Type
    RTImagePosition: DS_N_Type
    RadiationMachineName: SH_1_Type
    RadiationMachineSAD: DS_1_Type
    RadiationMachineSSD: DS_1_Type
    RTImageSID: DS_1_Type
    SourceToReferenceObjectDistance: DS_1_Type
    FractionNumber: IS_1_Type
    ExposureSequence: SQType
    MetersetExposure: DS_1_Type
    DiaphragmPosition: DS_N_Type
    FluenceMapSequence: SQType
    FluenceDataSource: CS_1_Type
    FluenceDataScale: DS_1_Type
    PrimaryFluenceModeSequence: SQType
    FluenceMode: CS_1_Type
    FluenceModeID: SH_1_Type
    SelectedFrameNumber: IS_1_Type
    SelectedFrameFunctionalGroupsSequence: SQType
    RTImageFrameGeneralContentSequence: SQType
    RTImageFrameContextSequence: SQType
    RTImageScopeSequence: SQType
    BeamModifierCoordinatesPresenceFlag: CS_1_Type
    StartCumulativeMeterset: FD_1_Type
    StopCumulativeMeterset: FD_1_Type
    RTAcquisitionPatientPositionSequence: SQType
    RTImageFrameImagingDevicePositionSequence: SQType
    RTImageFramekVRadiationAcquisitionSequence: SQType
    RTImageFrameMVRadiationAcquisitionSequence: SQType
    RTImageFrameRadiationAcquisitionSequence: SQType
    ImagingSourcePositionSequence: SQType
    ImageReceptorPositionSequence: SQType
    DevicePositionToEquipmentMappingMatrix: FD_N_Type
    DevicePositionParameterSequence: SQType
    ImagingSourceLocationSpecificationType: CS_1_Type
    ImagingDeviceLocationMatrixSequence: SQType
    ImagingDeviceLocationParameterSequence: SQType
    ImagingApertureSequence: SQType
    ImagingApertureSpecificationType: CS_1_Type
    NumberOfAcquisitionDevices: US_1_Type
    AcquisitionDeviceSequence: SQType
    AcquisitionTaskSequence: SQType
    AcquisitionTaskWorkitemCodeSequence: SQType
    AcquisitionSubtaskSequence: SQType
    SubtaskWorkitemCodeSequence: SQType
    AcquisitionTaskIndex: US_1_Type
    AcquisitionSubtaskIndex: US_1_Type
    ReferencedBaselineParametersRTRadiationInstanceSequence: SQType
    PositionAcquisitionTemplateIdentificationSequence: SQType
    PositionAcquisitionTemplateID: ST_1_Type
    PositionAcquisitionTemplateName: LO_1_Type
    PositionAcquisitionTemplateCodeSequence: SQType
    PositionAcquisitionTemplateDescription: LT_1_Type
    AcquisitionTaskApplicabilitySequence: SQType
    ProjectionImagingAcquisitionParameterSequence: SQType
    CTImagingAcquisitionParameterSequence: SQType
    KVImagingGenerationParametersSequence: SQType
    MVImagingGenerationParametersSequence: SQType
    AcquisitionSignalType: CS_1_Type
    AcquisitionMethod: CS_1_Type
    ScanStartPositionSequence: SQType
    ScanStopPositionSequence: SQType
    ImagingSourceToBeamModifierDefinitionPlaneDistance: FD_1_Type
    ScanArcType: CS_1_Type
    DetectorPositioningType: CS_1_Type
    AdditionalRTAccessoryDeviceSequence: SQType
    DeviceSpecificAcquisitionParameterSequence: SQType
    ReferencedPositionReferenceInstanceSequence: SQType
    EnergyDerivationCodeSequence: SQType
    MaximumCumulativeMetersetExposure: FD_1_Type
    AcquisitionInitiationSequence: SQType
    DVHType: CS_1_Type
    DoseUnits: CS_1_Type
    DoseType: CS_1_Type
    SpatialTransformOfDose: CS_1_Type
    DoseComment: LO_1_Type
    NormalizationPoint: DS_N_Type
    DoseSummationType: CS_1_Type
    GridFrameOffsetVector: DS_N_Type
    DoseGridScaling: DS_1_Type
    TissueHeterogeneityCorrection: CS_N_Type
    DVHNormalizationPoint: DS_N_Type
    DVHNormalizationDoseValue: DS_1_Type
    DVHSequence: SQType
    DVHDoseScaling: DS_1_Type
    DVHVolumeUnits: CS_1_Type
    DVHNumberOfBins: IS_1_Type
    DVHData: DS_N_Type
    DVHReferencedROISequence: SQType
    DVHROIContributionType: CS_1_Type
    DVHMinimumDose: DS_1_Type
    DVHMaximumDose: DS_1_Type
    DVHMeanDose: DS_1_Type
    StructureSetLabel: SH_1_Type
    StructureSetName: LO_1_Type
    StructureSetDescription: ST_1_Type
    StructureSetDate: DA_1_Type
    StructureSetTime: TM_1_Type
    ReferencedFrameOfReferenceSequence: SQType
    RTReferencedStudySequence: SQType
    RTReferencedSeriesSequence: SQType
    ContourImageSequence: SQType
    PredecessorStructureSetSequence: SQType
    StructureSetROISequence: SQType
    ROINumber: IS_1_Type
    ReferencedFrameOfReferenceUID: UI_1_Type
    ROIName: LO_1_Type
    ROIDescription: ST_1_Type
    ROIDisplayColor: IS_N_Type
    ROIVolume: DS_1_Type
    ROIDateTime: DT_1_Type
    ROIObservationDateTime: DT_1_Type
    RTRelatedROISequence: SQType
    RTROIRelationship: CS_1_Type
    ROIGenerationAlgorithm: CS_1_Type
    ROIDerivationAlgorithmIdentificationSequence: SQType
    ROIGenerationDescription: LO_1_Type
    ROIContourSequence: SQType
    ContourSequence: SQType
    ContourGeometricType: CS_1_Type
    NumberOfContourPoints: IS_1_Type
    ContourNumber: IS_1_Type
    SourcePixelPlanesCharacteristicsSequence: SQType
    SourceSeriesSequence: SQType
    SourceSeriesInformationSequence: SQType
    ROICreatorSequence: SQType
    ROIInterpreterSequence: SQType
    ROIObservationContextCodeSequence: SQType
    ContourData: DS_N_Type
    RTROIObservationsSequence: SQType
    ObservationNumber: IS_1_Type
    ReferencedROINumber: IS_1_Type
    RTROIIdentificationCodeSequence: SQType
    RelatedRTROIObservationsSequence: SQType
    RTROIInterpretedType: CS_1_Type
    ROIInterpreter: PN_1_Type
    ROIPhysicalPropertiesSequence: SQType
    ROIPhysicalProperty: CS_1_Type
    ROIPhysicalPropertyValue: DS_1_Type
    ROIElementalCompositionSequence: SQType
    ROIElementalCompositionAtomicNumber: US_1_Type
    ROIElementalCompositionAtomicMassFraction: FL_1_Type
    FrameOfReferenceTransformationMatrix: DS_N_Type
    FrameOfReferenceTransformationComment: LO_1_Type
    PatientLocationCoordinatesSequence: SQType
    PatientLocationCoordinatesCodeSequence: SQType
    PatientSupportPositionSequence: SQType
    MeasuredDoseReferenceSequence: SQType
    MeasuredDoseDescription: ST_1_Type
    MeasuredDoseType: CS_1_Type
    MeasuredDoseValue: DS_1_Type
    TreatmentSessionBeamSequence: SQType
    TreatmentSessionIonBeamSequence: SQType
    CurrentFractionNumber: IS_1_Type
    TreatmentControlPointDate: DA_1_Type
    TreatmentControlPointTime: TM_1_Type
    TreatmentTerminationStatus: CS_1_Type
    TreatmentVerificationStatus: CS_1_Type
    ReferencedTreatmentRecordSequence: SQType
    SpecifiedPrimaryMeterset: DS_1_Type
    SpecifiedSecondaryMeterset: DS_1_Type
    DeliveredPrimaryMeterset: DS_1_Type
    DeliveredSecondaryMeterset: DS_1_Type
    SpecifiedTreatmentTime: DS_1_Type
    DeliveredTreatmentTime: DS_1_Type
    ControlPointDeliverySequence: SQType
    IonControlPointDeliverySequence: SQType
    SpecifiedMeterset: DS_1_Type
    DeliveredMeterset: DS_1_Type
    MetersetRateSet: FL_1_Type
    MetersetRateDelivered: FL_1_Type
    ScanSpotMetersetsDelivered: FL_1N_Type
    DoseRateDelivered: DS_1_Type
    TreatmentSummaryCalculatedDoseReferenceSequence: SQType
    CumulativeDoseToDoseReference: DS_1_Type
    FirstTreatmentDate: DA_1_Type
    MostRecentTreatmentDate: DA_1_Type
    NumberOfFractionsDelivered: IS_1_Type
    OverrideSequence: SQType
    ParameterSequencePointer: AT_1_Type
    OverrideParameterPointer: AT_1_Type
    ParameterItemIndex: IS_1_Type
    MeasuredDoseReferenceNumber: IS_1_Type
    ParameterPointer: AT_1_Type
    OverrideReason: ST_1_Type
    ParameterValueNumber: US_1_Type
    CorrectedParameterSequence: SQType
    CorrectionValue: FL_1_Type
    CalculatedDoseReferenceSequence: SQType
    CalculatedDoseReferenceNumber: IS_1_Type
    CalculatedDoseReferenceDescription: ST_1_Type
    CalculatedDoseReferenceDoseValue: DS_1_Type
    StartMeterset: DS_1_Type
    EndMeterset: DS_1_Type
    ReferencedMeasuredDoseReferenceSequence: SQType
    ReferencedMeasuredDoseReferenceNumber: IS_1_Type
    ReferencedCalculatedDoseReferenceSequence: SQType
    ReferencedCalculatedDoseReferenceNumber: IS_1_Type
    BeamLimitingDeviceLeafPairsSequence: SQType
    EnhancedRTBeamLimitingDeviceSequence: SQType
    EnhancedRTBeamLimitingOpeningSequence: SQType
    EnhancedRTBeamLimitingDeviceDefinitionFlag: CS_1_Type
    ParallelRTBeamDelimiterOpeningExtents: FD_N_Type
    RecordedWedgeSequence: SQType
    RecordedCompensatorSequence: SQType
    RecordedBlockSequence: SQType
    RecordedBlockSlabSequence: SQType
    TreatmentSummaryMeasuredDoseReferenceSequence: SQType
    RecordedSnoutSequence: SQType
    RecordedRangeShifterSequence: SQType
    RecordedLateralSpreadingDeviceSequence: SQType
    RecordedRangeModulatorSequence: SQType
    RecordedSourceSequence: SQType
    SourceSerialNumber: LO_1_Type
    TreatmentSessionApplicationSetupSequence: SQType
    ApplicationSetupCheck: CS_1_Type
    RecordedBrachyAccessoryDeviceSequence: SQType
    ReferencedBrachyAccessoryDeviceNumber: IS_1_Type
    RecordedChannelSequence: SQType
    SpecifiedChannelTotalTime: DS_1_Type
    DeliveredChannelTotalTime: DS_1_Type
    SpecifiedNumberOfPulses: IS_1_Type
    DeliveredNumberOfPulses: IS_1_Type
    SpecifiedPulseRepetitionInterval: DS_1_Type
    DeliveredPulseRepetitionInterval: DS_1_Type
    RecordedSourceApplicatorSequence: SQType
    ReferencedSourceApplicatorNumber: IS_1_Type
    RecordedChannelShieldSequence: SQType
    ReferencedChannelShieldNumber: IS_1_Type
    BrachyControlPointDeliveredSequence: SQType
    SafePositionExitDate: DA_1_Type
    SafePositionExitTime: TM_1_Type
    SafePositionReturnDate: DA_1_Type
    SafePositionReturnTime: TM_1_Type
    PulseSpecificBrachyControlPointDeliveredSequence: SQType
    PulseNumber: US_1_Type
    BrachyPulseControlPointDeliveredSequence: SQType
    CurrentTreatmentStatus: CS_1_Type
    TreatmentStatusComment: ST_1_Type
    FractionGroupSummarySequence: SQType
    ReferencedFractionNumber: IS_1_Type
    FractionGroupType: CS_1_Type
    BeamStopperPosition: CS_1_Type
    FractionStatusSummarySequence: SQType
    TreatmentDate: DA_1_Type
    TreatmentTime: TM_1_Type
    RTPlanLabel: SH_1_Type
    RTPlanName: LO_1_Type
    RTPlanDescription: ST_1_Type
    RTPlanDate: DA_1_Type
    RTPlanTime: TM_1_Type
    TreatmentProtocols: LO_1N_Type
    PlanIntent: CS_1_Type
    RTPlanGeometry: CS_1_Type
    PrescriptionDescription: ST_1_Type
    DoseReferenceSequence: SQType
    DoseReferenceNumber: IS_1_Type
    DoseReferenceUID: UI_1_Type
    DoseReferenceStructureType: CS_1_Type
    NominalBeamEnergyUnit: CS_1_Type
    DoseReferenceDescription: LO_1_Type
    DoseReferencePointCoordinates: DS_N_Type
    NominalPriorDose: DS_1_Type
    DoseReferenceType: CS_1_Type
    ConstraintWeight: DS_1_Type
    DeliveryWarningDose: DS_1_Type
    DeliveryMaximumDose: DS_1_Type
    TargetMinimumDose: DS_1_Type
    TargetPrescriptionDose: DS_1_Type
    TargetMaximumDose: DS_1_Type
    TargetUnderdoseVolumeFraction: DS_1_Type
    OrganAtRiskFullVolumeDose: DS_1_Type
    OrganAtRiskLimitDose: DS_1_Type
    OrganAtRiskMaximumDose: DS_1_Type
    OrganAtRiskOverdoseVolumeFraction: DS_1_Type
    ToleranceTableSequence: SQType
    ToleranceTableNumber: IS_1_Type
    ToleranceTableLabel: SH_1_Type
    GantryAngleTolerance: DS_1_Type
    BeamLimitingDeviceAngleTolerance: DS_1_Type
    BeamLimitingDeviceToleranceSequence: SQType
    BeamLimitingDevicePositionTolerance: DS_1_Type
    SnoutPositionTolerance: FL_1_Type
    PatientSupportAngleTolerance: DS_1_Type
    TableTopEccentricAngleTolerance: DS_1_Type
    TableTopPitchAngleTolerance: FL_1_Type
    TableTopRollAngleTolerance: FL_1_Type
    TableTopVerticalPositionTolerance: DS_1_Type
    TableTopLongitudinalPositionTolerance: DS_1_Type
    TableTopLateralPositionTolerance: DS_1_Type
    TableTopPositionAlignmentUID: UI_1_Type
    RTPlanRelationship: CS_1_Type
    FractionGroupSequence: SQType
    FractionGroupNumber: IS_1_Type
    FractionGroupDescription: LO_1_Type
    NumberOfFractionsPlanned: IS_1_Type
    NumberOfFractionPatternDigitsPerDay: IS_1_Type
    RepeatFractionCycleLength: IS_1_Type
    FractionPattern: LT_1_Type
    NumberOfBeams: IS_1_Type
    ReferencedDoseReferenceUID: UI_1_Type
    BeamDose: DS_1_Type
    BeamMeterset: DS_1_Type
    BeamDosePointDepth: FL_1_Type
    BeamDosePointEquivalentDepth: FL_1_Type
    BeamDosePointSSD: FL_1_Type
    BeamDoseMeaning: CS_1_Type
    BeamDoseVerificationControlPointSequence: SQType
    BeamDoseType: CS_1_Type
    AlternateBeamDose: DS_1_Type
    AlternateBeamDoseType: CS_1_Type
    DepthValueAveragingFlag: CS_1_Type
    BeamDosePointSourceToExternalContourDistance: DS_1_Type
    NumberOfBrachyApplicationSetups: IS_1_Type
    BrachyApplicationSetupDoseSpecificationPoint: DS_N_Type
    BrachyApplicationSetupDose: DS_1_Type
    BeamSequence: SQType
    TreatmentMachineName: SH_1_Type
    PrimaryDosimeterUnit: CS_1_Type
    SourceAxisDistance: DS_1_Type
    BeamLimitingDeviceSequence: SQType
    RTBeamLimitingDeviceType: CS_1_Type
    SourceToBeamLimitingDeviceDistance: DS_1_Type
    IsocenterToBeamLimitingDeviceDistance: FL_1_Type
    NumberOfLeafJawPairs: IS_1_Type
    LeafPositionBoundaries: DS_N_Type
    BeamNumber: IS_1_Type
    BeamName: LO_1_Type
    BeamDescription: ST_1_Type
    BeamType: CS_1_Type
    BeamDeliveryDurationLimit: FD_1_Type
    RadiationType: CS_1_Type
    HighDoseTechniqueType: CS_1_Type
    ReferenceImageNumber: IS_1_Type
    PlannedVerificationImageSequence: SQType
    ImagingDeviceSpecificAcquisitionParameters: LO_1N_Type
    TreatmentDeliveryType: CS_1_Type
    NumberOfWedges: IS_1_Type
    WedgeSequence: SQType
    WedgeNumber: IS_1_Type
    WedgeType: CS_1_Type
    WedgeID: SH_1_Type
    WedgeAngle: IS_1_Type
    WedgeFactor: DS_1_Type
    TotalWedgeTrayWaterEquivalentThickness: FL_1_Type
    WedgeOrientation: DS_1_Type
    IsocenterToWedgeTrayDistance: FL_1_Type
    SourceToWedgeTrayDistance: DS_1_Type
    WedgeThinEdgePosition: FL_1_Type
    BolusID: SH_1_Type
    BolusDescription: ST_1_Type
    EffectiveWedgeAngle: DS_1_Type
    NumberOfCompensators: IS_1_Type
    MaterialID: SH_1_Type
    TotalCompensatorTrayFactor: DS_1_Type
    CompensatorSequence: SQType
    CompensatorNumber: IS_1_Type
    CompensatorID: SH_1_Type
    SourceToCompensatorTrayDistance: DS_1_Type
    CompensatorRows: IS_1_Type
    CompensatorColumns: IS_1_Type
    CompensatorPixelSpacing: DS_N_Type
    CompensatorPosition: DS_N_Type
    CompensatorTransmissionData: DS_1N_Type
    CompensatorThicknessData: DS_1N_Type
    NumberOfBoli: IS_1_Type
    CompensatorType: CS_1_Type
    CompensatorTrayID: SH_1_Type
    NumberOfBlocks: IS_1_Type
    TotalBlockTrayFactor: DS_1_Type
    TotalBlockTrayWaterEquivalentThickness: FL_1_Type
    BlockSequence: SQType
    BlockTrayID: SH_1_Type
    SourceToBlockTrayDistance: DS_1_Type
    IsocenterToBlockTrayDistance: FL_1_Type
    BlockType: CS_1_Type
    AccessoryCode: LO_1_Type
    BlockDivergence: CS_1_Type
    BlockMountingPosition: CS_1_Type
    BlockNumber: IS_1_Type
    BlockName: LO_1_Type
    BlockThickness: DS_1_Type
    BlockTransmission: DS_1_Type
    BlockNumberOfPoints: IS_1_Type
    BlockData: DS_N_Type
    ApplicatorSequence: SQType
    ApplicatorID: SH_1_Type
    ApplicatorType: CS_1_Type
    ApplicatorDescription: LO_1_Type
    CumulativeDoseReferenceCoefficient: DS_1_Type
    FinalCumulativeMetersetWeight: DS_1_Type
    NumberOfControlPoints: IS_1_Type
    ControlPointSequence: SQType
    ControlPointIndex: IS_1_Type
    NominalBeamEnergy: DS_1_Type
    DoseRateSet: DS_1_Type
    WedgePositionSequence: SQType
    WedgePosition: CS_1_Type
    BeamLimitingDevicePositionSequence: SQType
    LeafJawPositions: DS_N_Type
    GantryAngle: DS_1_Type
    GantryRotationDirection: CS_1_Type
    BeamLimitingDeviceAngle: DS_1_Type
    BeamLimitingDeviceRotationDirection: CS_1_Type
    PatientSupportAngle: DS_1_Type
    PatientSupportRotationDirection: CS_1_Type
    TableTopEccentricAxisDistance: DS_1_Type
    TableTopEccentricAngle: DS_1_Type
    TableTopEccentricRotationDirection: CS_1_Type
    TableTopVerticalPosition: DS_1_Type
    TableTopLongitudinalPosition: DS_1_Type
    TableTopLateralPosition: DS_1_Type
    IsocenterPosition: DS_N_Type
    SurfaceEntryPoint: DS_N_Type
    SourceToSurfaceDistance: DS_1_Type
    AverageBeamDosePointSourceToExternalContourDistance: FL_1_Type
    SourceToExternalContourDistance: FL_1_Type
    ExternalContourEntryPoint: FL_N_Type
    CumulativeMetersetWeight: DS_1_Type
    TableTopPitchAngle: FL_1_Type
    TableTopPitchRotationDirection: CS_1_Type
    TableTopRollAngle: FL_1_Type
    TableTopRollRotationDirection: CS_1_Type
    HeadFixationAngle: FL_1_Type
    GantryPitchAngle: FL_1_Type
    GantryPitchRotationDirection: CS_1_Type
    GantryPitchAngleTolerance: FL_1_Type
    FixationEye: CS_1_Type
    ChairHeadFramePosition: DS_1_Type
    HeadFixationAngleTolerance: DS_1_Type
    ChairHeadFramePositionTolerance: DS_1_Type
    FixationLightAzimuthalAngleTolerance: DS_1_Type
    FixationLightPolarAngleTolerance: DS_1_Type
    PatientSetupSequence: SQType
    PatientSetupNumber: IS_1_Type
    PatientSetupLabel: LO_1_Type
    PatientAdditionalPosition: LO_1_Type
    FixationDeviceSequence: SQType
    FixationDeviceType: CS_1_Type
    FixationDeviceLabel: SH_1_Type
    FixationDeviceDescription: ST_1_Type
    FixationDevicePosition: SH_1_Type
    FixationDevicePitchAngle: FL_1_Type
    FixationDeviceRollAngle: FL_1_Type
    ShieldingDeviceSequence: SQType
    ShieldingDeviceType: CS_1_Type
    ShieldingDeviceLabel: SH_1_Type
    ShieldingDeviceDescription: ST_1_Type
    ShieldingDevicePosition: SH_1_Type
    SetupTechnique: CS_1_Type
    SetupTechniqueDescription: ST_1_Type
    SetupDeviceSequence: SQType
    SetupDeviceType: CS_1_Type
    SetupDeviceLabel: SH_1_Type
    SetupDeviceDescription: ST_1_Type
    SetupDeviceParameter: DS_1_Type
    SetupReferenceDescription: ST_1_Type
    TableTopVerticalSetupDisplacement: DS_1_Type
    TableTopLongitudinalSetupDisplacement: DS_1_Type
    TableTopLateralSetupDisplacement: DS_1_Type
    BrachyTreatmentTechnique: CS_1_Type
    BrachyTreatmentType: CS_1_Type
    TreatmentMachineSequence: SQType
    SourceSequence: SQType
    SourceNumber: IS_1_Type
    SourceType: CS_1_Type
    SourceManufacturer: LO_1_Type
    ActiveSourceDiameter: DS_1_Type
    ActiveSourceLength: DS_1_Type
    SourceModelID: SH_1_Type
    SourceDescription: LO_1_Type
    SourceEncapsulationNominalThickness: DS_1_Type
    SourceEncapsulationNominalTransmission: DS_1_Type
    SourceIsotopeName: LO_1_Type
    SourceIsotopeHalfLife: DS_1_Type
    SourceStrengthUnits: CS_1_Type
    ReferenceAirKermaRate: DS_1_Type
    SourceStrength: DS_1_Type
    SourceStrengthReferenceDate: DA_1_Type
    SourceStrengthReferenceTime: TM_1_Type
    ApplicationSetupSequence: SQType
    ApplicationSetupType: CS_1_Type
    ApplicationSetupNumber: IS_1_Type
    ApplicationSetupName: LO_1_Type
    ApplicationSetupManufacturer: LO_1_Type
    TemplateNumber: IS_1_Type
    TemplateType: SH_1_Type
    TemplateName: LO_1_Type
    TotalReferenceAirKerma: DS_1_Type
    BrachyAccessoryDeviceSequence: SQType
    BrachyAccessoryDeviceNumber: IS_1_Type
    BrachyAccessoryDeviceID: SH_1_Type
    BrachyAccessoryDeviceType: CS_1_Type
    BrachyAccessoryDeviceName: LO_1_Type
    BrachyAccessoryDeviceNominalThickness: DS_1_Type
    BrachyAccessoryDeviceNominalTransmission: DS_1_Type
    ChannelEffectiveLength: DS_1_Type
    ChannelInnerLength: DS_1_Type
    AfterloaderChannelID: SH_1_Type
    SourceApplicatorTipLength: DS_1_Type
    ChannelSequence: SQType
    ChannelNumber: IS_1_Type
    ChannelLength: DS_1_Type
    ChannelTotalTime: DS_1_Type
    SourceMovementType: CS_1_Type
    NumberOfPulses: IS_1_Type
    PulseRepetitionInterval: DS_1_Type
    SourceApplicatorNumber: IS_1_Type
    SourceApplicatorID: SH_1_Type
    SourceApplicatorType: CS_1_Type
    SourceApplicatorName: LO_1_Type
    SourceApplicatorLength: DS_1_Type
    SourceApplicatorManufacturer: LO_1_Type
    SourceApplicatorWallNominalThickness: DS_1_Type
    SourceApplicatorWallNominalTransmission: DS_1_Type
    SourceApplicatorStepSize: DS_1_Type
    ApplicatorShapeReferencedROINumber: IS_1_Type
    TransferTubeNumber: IS_1_Type
    TransferTubeLength: DS_1_Type
    ChannelShieldSequence: SQType
    ChannelShieldNumber: IS_1_Type
    ChannelShieldID: SH_1_Type
    ChannelShieldName: LO_1_Type
    ChannelShieldNominalThickness: DS_1_Type
    ChannelShieldNominalTransmission: DS_1_Type
    FinalCumulativeTimeWeight: DS_1_Type
    BrachyControlPointSequence: SQType
    ControlPointRelativePosition: DS_1_Type
    ControlPoint3DPosition: DS_N_Type
    CumulativeTimeWeight: DS_1_Type
    CompensatorDivergence: CS_1_Type
    CompensatorMountingPosition: CS_1_Type
    SourceToCompensatorDistance: DS_1N_Type
    TotalCompensatorTrayWaterEquivalentThickness: FL_1_Type
    IsocenterToCompensatorTrayDistance: FL_1_Type
    CompensatorColumnOffset: FL_1_Type
    IsocenterToCompensatorDistances: FL_1N_Type
    CompensatorRelativeStoppingPowerRatio: FL_1_Type
    CompensatorMillingToolDiameter: FL_1_Type
    IonRangeCompensatorSequence: SQType
    CompensatorDescription: LT_1_Type
    RadiationMassNumber: IS_1_Type
    RadiationAtomicNumber: IS_1_Type
    RadiationChargeState: SS_1_Type
    ScanMode: CS_1_Type
    ModulatedScanModeType: CS_1_Type
    VirtualSourceAxisDistances: FL_N_Type
    SnoutSequence: SQType
    SnoutPosition: FL_1_Type
    SnoutID: SH_1_Type
    NumberOfRangeShifters: IS_1_Type
    RangeShifterSequence: SQType
    RangeShifterNumber: IS_1_Type
    RangeShifterID: SH_1_Type
    RangeShifterType: CS_1_Type
    RangeShifterDescription: LO_1_Type
    NumberOfLateralSpreadingDevices: IS_1_Type
    LateralSpreadingDeviceSequence: SQType
    LateralSpreadingDeviceNumber: IS_1_Type
    LateralSpreadingDeviceID: SH_1_Type
    LateralSpreadingDeviceType: CS_1_Type
    LateralSpreadingDeviceDescription: LO_1_Type
    LateralSpreadingDeviceWaterEquivalentThickness: FL_1_Type
    NumberOfRangeModulators: IS_1_Type
    RangeModulatorSequence: SQType
    RangeModulatorNumber: IS_1_Type
    RangeModulatorID: SH_1_Type
    RangeModulatorType: CS_1_Type
    RangeModulatorDescription: LO_1_Type
    BeamCurrentModulationID: SH_1_Type
    PatientSupportType: CS_1_Type
    PatientSupportID: SH_1_Type
    PatientSupportAccessoryCode: LO_1_Type
    TrayAccessoryCode: LO_1_Type
    FixationLightAzimuthalAngle: FL_1_Type
    FixationLightPolarAngle: FL_1_Type
    MetersetRate: FL_1_Type
    RangeShifterSettingsSequence: SQType
    RangeShifterSetting: LO_1_Type
    IsocenterToRangeShifterDistance: FL_1_Type
    RangeShifterWaterEquivalentThickness: FL_1_Type
    LateralSpreadingDeviceSettingsSequence: SQType
    LateralSpreadingDeviceSetting: LO_1_Type
    IsocenterToLateralSpreadingDeviceDistance: FL_1_Type
    RangeModulatorSettingsSequence: SQType
    RangeModulatorGatingStartValue: FL_1_Type
    RangeModulatorGatingStopValue: FL_1_Type
    RangeModulatorGatingStartWaterEquivalentThickness: FL_1_Type
    RangeModulatorGatingStopWaterEquivalentThickness: FL_1_Type
    IsocenterToRangeModulatorDistance: FL_1_Type
    ScanSpotTimeOffset: FL_1N_Type
    ScanSpotTuneID: SH_1_Type
    ScanSpotPrescribedIndices: IS_1N_Type
    NumberOfScanSpotPositions: IS_1_Type
    ScanSpotReordered: CS_1_Type
    ScanSpotPositionMap: FL_1N_Type
    ScanSpotReorderingAllowed: CS_1_Type
    ScanSpotMetersetWeights: FL_1N_Type
    ScanningSpotSize: FL_N_Type
    ScanSpotSizesDelivered: FL_N_Type
    NumberOfPaintings: IS_1_Type
    IonToleranceTableSequence: SQType
    IonBeamSequence: SQType
    IonBeamLimitingDeviceSequence: SQType
    IonBlockSequence: SQType
    IonControlPointSequence: SQType
    IonWedgeSequence: SQType
    IonWedgePositionSequence: SQType
    ReferencedSetupImageSequence: SQType
    SetupImageComment: ST_1_Type
    MotionSynchronizationSequence: SQType
    ControlPointOrientation: FL_N_Type
    GeneralAccessorySequence: SQType
    GeneralAccessoryID: SH_1_Type
    GeneralAccessoryDescription: ST_1_Type
    GeneralAccessoryType: CS_1_Type
    GeneralAccessoryNumber: IS_1_Type
    SourceToGeneralAccessoryDistance: FL_1_Type
    IsocenterToGeneralAccessoryDistance: DS_1_Type
    ApplicatorGeometrySequence: SQType
    ApplicatorApertureShape: CS_1_Type
    ApplicatorOpening: FL_1_Type
    ApplicatorOpeningX: FL_1_Type
    ApplicatorOpeningY: FL_1_Type
    SourceToApplicatorMountingPositionDistance: FL_1_Type
    NumberOfBlockSlabItems: IS_1_Type
    BlockSlabSequence: SQType
    BlockSlabThickness: DS_1_Type
    BlockSlabNumber: US_1_Type
    DeviceMotionControlSequence: SQType
    DeviceMotionExecutionMode: CS_1_Type
    DeviceMotionObservationMode: CS_1_Type
    DeviceMotionParameterCodeSequence: SQType
    DistalDepthFraction: FL_1_Type
    DistalDepth: FL_1_Type
    NominalRangeModulationFractions: FL_N_Type
    NominalRangeModulatedRegionDepths: FL_N_Type
    DepthDoseParametersSequence: SQType
    DeliveredDepthDoseParametersSequence: SQType
    DeliveredDistalDepthFraction: FL_1_Type
    DeliveredDistalDepth: FL_1_Type
    DeliveredNominalRangeModulationFractions: FL_N_Type
    DeliveredNominalRangeModulatedRegionDepths: FL_N_Type
    DeliveredReferenceDoseDefinition: CS_1_Type
    ReferenceDoseDefinition: CS_1_Type
    RTControlPointIndex: US_1_Type
    RadiationGenerationModeIndex: US_1_Type
    ReferencedDefinedDeviceIndex: US_1_Type
    RadiationDoseIdentificationIndex: US_1_Type
    NumberOfRTControlPoints: US_1_Type
    ReferencedRadiationGenerationModeIndex: US_1_Type
    TreatmentPositionIndex: US_1_Type
    ReferencedDeviceIndex: US_1_Type
    TreatmentPositionGroupLabel: LO_1_Type
    TreatmentPositionGroupUID: UI_1_Type
    TreatmentPositionGroupSequence: SQType
    ReferencedTreatmentPositionIndex: US_1_Type
    ReferencedRadiationDoseIdentificationIndex: US_1_Type
    RTAccessoryHolderWaterEquivalentThickness: FD_1_Type
    ReferencedRTAccessoryHolderDeviceIndex: US_1_Type
    RTAccessoryHolderSlotExistenceFlag: CS_1_Type
    RTAccessoryHolderSlotSequence: SQType
    RTAccessoryHolderSlotID: LO_1_Type
    RTAccessoryHolderSlotDistance: FD_1_Type
    RTAccessorySlotDistance: FD_1_Type
    RTAccessoryHolderDefinitionSequence: SQType
    RTAccessoryDeviceSlotID: LO_1_Type
    RTRadiationSequence: SQType
    RadiationDoseSequence: SQType
    RadiationDoseIdentificationSequence: SQType
    RadiationDoseIdentificationLabel: LO_1_Type
    ReferenceDoseType: CS_1_Type
    PrimaryDoseValueIndicator: CS_1_Type
    DoseValuesSequence: SQType
    DoseValuePurpose: CS_1N_Type
    ReferenceDosePointCoordinates: FD_N_Type
    RadiationDoseValuesParametersSequence: SQType
    MetersetToDoseMappingSequence: SQType
    ExpectedInVivoMeasurementValuesSequence: SQType
    ExpectedInVivoMeasurementValueIndex: US_1_Type
    RadiationDoseInVivoMeasurementLabel: LO_1_Type
    RadiationDoseCentralAxisDisplacement: FD_N_Type
    RadiationDoseValue: FD_1_Type
    RadiationDoseSourceToSkinDistance: FD_1_Type
    RadiationDoseMeasurementPointCoordinates: FD_N_Type
    RadiationDoseSourceToExternalContourDistance: FD_1_Type
    RTToleranceSetSequence: SQType
    RTToleranceSetLabel: LO_1_Type
    AttributeToleranceValuesSequence: SQType
    ToleranceValue: FD_1_Type
    PatientSupportPositionToleranceSequence: SQType
    TreatmentTimeLimit: FD_1_Type
    CArmPhotonElectronControlPointSequence: SQType
    ReferencedRTRadiationSequence: SQType
    ReferencedRTInstanceSequence: SQType
    SourceToPatientSurfaceDistance: FD_1_Type
    TreatmentMachineSpecialModeCodeSequence: SQType
    IntendedNumberOfFractions: US_1_Type
    RTRadiationSetIntent: CS_1_Type
    RTRadiationPhysicalAndGeometricContentDetailFlag: CS_1_Type
    RTRecordFlag: CS_1_Type
    TreatmentDeviceIdentificationSequence: SQType
    ReferencedRTPhysicianIntentSequence: SQType
    CumulativeMeterset: FD_1_Type
    DeliveryRate: FD_1_Type
    DeliveryRateUnitSequence: SQType
    TreatmentPositionSequence: SQType
    RadiationSourceAxisDistance: FD_1_Type
    NumberOfRTBeamLimitingDevices: US_1_Type
    RTBeamLimitingDeviceProximalDistance: FD_1_Type
    RTBeamLimitingDeviceDistalDistance: FD_1_Type
    ParallelRTBeamDelimiterDeviceOrientationLabelCodeSequence: SQType
    BeamModifierOrientationAngle: FD_1_Type
    FixedRTBeamDelimiterDeviceSequence: SQType
    ParallelRTBeamDelimiterDeviceSequence: SQType
    NumberOfParallelRTBeamDelimiters: US_1_Type
    ParallelRTBeamDelimiterBoundaries: FD_N_Type
    ParallelRTBeamDelimiterPositions: FD_N_Type
    RTBeamLimitingDeviceOffset: FD_N_Type
    RTBeamDelimiterGeometrySequence: SQType
    RTBeamLimitingDeviceDefinitionSequence: SQType
    ParallelRTBeamDelimiterOpeningMode: CS_1_Type
    ParallelRTBeamDelimiterLeafMountingSide: CS_1N_Type
    WedgeDefinitionSequence: SQType
    RadiationBeamWedgeAngle: FD_1_Type
    RadiationBeamWedgeThinEdgeDistance: FD_1_Type
    RadiationBeamEffectiveWedgeAngle: FD_1_Type
    NumberOfWedgePositions: US_1_Type
    RTBeamLimitingDeviceOpeningSequence: SQType
    NumberOfRTBeamLimitingDeviceOpenings: US_1_Type
    RadiationDosimeterUnitSequence: SQType
    RTDeviceDistanceReferenceLocationCodeSequence: SQType
    RadiationDeviceConfigurationAndCommissioningKeySequence: SQType
    PatientSupportPositionParameterSequence: SQType
    PatientSupportPositionSpecificationMethod: CS_1_Type
    PatientSupportPositionDeviceParameterSequence: SQType
    DeviceOrderIndex: US_1_Type
    PatientSupportPositionParameterOrderIndex: US_1_Type
    PatientSupportPositionDeviceToleranceSequence: SQType
    PatientSupportPositionToleranceOrderIndex: US_1_Type
    CompensatorDefinitionSequence: SQType
    CompensatorMapOrientation: CS_1_Type
    CompensatorProximalThicknessMap: OF_1_Type
    CompensatorDistalThicknessMap: OF_1_Type
    CompensatorBasePlaneOffset: FD_1_Type
    CompensatorShapeFabricationCodeSequence: SQType
    CompensatorShapeSequence: SQType
    RadiationBeamCompensatorMillingToolDiameter: FD_1_Type
    BlockDefinitionSequence: SQType
    BlockEdgeData: OF_1_Type
    BlockOrientation: CS_1_Type
    RadiationBeamBlockThickness: FD_1_Type
    RadiationBeamBlockSlabThickness: FD_1_Type
    BlockEdgeDataSequence: SQType
    NumberOfRTAccessoryHolders: US_1_Type
    GeneralAccessoryDefinitionSequence: SQType
    NumberOfGeneralAccessories: US_1_Type
    BolusDefinitionSequence: SQType
    NumberOfBoluses: US_1_Type
    EquipmentFrameOfReferenceUID: UI_1_Type
    EquipmentFrameOfReferenceDescription: ST_1_Type
    EquipmentReferencePointCoordinatesSequence: SQType
    EquipmentReferencePointCodeSequence: SQType
    RTBeamLimitingDeviceAngle: FD_1_Type
    SourceRollAngle: FD_1_Type
    RadiationGenerationModeSequence: SQType
    RadiationGenerationModeLabel: SH_1_Type
    RadiationGenerationModeDescription: ST_1_Type
    RadiationGenerationModeMachineCodeSequence: SQType
    RadiationTypeCodeSequence: SQType
    NominalEnergy: DS_1_Type
    MinimumNominalEnergy: DS_1_Type
    MaximumNominalEnergy: DS_1_Type
    RadiationFluenceModifierCodeSequence: SQType
    EnergyUnitCodeSequence: SQType
    NumberOfRadiationGenerationModes: US_1_Type
    PatientSupportDevicesSequence: SQType
    NumberOfPatientSupportDevices: US_1_Type
    RTBeamModifierDefinitionDistance: FD_1_Type
    BeamAreaLimitSequence: SQType
    ReferencedRTPrescriptionSequence: SQType
    DoseValueInterpretation: CS_1_Type
    TreatmentSessionUID: UI_1_Type
    RTRadiationUsage: CS_1_Type
    ReferencedRTRadiationSetSequence: SQType
    ReferencedRTRadiationRecordSequence: SQType
    RTRadiationSetDeliveryNumber: US_1_Type
    ClinicalFractionNumber: US_1_Type
    RTTreatmentFractionCompletionStatus: CS_1_Type
    RTRadiationSetUsage: CS_1_Type
    TreatmentDeliveryContinuationFlag: CS_1_Type
    TreatmentRecordContentOrigin: CS_1_Type
    RTTreatmentTerminationStatus: CS_1_Type
    RTTreatmentTerminationReasonCodeSequence: SQType
    MachineSpecificTreatmentTerminationCodeSequence: SQType
    RTRadiationSalvageRecordControlPointSequence: SQType
    StartingMetersetValueKnownFlag: CS_1_Type
    TreatmentTerminationDescription: ST_1_Type
    TreatmentToleranceViolationSequence: SQType
    TreatmentToleranceViolationCategory: CS_1_Type
    TreatmentToleranceViolationAttributeSequence: SQType
    TreatmentToleranceViolationDescription: ST_1_Type
    TreatmentToleranceViolationIdentification: ST_1_Type
    TreatmentToleranceViolationDateTime: DT_1_Type
    RecordedRTControlPointDateTime: DT_1_Type
    ReferencedRadiationRTControlPointIndex: US_1_Type
    AlternateValueSequence: SQType
    ConfirmationSequence: SQType
    InterlockSequence: SQType
    InterlockDateTime: DT_1_Type
    InterlockDescription: ST_1_Type
    InterlockOriginatingDeviceSequence: SQType
    InterlockCodeSequence: SQType
    InterlockResolutionCodeSequence: SQType
    InterlockResolutionUserSequence: SQType
    OverrideDateTime: DT_1_Type
    TreatmentToleranceViolationTypeCodeSequence: SQType
    TreatmentToleranceViolationCauseCodeSequence: SQType
    MeasuredMetersetToDoseMappingSequence: SQType
    ReferencedExpectedInVivoMeasurementValueIndex: US_1_Type
    DoseMeasurementDeviceCodeSequence: SQType
    AdditionalParameterRecordingInstanceSequence: SQType
    InterlockOriginDescription: ST_1_Type
    RTPatientPositionScopeSequence: SQType
    ReferencedTreatmentPositionGroupUID: UI_1_Type
    RadiationOrderIndex: US_1_Type
    OmittedRadiationSequence: SQType
    ReasonForOmissionCodeSequence: SQType
    RTDeliveryStartPatientPositionSequence: SQType
    RTTreatmentPreparationPatientPositionSequence: SQType
    ReferencedRTTreatmentPreparationSequence: SQType
    ReferencedPatientSetupPhotoSequence: SQType
    PatientTreatmentPreparationMethodCodeSequence: SQType
    PatientTreatmentPreparationProcedureParameterDescription: LT_1_Type
    PatientTreatmentPreparationDeviceSequence: SQType
    PatientTreatmentPreparationProcedureSequence: SQType
    PatientTreatmentPreparationProcedureCodeSequence: SQType
    PatientTreatmentPreparationMethodDescription: LT_1_Type
    PatientTreatmentPreparationProcedureParameterSequence: SQType
    PatientSetupPhotoDescription: LT_1_Type
    PatientTreatmentPreparationProcedureIndex: US_1_Type
    ReferencedPatientSetupProcedureIndex: US_1_Type
    RTRadiationTaskSequence: SQType
    RTPatientPositionDisplacementSequence: SQType
    RTPatientPositionSequence: SQType
    DisplacementReferenceLabel: LO_1_Type
    DisplacementMatrix: FD_N_Type
    PatientSupportDisplacementSequence: SQType
    DisplacementReferenceLocationCodeSequence: SQType
    RTRadiationSetDeliveryUsage: CS_1_Type
    PatientTreatmentPreparationSequence: SQType
    PatientToEquipmentRelationshipSequence: SQType
    ImagingEquipmentToTreatmentDeliveryDeviceRelationshipSequence: SQType
    ReferencedRTPlanSequence: SQType
    ReferencedBeamSequence: SQType
    ReferencedBeamNumber: IS_1_Type
    ReferencedReferenceImageNumber: IS_1_Type
    StartCumulativeMetersetWeight: DS_1_Type
    EndCumulativeMetersetWeight: DS_1_Type
    ReferencedBrachyApplicationSetupSequence: SQType
    ReferencedBrachyApplicationSetupNumber: IS_1_Type
    ReferencedSourceNumber: IS_1_Type
    ReferencedFractionGroupSequence: SQType
    ReferencedFractionGroupNumber: IS_1_Type
    ReferencedVerificationImageSequence: SQType
    ReferencedReferenceImageSequence: SQType
    ReferencedDoseReferenceSequence: SQType
    ReferencedDoseReferenceNumber: IS_1_Type
    BrachyReferencedDoseReferenceSequence: SQType
    ReferencedStructureSetSequence: SQType
    ReferencedPatientSetupNumber: IS_1_Type
    ReferencedDoseSequence: SQType
    ReferencedToleranceTableNumber: IS_1_Type
    ReferencedBolusSequence: SQType
    ReferencedWedgeNumber: IS_1_Type
    ReferencedCompensatorNumber: IS_1_Type
    ReferencedBlockNumber: IS_1_Type
    ReferencedControlPointIndex: IS_1_Type
    ReferencedControlPointSequence: SQType
    ReferencedStartControlPointIndex: IS_1_Type
    ReferencedStopControlPointIndex: IS_1_Type
    ReferencedRangeShifterNumber: IS_1_Type
    ReferencedLateralSpreadingDeviceNumber: IS_1_Type
    ReferencedRangeModulatorNumber: IS_1_Type
    OmittedBeamTaskSequence: SQType
    ReasonForOmission: CS_1_Type
    ReasonForOmissionDescription: LO_1_Type
    PrescriptionOverviewSequence: SQType
    TotalPrescriptionDose: FL_1_Type
    PlanOverviewSequence: SQType
    PlanOverviewIndex: US_1_Type
    ReferencedPlanOverviewIndex: US_1_Type
    NumberOfFractionsIncluded: US_1_Type
    DoseCalibrationConditionsSequence: SQType
    AbsorbedDoseToMetersetRatio: FD_1_Type
    DelineatedRadiationFieldSize: FD_N_Type
    DoseCalibrationConditionsVerifiedFlag: CS_1_Type
    CalibrationReferencePointDepth: FD_1_Type
    GatingBeamHoldTransitionSequence: SQType
    BeamHoldTransition: CS_1_Type
    BeamHoldTransitionDateTime: DT_1_Type
    BeamHoldOriginatingDeviceSequence: SQType
    BeamHoldTransitionTriggerSource: CS_1_Type
    ApprovalStatus: CS_1_Type
    ReviewDate: DA_1_Type
    ReviewTime: TM_1_Type
    ReviewerName: PN_1_Type
    RadiobiologicalDoseEffectSequence: SQType
    RadiobiologicalDoseEffectFlag: CS_1_Type
    EffectiveDoseCalculationMethodCategoryCodeSequence: SQType
    EffectiveDoseCalculationMethodCodeSequence: SQType
    EffectiveDoseCalculationMethodDescription: LO_1_Type
    ConceptualVolumeUID: UI_1_Type
    OriginatingSOPInstanceReferenceSequence: SQType
    ConceptualVolumeConstituentSequence: SQType
    EquivalentConceptualVolumeInstanceReferenceSequence: SQType
    EquivalentConceptualVolumesSequence: SQType
    ReferencedConceptualVolumeUID: UI_1_Type
    ConceptualVolumeCombinationExpression: UT_1_Type
    ConceptualVolumeConstituentIndex: US_1_Type
    ConceptualVolumeCombinationFlag: CS_1_Type
    ConceptualVolumeCombinationDescription: ST_1_Type
    ConceptualVolumeSegmentationDefinedFlag: CS_1_Type
    ConceptualVolumeSegmentationReferenceSequence: SQType
    ConceptualVolumeConstituentSegmentationReferenceSequence: SQType
    ConstituentConceptualVolumeUID: UI_1_Type
    DerivationConceptualVolumeSequence: SQType
    SourceConceptualVolumeUID: UI_1_Type
    ConceptualVolumeDerivationAlgorithmSequence: SQType
    ConceptualVolumeDescription: ST_1_Type
    SourceConceptualVolumeSequence: SQType
    AuthorIdentificationSequence: SQType
    ManufacturerModelVersion: LO_1_Type
    DeviceAlternateIdentifier: UC_1_Type
    DeviceAlternateIdentifierType: CS_1_Type
    DeviceAlternateIdentifierFormat: LT_1_Type
    SegmentationCreationTemplateLabel: LO_1_Type
    SegmentationTemplateUID: UI_1_Type
    ReferencedSegmentReferenceIndex: US_1_Type
    SegmentReferenceSequence: SQType
    SegmentReferenceIndex: US_1_Type
    DirectSegmentReferenceSequence: SQType
    CombinationSegmentReferenceSequence: SQType
    ConceptualVolumeSequence: SQType
    SegmentedRTAccessoryDeviceSequence: SQType
    SegmentCharacteristicsSequence: SQType
    RelatedSegmentCharacteristicsSequence: SQType
    SegmentCharacteristicsPrecedence: US_1_Type
    RTSegmentAnnotationSequence: SQType
    SegmentAnnotationCategoryCodeSequence: SQType
    SegmentAnnotationTypeCodeSequence: SQType
    DeviceLabel: LO_1_Type
    DeviceTypeCodeSequence: SQType
    SegmentAnnotationTypeModifierCodeSequence: SQType
    PatientEquipmentRelationshipCodeSequence: SQType
    ReferencedFiducialsUID: UI_1_Type
    PatientTreatmentOrientationSequence: SQType
    UserContentLabel: SH_1_Type
    UserContentLongLabel: LO_1_Type
    EntityLabel: SH_1_Type
    EntityName: LO_1_Type
    EntityDescription: ST_1_Type
    EntityLongLabel: LO_1_Type
    DeviceIndex: US_1_Type
    RTTreatmentPhaseIndex: US_1_Type
    RTTreatmentPhaseUID: UI_1_Type
    RTPrescriptionIndex: US_1_Type
    RTSegmentAnnotationIndex: US_1_Type
    BasisRTTreatmentPhaseIndex: US_1_Type
    RelatedRTTreatmentPhaseIndex: US_1_Type
    ReferencedRTTreatmentPhaseIndex: US_1_Type
    ReferencedRTPrescriptionIndex: US_1_Type
    ReferencedParentRTPrescriptionIndex: US_1_Type
    ManufacturerDeviceIdentifier: ST_1_Type
    InstanceLevelReferencedPerformedProcedureStepSequence: SQType
    RTTreatmentPhaseIntentPresenceFlag: CS_1_Type
    RadiotherapyTreatmentType: CS_1_Type
    TeletherapyRadiationType: CS_1N_Type
    BrachytherapySourceType: CS_1N_Type
    ReferencedRTTreatmentPhaseSequence: SQType
    ReferencedDirectSegmentInstanceSequence: SQType
    IntendedRTTreatmentPhaseSequence: SQType
    IntendedPhaseStartDate: DA_1_Type
    IntendedPhaseEndDate: DA_1_Type
    RTTreatmentPhaseIntervalSequence: SQType
    TemporalRelationshipIntervalAnchor: CS_1_Type
    MinimumNumberOfIntervalDays: FD_1_Type
    MaximumNumberOfIntervalDays: FD_1_Type
    PertinentSOPClassesInStudy: UI_1N_Type
    PertinentSOPClassesInSeries: UI_1N_Type
    RTPrescriptionLabel: LO_1_Type
    RTPhysicianIntentPredecessorSequence: SQType
    RTTreatmentApproachLabel: LO_1_Type
    RTPhysicianIntentSequence: SQType
    RTPhysicianIntentIndex: US_1_Type
    RTTreatmentIntentType: CS_1_Type
    RTPhysicianIntentNarrative: UT_1_Type
    RTProtocolCodeSequence: SQType
    ReasonForSuperseding: ST_1_Type
    RTDiagnosisCodeSequence: SQType
    ReferencedRTPhysicianIntentIndex: US_1_Type
    RTPhysicianIntentInputInstanceSequence: SQType
    RTAnatomicPrescriptionSequence: SQType
    PriorTreatmentDoseDescription: UT_1_Type
    PriorTreatmentReferenceSequence: SQType
    DosimetricObjectiveEvaluationScope: CS_1_Type
    TherapeuticRoleCategoryCodeSequence: SQType
    TherapeuticRoleTypeCodeSequence: SQType
    ConceptualVolumeOptimizationPrecedence: US_1_Type
    ConceptualVolumeCategoryCodeSequence: SQType
    ConceptualVolumeBlockingConstraint: CS_1_Type
    ConceptualVolumeTypeCodeSequence: SQType
    ConceptualVolumeTypeModifierCodeSequence: SQType
    RTPrescriptionSequence: SQType
    DosimetricObjectiveSequence: SQType
    DosimetricObjectiveTypeCodeSequence: SQType
    DosimetricObjectiveUID: UI_1_Type
    ReferencedDosimetricObjectiveUID: UI_1_Type
    DosimetricObjectiveParameterSequence: SQType
    ReferencedDosimetricObjectivesSequence: SQType
    AbsoluteDosimetricObjectiveFlag: CS_1_Type
    DosimetricObjectiveWeight: FD_1_Type
    DosimetricObjectivePurpose: CS_1_Type
    PlanningInputInformationSequence: SQType
    TreatmentSite: LO_1_Type
    TreatmentSiteCodeSequence: SQType
    FractionPatternSequence: SQType
    TreatmentTechniqueNotes: UT_1_Type
    PrescriptionNotes: UT_1_Type
    NumberOfIntervalFractions: IS_1_Type
    NumberOfFractions: US_1_Type
    IntendedDeliveryDuration: US_1_Type
    FractionationNotes: UT_1_Type
    RTTreatmentTechniqueCodeSequence: SQType
    PrescriptionNotesSequence: SQType
    FractionBasedRelationshipSequence: SQType
    FractionBasedRelationshipIntervalAnchor: CS_1_Type
    MinimumHoursBetweenFractions: FD_1_Type
    IntendedFractionStartTime: TM_1N_Type
    IntendedStartDayOfWeek: LT_1_Type
    WeekdayFractionPatternSequence: SQType
    DeliveryTimeStructureCodeSequence: SQType
    TreatmentSiteModifierCodeSequence: SQType
    RoboticPathNodeSetCodeSequence: SQType
    RoboticNodeIdentifier: UL_1_Type
    RTTreatmentSourceCoordinates: FD_N_Type
    RadiationSourceCoordinateSystemYawAngle: FD_1_Type
    RadiationSourceCoordinateSystemRollAngle: FD_1_Type
    RadiationSourceCoordinateSystemPitchAngle: FD_1_Type
    RoboticPathControlPointSequence: SQType
    TomotherapeuticControlPointSequence: SQType
    TomotherapeuticLeafOpenDurations: FD_1N_Type
    TomotherapeuticLeafInitialClosedDurations: FD_1N_Type
    ConceptualVolumeIdentificationSequence: SQType
    LowEnergyDetectors: CS_1_Type
    HighEnergyDetectors: CS_1_Type
    DetectorGeometrySequence: SQType
    ThreatROIVoxelSequence: SQType
    ThreatROIBase: FL_N_Type
    ThreatROIExtents: FL_N_Type
    ThreatROIBitmap: OB_1_Type
    RouteSegmentID: SH_1_Type
    GantryType: CS_1_Type
    OOIOwnerType: CS_1_Type
    RouteSegmentSequence: SQType
    PotentialThreatObjectID: US_1_Type
    ThreatSequence: SQType
    ThreatCategory: CS_1_Type
    ThreatCategoryDescription: LT_1_Type
    ATDAbilityAssessment: CS_1_Type
    ATDAssessmentFlag: CS_1_Type
    ATDAssessmentProbability: FL_1_Type
    Mass: FL_1_Type
    Density: FL_1_Type
    ZEffective: FL_1_Type
    BoardingPassID: SH_1_Type
    CenterOfMass: FL_N_Type
    CenterOfPTO: FL_N_Type
    BoundingPolygon: FL_N_Type
    RouteSegmentStartLocationID: SH_1_Type
    RouteSegmentEndLocationID: SH_1_Type
    RouteSegmentLocationIDType: CS_1_Type
    AbortReason: CS_1N_Type
    VolumeOfPTO: FL_1_Type
    AbortFlag: CS_1_Type
    RouteSegmentStartTime: DT_1_Type
    RouteSegmentEndTime: DT_1_Type
    TDRType: CS_1_Type
    InternationalRouteSegment: CS_1_Type
    ThreatDetectionAlgorithmAndVersion: LO_1N_Type
    AssignedLocation: SH_1_Type
    AlarmDecisionTime: DT_1_Type
    AlarmDecision: CS_1_Type
    NumberOfTotalObjects: US_1_Type
    NumberOfAlarmObjects: US_1_Type
    PTORepresentationSequence: SQType
    ATDAssessmentSequence: SQType
    TIPType: CS_1_Type
    DICOSVersion: CS_1_Type
    OOIOwnerCreationTime: DT_1_Type
    OOIType: CS_1_Type
    OOISize: FL_N_Type
    AcquisitionStatus: CS_1_Type
    BasisMaterialsCodeSequence: SQType
    PhantomType: CS_1_Type
    OOIOwnerSequence: SQType
    ScanType: CS_1_Type
    ItineraryID: LO_1_Type
    ItineraryIDType: SH_1_Type
    ItineraryIDAssigningAuthority: LO_1_Type
    RouteID: SH_1_Type
    RouteIDAssigningAuthority: SH_1_Type
    InboundArrivalType: CS_1_Type
    CarrierID: SH_1_Type
    CarrierIDAssigningAuthority: CS_1_Type
    SourceOrientation: FL_N_Type
    SourcePosition: FL_N_Type
    BeltHeight: FL_1_Type
    AlgorithmRoutingCodeSequence: SQType
    TransportClassification: CS_1_Type
    OOITypeDescriptor: LT_1_Type
    TotalProcessingTime: FL_1_Type
    DetectorCalibrationData: OB_1_Type
    AdditionalScreeningPerformed: CS_1_Type
    AdditionalInspectionSelectionCriteria: CS_1_Type
    AdditionalInspectionMethodSequence: SQType
    AITDeviceType: CS_1_Type
    QRMeasurementsSequence: SQType
    TargetMaterialSequence: SQType
    SNRThreshold: FD_1_Type
    ImageScaleRepresentation: DS_1_Type
    ReferencedPTOSequence: SQType
    ReferencedTDRInstanceSequence: SQType
    PTOLocationDescription: ST_1_Type
    AnomalyLocatorIndicatorSequence: SQType
    AnomalyLocatorIndicator: FL_N_Type
    PTORegionSequence: SQType
    InspectionSelectionCriteria: CS_1_Type
    SecondaryInspectionMethodSequence: SQType
    PRCSToRCSOrientation: DS_N_Type
    MACParametersSequence: SQType
    SharedFunctionalGroupsSequence: SQType
    PerFrameFunctionalGroupsSequence: SQType
    WaveformSequence: SQType
    ChannelMinimumValue: OB_OW_Type
    ChannelMaximumValue: OB_OW_Type
    WaveformBitsAllocated: US_1_Type
    WaveformSampleInterpretation: CS_1_Type
    WaveformPaddingValue: OB_OW_Type
    WaveformData: OB_OW_Type
    FirstOrderPhaseCorrectionAngle: OF_1_Type
    SpectroscopyData: OF_1_Type
    ExtendedOffsetTable: OV_1_Type
    ExtendedOffsetTableLengths: OV_1_Type
    EncapsulatedPixelDataValueTotalLength: UV_1_Type
    FloatPixelData: OF_1_Type
    DoubleFloatPixelData: OD_1_Type
    PixelData: OB_OW_Type
    DigitalSignaturesSequence: SQType
    DataSetTrailingPadding: OB_1_Type

    # Auto-generated class attributes above

    indent_chars: str
    is_decompressed: bool
    is_undefined_length_sequence_item: bool
    file_meta: Incomplete
    def __init__(self, *args: _DatasetType, **kwargs: Any) -> None: ...
    def __enter__(self) -> Dataset: ...
    def __exit__(self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None) -> bool | None: ...
    def add(self, data_element: DataElement) -> None: ...
    def add_new(self, tag: TagType, VR: str, value: Any) -> None: ...
    def add_new_private(self, private_creator: str, group: int, element_offset: int, value: Any, vr: str | None = None) -> None: ...
    def __array__(self) -> numpy.ndarray: ...
    def data_element(self, name: str) -> DataElement | None: ...
    def __contains__(self, name: TagType) -> bool: ...
    def decode(self) -> None: ...
    def copy(self) -> Dataset: ...
    def __delattr__(self, name: str) -> None: ...
    def __delitem__(self, key: slice | BaseTag | TagType) -> None: ...
    def __dir__(self) -> list[str]: ...
    def dir(self, *filters: str) -> list[str]: ...
    def __eq__(self, other: Any) -> bool: ...
    @overload
    def get(self, key: str, default: Any | None = None) -> Any: ...
    @overload
    def get(self, key: int | tuple[int, int] | BaseTag, default: Any | None = None) -> DataElement: ...
    def items(self) -> Set[tuple[BaseTag, _DatasetValue]]: ...
    def keys(self) -> Set[BaseTag]: ...
    def values(self) -> ValuesView[_DatasetValue]: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    def original_character_set(self) -> str | MutableSequence[str]: ...
    @property
    def read_encoding(self) -> str | MutableSequence[str]: ...
    @read_encoding.setter
    def read_encoding(self, value: str | MutableSequence[str]) -> None: ...
    @overload
    def __getitem__(self, key: slice) -> Dataset: ...
    @overload
    def __getitem__(self, key: TagType) -> DataElement: ...
    def private_block(self, group: int, private_creator: str, create: bool = False) -> PrivateBlock: ...
    def private_creators(self, group: int) -> list[str]: ...
    def get_private_item(self, group: int, element_offset: int, private_creator: str) -> DataElement: ...
    @overload
    def get_item(self, key: slice, *, keep_deferred: bool = ...) -> Dataset: ...
    @overload
    def get_item(self, key: TagType, *, keep_deferred: bool = ...) -> DataElement: ...
    @property
    def is_implicit_VR(self) -> bool | None: ...
    @is_implicit_VR.setter
    def is_implicit_VR(self, value: bool | None) -> None: ...
    @property
    def is_little_endian(self) -> bool | None: ...
    @is_little_endian.setter
    def is_little_endian(self, value: bool | None) -> None: ...
    @property
    def is_original_encoding(self) -> bool: ...
    @property
    def original_encoding(self) -> tuple[bool, bool] | tuple[None, None]: ...
    def set_original_encoding(self, is_implicit_vr: bool | None, is_little_endian: bool | None, character_encoding: str | MutableSequence[str] | None = None) -> None: ...
    def group_dataset(self, group: int) -> Dataset: ...
    def __iter__(self) -> Iterator[DataElement]: ...
    def elements(self) -> Iterator[DataElement | RawDataElement]: ...
    def __len__(self) -> int: ...
    def __ne__(self, other: Any) -> bool: ...
    def clear(self) -> None: ...
    def pop(self, key: BaseTag | TagType, *args: Any) -> _DatasetValue: ...
    def popitem(self) -> tuple[BaseTag, _DatasetValue]: ...
    def setdefault(self, key: TagType, default: Any | None = None) -> DataElement: ...
    def convert_pixel_data(self, handler_name: str = '') -> None: ...
    def compress(self, transfer_syntax_uid: str, arr: numpy.ndarray | None = None, encoding_plugin: str = '', encapsulate_ext: bool = False, *, generate_instance_uid: bool = True, jls_error: int | None = None, j2k_cr: list[float] | None = None, j2k_psnr: list[float] | None = None, **kwargs: Any) -> None: ...
    def decompress(self, handler_name: str = '', *, as_rgb: bool = True, generate_instance_uid: bool = True, decoding_plugin: str = '', **kwargs: Any) -> None: ...
    def overlay_array(self, group: int) -> numpy.ndarray: ...
    @property
    def pixel_array(self) -> numpy.ndarray: ...
    def pixel_array_options(self, *, index: int | None = None, raw: bool = False, decoding_plugin: str = '', use_v2_backend: bool = False, **kwargs: Any) -> None: ...
    def waveform_array(self, index: int) -> numpy.ndarray: ...
    default_element_format: str
    default_sequence_element_format: str
    def formatted_lines(self, element_format: str = ..., sequence_element_format: str = ..., indent_format: str | None = None) -> Iterator[str]: ...
    @property
    def read_implicit_vr(self) -> bool | None: ...
    @property
    def read_little_endian(self) -> bool | None: ...
    def remove_private_tags(self) -> None: ...
    def save_as(self, filename: str | os.PathLike[AnyStr] | BinaryIO | WriteableBuffer, __write_like_original: bool | None = None, /, *, implicit_vr: bool | None = None, little_endian: bool | None = None, enforce_file_format: bool = False, overwrite: bool = True, **kwargs: Any) -> None: ...
    def ensure_file_meta(self) -> None: ...
    def __setattr__(self, name: str, value: Any) -> None: ...
    def __setitem__(self, key: slice | TagType, elem: _DatasetValue) -> None: ...
    def set_pixel_data(self, arr: numpy.ndarray, photometric_interpretation: str, bits_stored: int, *, generate_instance_uid: bool = True) -> None: ...
    def top(self) -> str: ...
    def trait_names(self) -> list[str]: ...
    def update(self, d: _DatasetType) -> None: ...
    def iterall(self) -> Iterator[DataElement]: ...
    def walk(self, callback: Callable[[Dataset, DataElement], None], recursive: bool = True) -> None: ...
    @classmethod
    def from_json(cls, json_dataset: dict[str, Any] | str | bytes | bytearray, bulk_data_uri_handler: Callable[[str, str, str], None | str | int | float | bytes] | Callable[[str], None | str | int | float | bytes] | None = None) -> Dataset: ...
    def to_json_dict(self, bulk_data_threshold: int = 1024, bulk_data_element_handler: Callable[[DataElement], str] | None = None, suppress_invalid_tags: bool = False) -> dict[str, Any]: ...
    def to_json(self, bulk_data_threshold: int = 1024, bulk_data_element_handler: Callable[[DataElement], str] | None = None, dump_handler: Callable[[dict[str, Any]], str] | None = None, suppress_invalid_tags: bool = False) -> str: ...
    def update_raw_element(self, tag: TagType, *, vr: str | None = None, value: bytes | None = None) -> None: ...

class FileDataset(Dataset):
    preamble: Incomplete
    file_meta: Incomplete
    fileobj_type: Incomplete
    filename: Incomplete
    buffer: Incomplete
    timestamp: Incomplete
    def __init__(self, filename_or_obj: PathType | BinaryIO | ReadableBuffer, dataset: _DatasetType, preamble: bytes | None = None, file_meta: FileMetaDataset | None = None, is_implicit_VR: bool = True, is_little_endian: bool = True) -> None: ...
    def __deepcopy__(self, memo: dict[int, Any]) -> FileDataset: ...

def validate_file_meta(file_meta: FileMetaDataset, enforce_standard: bool = True) -> None: ...

class FileMetaDataset(Dataset):
    FileMetaInformationGroupLength: Incomplete
    FileMetaInformationVersion: Incomplete
    MediaStorageSOPClassUID: Incomplete
    MediaStorageSOPInstanceUID: Incomplete
    TransferSyntaxUID: Incomplete
    ImplementationClassUID: Incomplete
    ImplementationVersionName: Incomplete
    SourceApplicationEntityTitle: Incomplete
    SendingApplicationEntityTitle: Incomplete
    ReceivingApplicationEntityTitle: Incomplete
    SourcePresentationAddress: Incomplete
    ReceivingPresentationAddress: Incomplete
    PrivateInformationCreatorUID: Incomplete
    PrivateInformation: Incomplete
    def __init__(self, *args: _DatasetType, **kwargs: Any) -> None: ...
    @staticmethod
    def validate(init_value: _DatasetType) -> None: ...
    def __setitem__(self, key: slice | TagType, value: _DatasetValue) -> None: ...
